Class: AvalaraSdk::A1099::V2::CoveredIndividual
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::CoveredIndividual
- Defined in:
- lib/avalara_sdk/models/A1099/V2/covered_individual.rb
Overview
Covered individual information for health coverage forms
Instance Attribute Summary collapse
-
#birth_date ⇒ Object
Covered individual’s date of birth - Required when SSN is missing.
-
#covered_april ⇒ Object
Coverage indicator for April.
-
#covered_august ⇒ Object
Coverage indicator for August.
-
#covered_december ⇒ Object
Coverage indicator for December.
-
#covered_february ⇒ Object
Coverage indicator for February.
-
#covered_january ⇒ Object
Coverage indicator for January.
-
#covered_july ⇒ Object
Coverage indicator for July.
-
#covered_june ⇒ Object
Coverage indicator for June.
-
#covered_march ⇒ Object
Coverage indicator for March.
-
#covered_may ⇒ Object
Coverage indicator for May.
-
#covered_november ⇒ Object
Coverage indicator for November.
-
#covered_october ⇒ Object
Coverage indicator for October.
-
#covered_september ⇒ Object
Coverage indicator for September.
-
#first_name ⇒ Object
Covered individual’s first name.
-
#id ⇒ Object
Covered individual’s ID.
-
#last_name ⇒ Object
Covered individual’s last name.
-
#middle_name ⇒ Object
Covered individual’s middle name.
-
#name_suffix ⇒ Object
Covered individual’s name suffix.
-
#tin ⇒ Object
Covered individual’s Federal Tax Identification Number (TIN)..
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CoveredIndividual
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CoveredIndividual
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::CoveredIndividual` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::CoveredIndividual`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] else self.first_name = nil end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] else self.last_name = nil end if attributes.key?(:'name_suffix') self.name_suffix = attributes[:'name_suffix'] end if attributes.key?(:'tin') self.tin = attributes[:'tin'] end if attributes.key?(:'birth_date') self.birth_date = attributes[:'birth_date'] end if attributes.key?(:'covered_january') self.covered_january = attributes[:'covered_january'] end if attributes.key?(:'covered_february') self.covered_february = attributes[:'covered_february'] end if attributes.key?(:'covered_march') self.covered_march = attributes[:'covered_march'] end if attributes.key?(:'covered_april') self.covered_april = attributes[:'covered_april'] end if attributes.key?(:'covered_may') self.covered_may = attributes[:'covered_may'] end if attributes.key?(:'covered_june') self.covered_june = attributes[:'covered_june'] end if attributes.key?(:'covered_july') self.covered_july = attributes[:'covered_july'] end if attributes.key?(:'covered_august') self.covered_august = attributes[:'covered_august'] end if attributes.key?(:'covered_september') self.covered_september = attributes[:'covered_september'] end if attributes.key?(:'covered_october') self.covered_october = attributes[:'covered_october'] end if attributes.key?(:'covered_november') self.covered_november = attributes[:'covered_november'] end if attributes.key?(:'covered_december') self.covered_december = attributes[:'covered_december'] end end |
Instance Attribute Details
#birth_date ⇒ Object
Covered individual’s date of birth - Required when SSN is missing.
34 35 36 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 34 def birth_date @birth_date end |
#covered_april ⇒ Object
Coverage indicator for April
46 47 48 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 46 def covered_april @covered_april end |
#covered_august ⇒ Object
Coverage indicator for August
58 59 60 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 58 def covered_august @covered_august end |
#covered_december ⇒ Object
Coverage indicator for December
70 71 72 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 70 def covered_december @covered_december end |
#covered_february ⇒ Object
Coverage indicator for February
40 41 42 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 40 def covered_february @covered_february end |
#covered_january ⇒ Object
Coverage indicator for January
37 38 39 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 37 def covered_january @covered_january end |
#covered_july ⇒ Object
Coverage indicator for July
55 56 57 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 55 def covered_july @covered_july end |
#covered_june ⇒ Object
Coverage indicator for June
52 53 54 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 52 def covered_june @covered_june end |
#covered_march ⇒ Object
Coverage indicator for March
43 44 45 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 43 def covered_march @covered_march end |
#covered_may ⇒ Object
Coverage indicator for May
49 50 51 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 49 def covered_may @covered_may end |
#covered_november ⇒ Object
Coverage indicator for November
67 68 69 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 67 def covered_november @covered_november end |
#covered_october ⇒ Object
Coverage indicator for October
64 65 66 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 64 def covered_october @covered_october end |
#covered_september ⇒ Object
Coverage indicator for September
61 62 63 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 61 def covered_september @covered_september end |
#first_name ⇒ Object
Covered individual’s first name
19 20 21 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 19 def first_name @first_name end |
#id ⇒ Object
Covered individual’s ID
16 17 18 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 16 def id @id end |
#last_name ⇒ Object
Covered individual’s last name
25 26 27 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 25 def last_name @last_name end |
#middle_name ⇒ Object
Covered individual’s middle name
22 23 24 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 22 def middle_name @middle_name end |
#name_suffix ⇒ Object
Covered individual’s name suffix
28 29 30 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 28 def name_suffix @name_suffix end |
#tin ⇒ Object
Covered individual’s Federal Tax Identification Number (TIN).. SSN or ITIN. Required unless unavailable.
31 32 33 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 31 def tin @tin end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 328 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 73 def self.attribute_map { :'id' => :'id', :'first_name' => :'firstName', :'middle_name' => :'middleName', :'last_name' => :'lastName', :'name_suffix' => :'nameSuffix', :'tin' => :'tin', :'birth_date' => :'birthDate', :'covered_january' => :'coveredJanuary', :'covered_february' => :'coveredFebruary', :'covered_march' => :'coveredMarch', :'covered_april' => :'coveredApril', :'covered_may' => :'coveredMay', :'covered_june' => :'coveredJune', :'covered_july' => :'coveredJuly', :'covered_august' => :'coveredAugust', :'covered_september' => :'coveredSeptember', :'covered_october' => :'coveredOctober', :'covered_november' => :'coveredNovember', :'covered_december' => :'coveredDecember' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 304 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 128 def self.openapi_nullable Set.new([ :'id', :'first_name', :'middle_name', :'last_name', :'name_suffix', :'tin', :'birth_date', :'covered_january', :'covered_february', :'covered_march', :'covered_april', :'covered_may', :'covered_june', :'covered_july', :'covered_august', :'covered_september', :'covered_october', :'covered_november', :'covered_december' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 103 def self.openapi_types { :'id' => :'String', :'first_name' => :'String', :'middle_name' => :'String', :'last_name' => :'String', :'name_suffix' => :'String', :'tin' => :'String', :'birth_date' => :'Date', :'covered_january' => :'Boolean', :'covered_february' => :'Boolean', :'covered_march' => :'Boolean', :'covered_april' => :'Boolean', :'covered_may' => :'Boolean', :'covered_june' => :'Boolean', :'covered_july' => :'Boolean', :'covered_august' => :'Boolean', :'covered_september' => :'Boolean', :'covered_october' => :'Boolean', :'covered_november' => :'Boolean', :'covered_december' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && first_name == o.first_name && middle_name == o.middle_name && last_name == o.last_name && name_suffix == o.name_suffix && tin == o.tin && birth_date == o.birth_date && covered_january == o.covered_january && covered_february == o.covered_february && covered_march == o.covered_march && covered_april == o.covered_april && covered_may == o.covered_may && covered_june == o.covered_june && covered_july == o.covered_july && covered_august == o.covered_august && covered_september == o.covered_september && covered_october == o.covered_october && covered_november == o.covered_november && covered_december == o.covered_december end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 399 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
291 292 293 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 291 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
297 298 299 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 297 def hash [id, first_name, middle_name, last_name, name_suffix, tin, birth_date, covered_january, covered_february, covered_march, covered_april, covered_may, covered_june, covered_july, covered_august, covered_september, covered_october, covered_november, covered_december].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
250 251 252 253 254 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 250 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
375 376 377 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 375 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 381 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
369 370 371 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 369 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 |
# File 'lib/avalara_sdk/models/A1099/V2/covered_individual.rb', line 258 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |