Class: AvalaraSdk::A1099::V2::Form1042S

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/A1099/V2/form1042_s.rb

Overview

Form 1042-S: Foreign Person’s U.S. Source Income Subject to Withholding

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Form1042S

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 438

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::Form1042S` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::Form1042S`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tin_type')
    self.tin_type = attributes[:'tin_type']
  end

  if attributes.key?(:'unique_form_id')
    self.unique_form_id = attributes[:'unique_form_id']
  else
    self.unique_form_id = nil
  end

  if attributes.key?(:'recipient_date_of_birth')
    self.recipient_date_of_birth = attributes[:'recipient_date_of_birth']
  end

  if attributes.key?(:'recipient_giin')
    self.recipient_giin = attributes[:'recipient_giin']
  end

  if attributes.key?(:'recipient_foreign_tin')
    self.recipient_foreign_tin = attributes[:'recipient_foreign_tin']
  end

  if attributes.key?(:'lob_code')
    self.lob_code = attributes[:'lob_code']
  end

  if attributes.key?(:'income_code')
    self.income_code = attributes[:'income_code']
  else
    self.income_code = nil
  end

  if attributes.key?(:'gross_income')
    self.gross_income = attributes[:'gross_income']
  else
    self.gross_income = nil
  end

  if attributes.key?(:'withholding_indicator')
    self.withholding_indicator = attributes[:'withholding_indicator']
  else
    self.withholding_indicator = nil
  end

  if attributes.key?(:'tax_country_code')
    self.tax_country_code = attributes[:'tax_country_code']
  else
    self.tax_country_code = nil
  end

  if attributes.key?(:'exemption_code_chap3')
    self.exemption_code_chap3 = attributes[:'exemption_code_chap3']
  end

  if attributes.key?(:'exemption_code_chap4')
    self.exemption_code_chap4 = attributes[:'exemption_code_chap4']
  end

  if attributes.key?(:'tax_rate_chap3')
    self.tax_rate_chap3 = attributes[:'tax_rate_chap3']
  end

  if attributes.key?(:'withholding_allowance')
    self.withholding_allowance = attributes[:'withholding_allowance']
  end

  if attributes.key?(:'federal_tax_withheld')
    self.federal_tax_withheld = attributes[:'federal_tax_withheld']
  end

  if attributes.key?(:'tax_not_deposited_indicator')
    self.tax_not_deposited_indicator = attributes[:'tax_not_deposited_indicator']
  end

  if attributes.key?(:'academic_indicator')
    self.academic_indicator = attributes[:'academic_indicator']
  end

  if attributes.key?(:'tax_withheld_other_agents')
    self.tax_withheld_other_agents = attributes[:'tax_withheld_other_agents']
  end

  if attributes.key?(:'amount_repaid')
    self.amount_repaid = attributes[:'amount_repaid']
  end

  if attributes.key?(:'tax_paid_agent')
    self.tax_paid_agent = attributes[:'tax_paid_agent']
  end

  if attributes.key?(:'chap3_status_code')
    self.chap3_status_code = attributes[:'chap3_status_code']
  end

  if attributes.key?(:'chap4_status_code')
    self.chap4_status_code = attributes[:'chap4_status_code']
  end

  if attributes.key?(:'primary_withholding_agent')
    self.primary_withholding_agent = attributes[:'primary_withholding_agent']
  end

  if attributes.key?(:'intermediary_or_flow_through')
    self.intermediary_or_flow_through = attributes[:'intermediary_or_flow_through']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'issuer_id')
    self.issuer_id = attributes[:'issuer_id']
  end

  if attributes.key?(:'issuer_reference_id')
    self.issuer_reference_id = attributes[:'issuer_reference_id']
  end

  if attributes.key?(:'issuer_tin')
    self.issuer_tin = attributes[:'issuer_tin']
  end

  if attributes.key?(:'tax_year')
    self.tax_year = attributes[:'tax_year']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'tin')
    self.tin = attributes[:'tin']
  end

  if attributes.key?(:'recipient_name')
    self.recipient_name = attributes[:'recipient_name']
  else
    self.recipient_name = nil
  end

  if attributes.key?(:'recipient_second_name')
    self.recipient_second_name = attributes[:'recipient_second_name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'address2')
    self.address2 = attributes[:'address2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'zip')
    self.zip = attributes[:'zip']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'account_number')
    self. = attributes[:'account_number']
  end

  if attributes.key?(:'office_code')
    self.office_code = attributes[:'office_code']
  end

  if attributes.key?(:'non_us_province')
    self.non_us_province = attributes[:'non_us_province']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  else
    self.country_code = nil
  end

  if attributes.key?(:'federal_efile_date')
    self.federal_efile_date = attributes[:'federal_efile_date']
  end

  if attributes.key?(:'postal_mail')
    self.postal_mail = attributes[:'postal_mail']
  end

  if attributes.key?(:'state_efile_date')
    self.state_efile_date = attributes[:'state_efile_date']
  end

  if attributes.key?(:'recipient_edelivery_date')
    self.recipient_edelivery_date = attributes[:'recipient_edelivery_date']
  end

  if attributes.key?(:'tin_match')
    self.tin_match = attributes[:'tin_match']
  end

  if attributes.key?(:'no_tin')
    self.no_tin = attributes[:'no_tin']
  end

  if attributes.key?(:'address_verification')
    self.address_verification = attributes[:'address_verification']
  end

  if attributes.key?(:'state_and_local_withholding')
    self.state_and_local_withholding = attributes[:'state_and_local_withholding']
  end

  if attributes.key?(:'second_tin_notice')
    self.second_tin_notice = attributes[:'second_tin_notice']
  end

  if attributes.key?(:'federal_efile_status')
    self.federal_efile_status = attributes[:'federal_efile_status']
  end

  if attributes.key?(:'state_efile_status')
    if (value = attributes[:'state_efile_status']).is_a?(Array)
      self.state_efile_status = value
    end
  end

  if attributes.key?(:'postal_mail_status')
    self.postal_mail_status = attributes[:'postal_mail_status']
  end

  if attributes.key?(:'tin_match_status')
    self.tin_match_status = attributes[:'tin_match_status']
  end

  if attributes.key?(:'address_verification_status')
    self.address_verification_status = attributes[:'address_verification_status']
  end

  if attributes.key?(:'e_delivery_status')
    self.e_delivery_status = attributes[:'e_delivery_status']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#academic_indicatorObject

Academic indicator



64
65
66
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 64

def academic_indicator
  @academic_indicator
end

#account_numberObject

Account number



136
137
138
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 136

def 
  @account_number
end

#addressObject

Address.



118
119
120
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 118

def address
  @address
end

#address2Object

Address line 2.



121
122
123
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 121

def address2
  @address2
end

#address_verificationObject

Boolean indicating that address verification should be scheduled for this form



166
167
168
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 166

def address_verification
  @address_verification
end

#address_verification_statusObject

Address verification status. Available values: - unknown: Address verification has not been checked - pending: Address verification is in progress - failed: Address verification failed - incomplete: Address verification is incomplete - unchanged: User declined address changes - verified: Address has been verified and accepted



187
188
189
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 187

def address_verification_status
  @address_verification_status
end

#amount_repaidObject

Amount repaid to recipient



70
71
72
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 70

def amount_repaid
  @amount_repaid
end

#chap3_status_codeObject

Chapter 3 status code - Required if WithholdingIndicator is 3 (Chapter 3). Available values: - 01: U.S. Withholding Agent - FI (Deprecated - valid only for tax years prior to 2020) - 02: U.S. Withholding Agent - Other (Deprecated - valid only for tax years prior to 2020) - 03: Territory FI - treated as U.S. Person - 04: Territory FI - not treated as U.S. Person - 05: U.S. branch - treated as U.S. Person - 06: U.S. branch - not treated as U.S. Person - 07: U.S. branch - ECI presumption applied - 08: Partnership other than Withholding Foreign Partnership - 09: Withholding Foreign Partnership - 10: Trust other than Withholding Foreign Trust - 11: Withholding Foreign Trust - 12: Qualified Intermediary - 13: Qualified Securities Lender - Qualified Intermediary - 14: Qualified Securities Lender - Other - 15: Corporation - 16: Individual - 17: Estate - 18: Private Foundation - 19: Government or International Organization - 20: Tax Exempt Organization (Section 501© entities) - 21: Unknown Recipient - 22: Artist or Athlete - 23: Pension - 24: Foreign Central Bank of Issue - 25: Nonqualified Intermediary - 26: Hybrid entity making Treaty Claim - 27: Withholding Rate Pool - General - 28: Withholding Rate Pool - Exempt Organization - 29: PAI Withholding Rate Pool - General - 30: PAI Withholding Rate Pool - Exempt Organization - 31: Agency Withholding Rate Pool - General - 32: Agency Withholding Rate Pool - Exempt Organization - 34: U.S. Withholding Agent-Foreign branch of FI (Deprecated - valid only for tax years prior to 2020) - 35: Qualified Derivatives Dealer - 36: Foreign Government - Integral Part - 37: Foreign Government - Controlled Entity - 38: Publicly Traded Partnership - 39: Disclosing Qualified Intermediary



76
77
78
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 76

def chap3_status_code
  @chap3_status_code
end

#chap4_status_codeObject

Chapter 4 status code. Required if WithholdingIndicator is 4 (Chapter 4). Required if email is specified, must fill either this or RecipientForeignTin. Available values: - 01: U.S. Withholding Agent - FI - 02: U.S. Withholding Agent - Other - 03: Territory FI - not treated as U.S. Person - 04: Territory FI - treated as U.S. Person - 05: Participating FFI - Other - 06: Participating FFI - Reporting Model 2 FFI - 07: Registered Deemed - Compliant FFI-Reporting Model 1 FFI - 08: Registered Deemed - Compliant FFI-Sponsored Entity - 09: Registered Deemed - Compliant FFI-Other - 10: Certified Deemed - Compliant FFI-Other - 11: Certified Deemed - Compliant FFI-FFI with Low Value Accounts - 12: Certified Deemed - Compliant FFI-Non-Registering Local Bank - 13: Certified Deemed - Compliant FFI-Sponsored Entity - 14: Certified Deemed - Compliant FFI-Investment Advisor or Investment Manager - 15: Nonparticipating FFI - 16: Owner-Documented FFI - 17: U.S. Branch - treated as U.S. person - 18: U.S. Branch - not treated as U.S. person (reporting under section 1471) - 19: Passive NFFE identifying Substantial U.S. Owners - 20: Passive NFFE with no Substantial U.S. Owners - 21: Publicly Traded NFFE or Affiliate of Publicly Traded NFFE - 22: Active NFFE - 23: Individual - 24: Section 501© Entities - 25: Excepted Territory NFFE - 26: Excepted NFFE - Other - 27: Exempt Beneficial Owner - 28: Entity Wholly Owned by Exempt Beneficial Owners - 29: Unknown Recipient - 30: Recalcitrant Account Holder - 31: Nonreporting IGA FFI - 32: Direct reporting NFFE - 33: U.S. reportable account - 34: Non-consenting U.S. account - 35: Sponsored direct reporting NFFE - 36: Excepted Inter-affiliate FFI - 37: Undocumented Preexisting Obligation - 38: U.S. Branch - ECI presumption applied - 39: Account Holder of Excluded Financial Account - 40: Passive NFFE reported by FFI - 41: NFFE subject to 1472 withholding - 42: Recalcitrant Pool - No U.S. Indicia - 43: Recalcitrant Pool - U.S. Indicia - 44: Recalcitrant Pool - Dormant Account - 45: Recalcitrant Pool - U.S. Persons - 46: Recalcitrant Pool - Passive NFFEs - 47: Nonparticipating FFI Pool - 48: U.S. Payees Pool - 49: QI - Recalcitrant Pool-General - 50: U.S. Withholding Agent-Foreign branch of FI



79
80
81
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 79

def chap4_status_code
  @chap4_status_code
end

#cityObject

City.



124
125
126
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 124

def city
  @city
end

#country_codeObject

Two-letter IRS country code (e.g., ‘US’, ‘CA’), as defined at www.irs.gov/e-file-providers/country-codes.



145
146
147
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 145

def country_code
  @country_code
end

#created_atObject

Date time when the record was created.



196
197
198
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 196

def created_at
  @created_at
end

#e_delivery_statusObject

EDelivery status. Available values: - unscheduled: E-delivery has not been scheduled - scheduled: E-delivery is scheduled to be sent - sent: E-delivery has been sent to recipient - bounced: E-delivery bounced back (invalid email) - refused: E-delivery was refused by recipient - bad_verify: E-delivery failed verification - accepted: E-delivery was accepted by recipient - bad_verify_limit: E-delivery failed verification limit reached - second_delivery: Second e-delivery attempt - undelivered: E-delivery is undelivered (temporary state allowing resend)



190
191
192
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 190

def e_delivery_status
  @e_delivery_status
end

#emailObject

Recipient’s Contact email address.



133
134
135
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 133

def email
  @email
end

#exemption_code_chap3Object

Exemption code (Chapter 3). Required if WithholdingIndicator is 3 (Chapter 3) and FederalTaxWithheld is 0. Required when using TaxRateChap3. Can be left empty if FederalTaxWithheld is greater than 0. Available values: - 00: Not exempt - 01: Effectively connected income - 02: Exempt under IRC (other than portfolio interest) - 03: Income is not from US sources - 04: Exempt under tax treaty - 05: Portfolio interest exempt under IRC - 06: QI that assumes primary withholding responsibility - 07: WFP or WFT - 08: U.S. branch treated as U.S. Person - 09: Territory FI treated as U.S. Person - 10: QI represents that income is exempt - 11: QSL that assumes primary withholding responsibility - 12: Payee subjected to chapter 4 withholding - 22: QDD that assumes primary withholding responsibility - 23: Exempt under section 897(l) - 24: Exempt under section 892



46
47
48
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 46

def exemption_code_chap3
  @exemption_code_chap3
end

#exemption_code_chap4Object

Exemption code (Chapter 4). Required if WithholdingIndicator is 4 (Chapter 4). Available values: - 00: Not exempt - 13: Grandfathered payment - 14: Effectively connected income - 15: Payee not subject to chapter 4 withholding - 16: Excluded nonfinancial payment - 17: Foreign Entity that assumes primary withholding responsibility - 18: U.S. Payees - of participating FFI or registered deemed - compliant FFI - 19: Exempt from withholding under IGA(6) - 20: Dormant account(7) - 21: Other - payment not subject to chapter 4 withholding



49
50
51
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 49

def exemption_code_chap4
  @exemption_code_chap4
end

#federal_efile_dateObject

Date when federal e-filing should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



148
149
150
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 148

def federal_efile_date
  @federal_efile_date
end

#federal_efile_statusObject

Federal e-file status. Available values: - unscheduled: Form has not been scheduled for federal e-filing - scheduled: Form is scheduled for federal e-filing - airlock: Form is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - sent: Form has been sent to the IRS - accepted: Form was accepted by the IRS - corrected_scheduled: Correction is scheduled to be sent - corrected_airlock: Correction is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - corrected: A correction has been sent to the IRS - corrected_accepted: Correction was accepted by the IRS - rejected: Form was rejected by the IRS - corrected_rejected: Correction was rejected by the IRS - held: Form is held and will not be submitted to IRS (used for certain forms submitted only to states)



175
176
177
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 175

def federal_efile_status
  @federal_efile_status
end

#federal_tax_withheldObject

Federal tax withheld



58
59
60
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 58

def federal_tax_withheld
  @federal_tax_withheld
end

#gross_incomeObject

Gross income



37
38
39
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 37

def gross_income
  @gross_income
end

#idObject

Form ID. Unique identifier set when the record is created.



91
92
93
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 91

def id
  @id
end

#income_codeObject

Income code. Available values: Interest: - 01: Interest paid by US obligors - general - 02: Interest paid on real property mortgages - 03: Interest paid to controlling foreign corporations - 04: Interest paid by foreign corporations - 05: Interest on tax-free covenant bonds - 22: Interest paid on deposit with a foreign branch of a domestic corporation or partnership - 29: Deposit interest - 30: Original issue discount (OID) - 31: Short-term OID - 33: Substitute payment - interest - 51: Interest paid on certain actively traded or publicly offered securities(1) - 54: Substitute payments - interest from certain actively traded or publicly offered securities(1) Dividend: - 06: Dividends paid by U.S. corporations - general - 07: Dividends qualifying for direct dividend rate - 08: Dividends paid by foreign corporations - 34: Substitute payment - dividends - 40: Other dividend equivalents under IRC section 871(m) (formerly 871(l)) - 52: Dividends paid on certain actively traded or publicly offered securities(1) - 53: Substitute payments - dividends from certain actively traded or publicly offered securities(1) - 56: Dividend equivalents under IRC section 871(m) as a result of applying the combined transaction rules Other: - 09: Capital gains - 10: Industrial royalties - 11: Motion picture or television copyright royalties - 12: Other royalties (for example, copyright, software, broadcasting, endorsement payments) - 13: Royalties paid on certain publicly offered securities(1) - 14: Real property income and natural resources royalties - 15: Pensions, annuities, alimony, and/or insurance premiums - 16: Scholarship or fellowship grants - 17: Compensation for independent personal services(2) - 18: Compensation for dependent personal services(2) - 19: Compensation for teaching(2) - 20: Compensation during studying and training(2) - 23: Other income - 24: Qualified investment entity (QIE) distributions of capital gains - 25: Trust distributions subject to IRC section 1445 - 26: Unsevered growing crops and timber distributions by a trust subject to IRC section 1445 - 27: Publicly traded partnership distributions subject to IRC section 1446 - 28: Gambling winnings(3) - 32: Notional principal contract income(4) - 35: Substitute payment - other - 36: Capital gains distributions - 37: Return of capital - 38: Eligible deferred compensation items subject to IRC section 877A(d)(1) - 39: Distributions from a nongrantor trust subject to IRC section 877A(f)(1) - 41: Guarantee of indebtedness - 42: Earnings as an artist or athlete - no central withholding agreement(5) - 43: Earnings as an artist or athlete - central withholding agreement(5) - 44: Specified Federal procurement payments - 50: Income previously reported under escrow procedure(6) - 55: Taxable death benefits on life insurance contracts - 57: Amount realized under IRC section 1446(f) - 58: Publicly traded partnership distributions-undetermined



34
35
36
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 34

def income_code
  @income_code
end

#intermediary_or_flow_throughObject

Intermediary or flow-through entity information



85
86
87
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 85

def intermediary_or_flow_through
  @intermediary_or_flow_through
end

#issuer_idObject

Issuer ID - only required when creating forms



94
95
96
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 94

def issuer_id
  @issuer_id
end

#issuer_reference_idObject

Issuer Reference ID - only required when creating forms via $bulk-upsert



97
98
99
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 97

def issuer_reference_id
  @issuer_reference_id
end

#issuer_tinObject

Issuer TIN - readonly



100
101
102
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 100

def issuer_tin
  @issuer_tin
end

#lob_codeObject

Limitation on Benefits (LOB) code for tax treaty purposes. Available values: - 01: Individual (Deprecated - valid only for tax years prior to 2019) - 02: Government - contracting state/political subdivision/local authority - 03: Tax exempt pension trust/Pension fund - 04: Tax exempt/Charitable organization - 05: Publicly-traded corporation - 06: Subsidiary of publicly-traded corporation - 07: Company that meets the ownership and base erosion test - 08: Company that meets the derivative benefits test - 09: Company with an item of income that meets the active trade or business test - 10: Discretionary determination - 11: Other - 12: No LOB article in treaty



31
32
33
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 31

def lob_code
  @lob_code
end

#no_tinObject

No TIN indicator



163
164
165
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 163

def no_tin
  @no_tin
end

#non_us_provinceObject

Province or region for non-US/CA addresses.



142
143
144
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 142

def non_us_province
  @non_us_province
end

#office_codeObject

Office code



139
140
141
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 139

def office_code
  @office_code
end

#postal_mailObject

Boolean indicating that postal mailing to the recipient should be scheduled for this form



151
152
153
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 151

def postal_mail
  @postal_mail
end

#postal_mail_statusObject

Postal mail to recipient status. Available values: - unscheduled: Postal mail has not been scheduled - pending: Postal mail is pending to be sent - sent: Postal mail has been sent - delivered: Postal mail has been delivered



181
182
183
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 181

def postal_mail_status
  @postal_mail_status
end

#primary_withholding_agentObject

Primary withholding agent information



82
83
84
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 82

def primary_withholding_agent
  @primary_withholding_agent
end

#recipient_date_of_birthObject

Recipient’s date of birth



22
23
24
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 22

def recipient_date_of_birth
  @recipient_date_of_birth
end

#recipient_edelivery_dateObject

Date when recipient e-delivery should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



157
158
159
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 157

def recipient_edelivery_date
  @recipient_edelivery_date
end

#recipient_foreign_tinObject

Recipient’s foreign TIN. Required if email is specified, must fill either this or Chap3StatusCode.



28
29
30
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 28

def recipient_foreign_tin
  @recipient_foreign_tin
end

#recipient_giinObject

Recipient’s Global Intermediary Identification Number (GIIN). A valid GIIN looks like ‘XXXXXX.XXXXX.XX.XXX’.



25
26
27
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 25

def recipient_giin
  @recipient_giin
end

#recipient_nameObject

Recipient name



112
113
114
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 112

def recipient_name
  @recipient_name
end

#recipient_second_nameObject

Recipient second name



115
116
117
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 115

def recipient_second_name
  @recipient_second_name
end

#reference_idObject

Internal reference ID. Never shown to any agency or recipient.



106
107
108
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 106

def reference_id
  @reference_id
end

#second_tin_noticeObject

Second TIN notice



172
173
174
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 172

def second_tin_notice
  @second_tin_notice
end

#stateObject

Two-letter US state or Canadian province code (required for US/CA addresses).



127
128
129
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 127

def state
  @state
end

#state_and_local_withholdingObject

State and local withholding information



169
170
171
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 169

def state_and_local_withholding
  @state_and_local_withholding
end

#state_efile_dateObject

Date when state e-filing should be scheduled. Must be on or after federalEfileDate. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



154
155
156
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 154

def state_efile_date
  @state_efile_date
end

#state_efile_statusObject

State e-file status. Available values: - unscheduled: Form has not been scheduled for state e-filing - scheduled: Form is scheduled for state e-filing - airlocked: Form is in process of being uploaded to the state - sent: Form has been sent to the state - rejected: Form was rejected by the state - accepted: Form was accepted by the state - corrected_scheduled: Correction is scheduled to be sent - corrected_airlocked: Correction is in process of being uploaded to the state - corrected_sent: Correction has been sent to the state - corrected_rejected: Correction was rejected by the state - corrected_accepted: Correction was accepted by the state



178
179
180
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 178

def state_efile_status
  @state_efile_status
end

#tax_country_codeObject

Country code



43
44
45
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 43

def tax_country_code
  @tax_country_code
end

#tax_not_deposited_indicatorObject

Tax not deposited indicator



61
62
63
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 61

def tax_not_deposited_indicator
  @tax_not_deposited_indicator
end

#tax_paid_agentObject

Tax paid by withholding agent



73
74
75
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 73

def tax_paid_agent
  @tax_paid_agent
end

#tax_rate_chap3Object

Tax rate (Chapter 3) - Required if WithholdingIndicator is 3 (Chapter 3). Available values: - 00.00: 0.00% - 02.00: 2.00% - 04.00: 4.00% - 04.90: 4.90% - 04.95: 4.95% - 05.00: 5.00% - 07.00: 7.00% - 08.00: 8.00% - 10.00: 10.00% - 12.00: 12.00% - 12.50: 12.50% - 14.00: 14.00% - 15.00: 15.00% - 17.50: 17.50% - 20.00: 20.00% - 21.00: 21.00% - 24.00: 24.00% - 25.00: 25.00% - 27.50: 27.50% - 28.00: 28.00% - 30.00: 30.00% - 37.00: 37.00%



52
53
54
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 52

def tax_rate_chap3
  @tax_rate_chap3
end

#tax_withheld_other_agentsObject

Tax withheld by other agents



67
68
69
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 67

def tax_withheld_other_agents
  @tax_withheld_other_agents
end

#tax_yearObject

Tax Year - only required when creating forms via $bulk-upsert



103
104
105
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 103

def tax_year
  @tax_year
end

#tinObject

Recipient’s Federal Tax Identification Number (TIN).



109
110
111
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 109

def tin
  @tin
end

#tin_matchObject

Boolean indicating that TIN Matching should be scheduled for this form



160
161
162
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 160

def tin_match
  @tin_match
end

#tin_match_statusObject

TIN Match status. Available values: - none: TIN matching has not been performed - pending: TIN matching request is pending - matched: Name/TIN combination matches IRS records - unknown: TIN is missing, invalid, or request contains errors - rejected: Name/TIN combination does not match IRS records or TIN not currently issued



184
185
186
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 184

def tin_match_status
  @tin_match_status
end

#tin_typeObject

Tax Identification Number (TIN) type. Available values: - EIN: Employer Identification Number - SSN: Social Security Number - ITIN: Individual Taxpayer Identification Number - ATIN: Adoption Taxpayer Identification Number



16
17
18
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 16

def tin_type
  @tin_type
end

#typeObject

Form type.



88
89
90
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 88

def type
  @type
end

#unique_form_idObject

Unique form identifier



19
20
21
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 19

def unique_form_id
  @unique_form_id
end

#updated_atObject

Date time when the record was last updated.



199
200
201
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 199

def updated_at
  @updated_at
end

#validation_errorsObject

Validation errors



193
194
195
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 193

def validation_errors
  @validation_errors
end

#withholding_allowanceObject

Withholding allowance



55
56
57
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 55

def withholding_allowance
  @withholding_allowance
end

#withholding_indicatorObject

Withholding indicator Available values: - 3: Chapter 3 - 4: Chapter 4



40
41
42
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 40

def withholding_indicator
  @withholding_indicator
end

#zipObject

ZIP/postal code.



130
131
132
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 130

def zip
  @zip
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 972

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::A1099::V2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



292
293
294
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 292

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 224

def self.attribute_map
  {
    :'tin_type' => :'tinType',
    :'unique_form_id' => :'uniqueFormId',
    :'recipient_date_of_birth' => :'recipientDateOfBirth',
    :'recipient_giin' => :'recipientGiin',
    :'recipient_foreign_tin' => :'recipientForeignTin',
    :'lob_code' => :'lobCode',
    :'income_code' => :'incomeCode',
    :'gross_income' => :'grossIncome',
    :'withholding_indicator' => :'withholdingIndicator',
    :'tax_country_code' => :'taxCountryCode',
    :'exemption_code_chap3' => :'exemptionCodeChap3',
    :'exemption_code_chap4' => :'exemptionCodeChap4',
    :'tax_rate_chap3' => :'taxRateChap3',
    :'withholding_allowance' => :'withholdingAllowance',
    :'federal_tax_withheld' => :'federalTaxWithheld',
    :'tax_not_deposited_indicator' => :'taxNotDepositedIndicator',
    :'academic_indicator' => :'academicIndicator',
    :'tax_withheld_other_agents' => :'taxWithheldOtherAgents',
    :'amount_repaid' => :'amountRepaid',
    :'tax_paid_agent' => :'taxPaidAgent',
    :'chap3_status_code' => :'chap3StatusCode',
    :'chap4_status_code' => :'chap4StatusCode',
    :'primary_withholding_agent' => :'primaryWithholdingAgent',
    :'intermediary_or_flow_through' => :'intermediaryOrFlowThrough',
    :'type' => :'type',
    :'id' => :'id',
    :'issuer_id' => :'issuerId',
    :'issuer_reference_id' => :'issuerReferenceId',
    :'issuer_tin' => :'issuerTin',
    :'tax_year' => :'taxYear',
    :'reference_id' => :'referenceId',
    :'tin' => :'tin',
    :'recipient_name' => :'recipientName',
    :'recipient_second_name' => :'recipientSecondName',
    :'address' => :'address',
    :'address2' => :'address2',
    :'city' => :'city',
    :'state' => :'state',
    :'zip' => :'zip',
    :'email' => :'email',
    :'account_number' => :'accountNumber',
    :'office_code' => :'officeCode',
    :'non_us_province' => :'nonUsProvince',
    :'country_code' => :'countryCode',
    :'federal_efile_date' => :'federalEfileDate',
    :'postal_mail' => :'postalMail',
    :'state_efile_date' => :'stateEfileDate',
    :'recipient_edelivery_date' => :'recipientEdeliveryDate',
    :'tin_match' => :'tinMatch',
    :'no_tin' => :'noTin',
    :'address_verification' => :'addressVerification',
    :'state_and_local_withholding' => :'stateAndLocalWithholding',
    :'second_tin_notice' => :'secondTinNotice',
    :'federal_efile_status' => :'federalEfileStatus',
    :'state_efile_status' => :'stateEfileStatus',
    :'postal_mail_status' => :'postalMailStatus',
    :'tin_match_status' => :'tinMatchStatus',
    :'address_verification_status' => :'addressVerificationStatus',
    :'e_delivery_status' => :'eDeliveryStatus',
    :'validation_errors' => :'validationErrors',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 948

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



430
431
432
433
434
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 430

def self.openapi_all_of
  [
  :'Form1099Base'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 365

def self.openapi_nullable
  Set.new([
    :'tin_type',
    :'unique_form_id',
    :'recipient_date_of_birth',
    :'recipient_giin',
    :'recipient_foreign_tin',
    :'lob_code',
    :'income_code',
    :'gross_income',
    :'withholding_indicator',
    :'tax_country_code',
    :'exemption_code_chap3',
    :'exemption_code_chap4',
    :'tax_rate_chap3',
    :'withholding_allowance',
    :'federal_tax_withheld',
    :'tax_not_deposited_indicator',
    :'academic_indicator',
    :'tax_withheld_other_agents',
    :'amount_repaid',
    :'tax_paid_agent',
    :'chap3_status_code',
    :'chap4_status_code',
    :'primary_withholding_agent',
    :'intermediary_or_flow_through',
    :'id',
    :'issuer_id',
    :'issuer_reference_id',
    :'issuer_tin',
    :'tax_year',
    :'reference_id',
    :'tin',
    :'recipient_name',
    :'recipient_second_name',
    :'address',
    :'address2',
    :'city',
    :'state',
    :'zip',
    :'email',
    :'account_number',
    :'office_code',
    :'non_us_province',
    :'country_code',
    :'federal_efile_date',
    :'postal_mail',
    :'state_efile_date',
    :'recipient_edelivery_date',
    :'tin_match',
    :'no_tin',
    :'address_verification',
    :'state_and_local_withholding',
    :'second_tin_notice',
    :'federal_efile_status',
    :'state_efile_status',
    :'postal_mail_status',
    :'tin_match_status',
    :'address_verification_status',
    :'e_delivery_status',
    :'validation_errors',
  ])
end

.openapi_typesObject

Attribute type mapping.



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 297

def self.openapi_types
  {
    :'tin_type' => :'String',
    :'unique_form_id' => :'String',
    :'recipient_date_of_birth' => :'Date',
    :'recipient_giin' => :'String',
    :'recipient_foreign_tin' => :'String',
    :'lob_code' => :'String',
    :'income_code' => :'String',
    :'gross_income' => :'Float',
    :'withholding_indicator' => :'String',
    :'tax_country_code' => :'String',
    :'exemption_code_chap3' => :'String',
    :'exemption_code_chap4' => :'String',
    :'tax_rate_chap3' => :'String',
    :'withholding_allowance' => :'Float',
    :'federal_tax_withheld' => :'Float',
    :'tax_not_deposited_indicator' => :'Boolean',
    :'academic_indicator' => :'Boolean',
    :'tax_withheld_other_agents' => :'Float',
    :'amount_repaid' => :'Float',
    :'tax_paid_agent' => :'Float',
    :'chap3_status_code' => :'String',
    :'chap4_status_code' => :'String',
    :'primary_withholding_agent' => :'PrimaryWithholdingAgent',
    :'intermediary_or_flow_through' => :'IntermediaryOrFlowThrough',
    :'type' => :'String',
    :'id' => :'String',
    :'issuer_id' => :'String',
    :'issuer_reference_id' => :'String',
    :'issuer_tin' => :'String',
    :'tax_year' => :'Integer',
    :'reference_id' => :'String',
    :'tin' => :'String',
    :'recipient_name' => :'String',
    :'recipient_second_name' => :'String',
    :'address' => :'String',
    :'address2' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'zip' => :'String',
    :'email' => :'String',
    :'account_number' => :'String',
    :'office_code' => :'String',
    :'non_us_province' => :'String',
    :'country_code' => :'String',
    :'federal_efile_date' => :'Date',
    :'postal_mail' => :'Boolean',
    :'state_efile_date' => :'Date',
    :'recipient_edelivery_date' => :'Date',
    :'tin_match' => :'Boolean',
    :'no_tin' => :'Boolean',
    :'address_verification' => :'Boolean',
    :'state_and_local_withholding' => :'StateAndLocalWithholding',
    :'second_tin_notice' => :'Boolean',
    :'federal_efile_status' => :'Form1099StatusDetail',
    :'state_efile_status' => :'Array<StateEfileStatusDetail>',
    :'postal_mail_status' => :'Form1099StatusDetail',
    :'tin_match_status' => :'Form1099StatusDetail',
    :'address_verification_status' => :'Form1099StatusDetail',
    :'e_delivery_status' => :'Form1099StatusDetail',
    :'validation_errors' => :'Array<ValidationError>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 866

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tin_type == o.tin_type &&
      unique_form_id == o.unique_form_id &&
      recipient_date_of_birth == o.recipient_date_of_birth &&
      recipient_giin == o.recipient_giin &&
      recipient_foreign_tin == o.recipient_foreign_tin &&
      lob_code == o.lob_code &&
      income_code == o.income_code &&
      gross_income == o.gross_income &&
      withholding_indicator == o.withholding_indicator &&
      tax_country_code == o.tax_country_code &&
      exemption_code_chap3 == o.exemption_code_chap3 &&
      exemption_code_chap4 == o.exemption_code_chap4 &&
      tax_rate_chap3 == o.tax_rate_chap3 &&
      withholding_allowance == o.withholding_allowance &&
      federal_tax_withheld == o.federal_tax_withheld &&
      tax_not_deposited_indicator == o.tax_not_deposited_indicator &&
      academic_indicator == o.academic_indicator &&
      tax_withheld_other_agents == o.tax_withheld_other_agents &&
      amount_repaid == o.amount_repaid &&
      tax_paid_agent == o.tax_paid_agent &&
      chap3_status_code == o.chap3_status_code &&
      chap4_status_code == o.chap4_status_code &&
      primary_withholding_agent == o.primary_withholding_agent &&
      intermediary_or_flow_through == o.intermediary_or_flow_through &&
      type == o.type &&
      id == o.id &&
      issuer_id == o.issuer_id &&
      issuer_reference_id == o.issuer_reference_id &&
      issuer_tin == o.issuer_tin &&
      tax_year == o.tax_year &&
      reference_id == o.reference_id &&
      tin == o.tin &&
      recipient_name == o.recipient_name &&
      recipient_second_name == o.recipient_second_name &&
      address == o.address &&
      address2 == o.address2 &&
      city == o.city &&
      state == o.state &&
      zip == o.zip &&
      email == o.email &&
       == o. &&
      office_code == o.office_code &&
      non_us_province == o.non_us_province &&
      country_code == o.country_code &&
      federal_efile_date == o.federal_efile_date &&
      postal_mail == o.postal_mail &&
      state_efile_date == o.state_efile_date &&
      recipient_edelivery_date == o.recipient_edelivery_date &&
      tin_match == o.tin_match &&
      no_tin == o.no_tin &&
      address_verification == o.address_verification &&
      state_and_local_withholding == o.state_and_local_withholding &&
      second_tin_notice == o.second_tin_notice &&
      federal_efile_status == o.federal_efile_status &&
      state_efile_status == o.state_efile_status &&
      postal_mail_status == o.postal_mail_status &&
      tin_match_status == o.tin_match_status &&
      address_verification_status == o.address_verification_status &&
      e_delivery_status == o.e_delivery_status &&
      validation_errors == o.validation_errors &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 1043

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


935
936
937
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 935

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



941
942
943
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 941

def hash
  [tin_type, unique_form_id, recipient_date_of_birth, recipient_giin, recipient_foreign_tin, lob_code, income_code, gross_income, withholding_indicator, tax_country_code, exemption_code_chap3, exemption_code_chap4, tax_rate_chap3, withholding_allowance, federal_tax_withheld, tax_not_deposited_indicator, academic_indicator, tax_withheld_other_agents, amount_repaid, tax_paid_agent, chap3_status_code, chap4_status_code, primary_withholding_agent, intermediary_or_flow_through, type, id, issuer_id, issuer_reference_id, issuer_tin, tax_year, reference_id, tin, recipient_name, recipient_second_name, address, address2, city, state, zip, email, , office_code, non_us_province, country_code, federal_efile_date, postal_mail, state_efile_date, recipient_edelivery_date, tin_match, no_tin, address_verification, state_and_local_withholding, second_tin_notice, federal_efile_status, state_efile_status, postal_mail_status, tin_match_status, address_verification_status, e_delivery_status, validation_errors, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



726
727
728
729
730
731
732
733
734
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 726

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



1019
1020
1021
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 1019

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 1025

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



1013
1014
1015
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 1013

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
# File 'lib/avalara_sdk/models/A1099/V2/form1042_s.rb', line 738

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  tin_type_validator = EnumAttributeValidator.new('String', ["EIN", "SSN", "ITIN", "ATIN"])
  return false unless tin_type_validator.valid?(@tin_type)
  lob_code_validator = EnumAttributeValidator.new('String', ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12"])
  return false unless lob_code_validator.valid?(@lob_code)
  income_code_validator = EnumAttributeValidator.new('String', ["01", "02", "03", "04", "05", "22", "29", "30", "31", "33", "51", "54", "06", "07", "08", "34", "40", "52", "53", "56", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "23", "24", "25", "26", "27", "28", "32", "35", "36", "37", "38", "39", "41", "42", "43", "44", "50", "55", "57", "58"])
  return false unless income_code_validator.valid?(@income_code)
  withholding_indicator_validator = EnumAttributeValidator.new('String', ["3", "4"])
  return false unless withholding_indicator_validator.valid?(@withholding_indicator)
  exemption_code_chap3_validator = EnumAttributeValidator.new('String', ["00", "01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "22", "23", "24"])
  return false unless exemption_code_chap3_validator.valid?(@exemption_code_chap3)
  exemption_code_chap4_validator = EnumAttributeValidator.new('String', ["00", "13", "14", "15", "16", "17", "18", "19", "20", "21"])
  return false unless exemption_code_chap4_validator.valid?(@exemption_code_chap4)
  tax_rate_chap3_validator = EnumAttributeValidator.new('String', ["00.00", "02.00", "04.00", "04.90", "04.95", "05.00", "07.00", "08.00", "10.00", "12.00", "12.50", "14.00", "15.00", "17.50", "20.00", "21.00", "24.00", "25.00", "27.50", "28.00", "30.00", "37.00"])
  return false unless tax_rate_chap3_validator.valid?(@tax_rate_chap3)
  chap3_status_code_validator = EnumAttributeValidator.new('String', ["01", "02", "34", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "35", "36", "37", "38", "39"])
  return false unless chap3_status_code_validator.valid?(@chap3_status_code)
  chap4_status_code_validator = EnumAttributeValidator.new('String', ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", "47", "48", "49", "50"])
  return false unless chap4_status_code_validator.valid?(@chap4_status_code)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["1042-S", "1095-B", "1095-C", "1099-DIV", "1099-INT", "1099-K", "1099-MISC", "1099-NEC", "1099-R"])
  return false unless type_validator.valid?(@type)
  true
end