Class: AvalaraSdk::A1099::V2::Form1099Base

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/A1099/V2/form1099_base.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Form1099Base

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 262

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::Form1099Base` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::Form1099Base`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'issuer_id')
    self.issuer_id = attributes[:'issuer_id']
  end

  if attributes.key?(:'issuer_reference_id')
    self.issuer_reference_id = attributes[:'issuer_reference_id']
  end

  if attributes.key?(:'issuer_tin')
    self.issuer_tin = attributes[:'issuer_tin']
  end

  if attributes.key?(:'tax_year')
    self.tax_year = attributes[:'tax_year']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'tin')
    self.tin = attributes[:'tin']
  end

  if attributes.key?(:'recipient_name')
    self.recipient_name = attributes[:'recipient_name']
  end

  if attributes.key?(:'recipient_second_name')
    self.recipient_second_name = attributes[:'recipient_second_name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'address2')
    self.address2 = attributes[:'address2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'zip')
    self.zip = attributes[:'zip']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'non_us_province')
    self.non_us_province = attributes[:'non_us_province']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  else
    self.country_code = nil
  end

  if attributes.key?(:'federal_efile_date')
    self.federal_efile_date = attributes[:'federal_efile_date']
  end

  if attributes.key?(:'postal_mail')
    self.postal_mail = attributes[:'postal_mail']
  end

  if attributes.key?(:'state_efile_date')
    self.state_efile_date = attributes[:'state_efile_date']
  end

  if attributes.key?(:'recipient_edelivery_date')
    self.recipient_edelivery_date = attributes[:'recipient_edelivery_date']
  end

  if attributes.key?(:'tin_match')
    self.tin_match = attributes[:'tin_match']
  end

  if attributes.key?(:'address_verification')
    self.address_verification = attributes[:'address_verification']
  end

  if attributes.key?(:'state_and_local_withholding')
    self.state_and_local_withholding = attributes[:'state_and_local_withholding']
  end

  if attributes.key?(:'federal_efile_status')
    self.federal_efile_status = attributes[:'federal_efile_status']
  end

  if attributes.key?(:'state_efile_status')
    if (value = attributes[:'state_efile_status']).is_a?(Array)
      self.state_efile_status = value
    end
  end

  if attributes.key?(:'postal_mail_status')
    self.postal_mail_status = attributes[:'postal_mail_status']
  end

  if attributes.key?(:'tin_match_status')
    self.tin_match_status = attributes[:'tin_match_status']
  end

  if attributes.key?(:'address_verification_status')
    self.address_verification_status = attributes[:'address_verification_status']
  end

  if attributes.key?(:'e_delivery_status')
    self.e_delivery_status = attributes[:'e_delivery_status']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#addressObject

Address.



45
46
47
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 45

def address
  @address
end

#address2Object

Address line 2.



48
49
50
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 48

def address2
  @address2
end

#address_verificationObject

Boolean indicating that address verification should be scheduled for this form



84
85
86
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 84

def address_verification
  @address_verification
end

#address_verification_statusObject

Address verification status. Available values: - unknown: Address verification has not been checked - pending: Address verification is in progress - failed: Address verification failed - incomplete: Address verification is incomplete - unchanged: User declined address changes - verified: Address has been verified and accepted



102
103
104
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 102

def address_verification_status
  @address_verification_status
end

#cityObject

City.



51
52
53
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 51

def city
  @city
end

#country_codeObject

Two-letter IRS country code (e.g., 'US', 'CA'), as defined at https://www.irs.gov/e-file-providers/country-codes.



66
67
68
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 66

def country_code
  @country_code
end

#created_atObject

Date time when the record was created.



111
112
113
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 111

def created_at
  @created_at
end

#e_delivery_statusObject

EDelivery status. Available values: - unscheduled: E-delivery has not been scheduled - scheduled: E-delivery is scheduled to be sent - sent: E-delivery has been sent to recipient - bounced: E-delivery bounced back (invalid email) - refused: E-delivery was refused by recipient - bad_verify: E-delivery failed verification - accepted: E-delivery was accepted by recipient - bad_verify_limit: E-delivery failed verification limit reached - second_delivery: Second e-delivery attempt - undelivered: E-delivery is undelivered (temporary state allowing resend)



105
106
107
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 105

def e_delivery_status
  @e_delivery_status
end

#emailObject

Recipient's Contact email address.



60
61
62
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 60

def email
  @email
end

#federal_efile_dateObject

Date when federal e-filing should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



69
70
71
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 69

def federal_efile_date
  @federal_efile_date
end

#federal_efile_statusObject

Federal e-file status. Available values: - unscheduled: Form has not been scheduled for federal e-filing - scheduled: Form is scheduled for federal e-filing - airlock: Form is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - sent: Form has been sent to the IRS - accepted: Form was accepted by the IRS - corrected_scheduled: Correction is scheduled to be sent - corrected_airlock: Correction is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - corrected: A correction has been sent to the IRS - corrected_accepted: Correction was accepted by the IRS - rejected: Form was rejected by the IRS - corrected_rejected: Correction was rejected by the IRS - held: Form is held and will not be submitted to IRS (used for certain forms submitted only to states)



90
91
92
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 90

def federal_efile_status
  @federal_efile_status
end

#idObject

Form ID. Unique identifier set when the record is created.



18
19
20
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 18

def id
  @id
end

#issuer_idObject

Issuer ID - only required when creating forms



21
22
23
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 21

def issuer_id
  @issuer_id
end

#issuer_reference_idObject

Issuer Reference ID - only required when creating forms via $bulk-upsert



24
25
26
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 24

def issuer_reference_id
  @issuer_reference_id
end

#issuer_tinObject

Issuer TIN - readonly



27
28
29
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 27

def issuer_tin
  @issuer_tin
end

#non_us_provinceObject

Province or region for non-US/CA addresses.



63
64
65
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 63

def non_us_province
  @non_us_province
end

#postal_mailObject

Boolean indicating that postal mailing to the recipient should be scheduled for this form



72
73
74
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 72

def postal_mail
  @postal_mail
end

#postal_mail_statusObject

Postal mail to recipient status. Available values: - unscheduled: Postal mail has not been scheduled - pending: Postal mail is pending to be sent - sent: Postal mail has been sent - delivered: Postal mail has been delivered



96
97
98
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 96

def postal_mail_status
  @postal_mail_status
end

#recipient_edelivery_dateObject

Date when recipient e-delivery should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



78
79
80
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 78

def recipient_edelivery_date
  @recipient_edelivery_date
end

#recipient_nameObject

DEPRECATED: Use businessName for businesses; use firstName, middleName, lastName, and suffixName for individuals.



39
40
41
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 39

def recipient_name
  @recipient_name
end

#recipient_second_nameObject

DEPRECATED: Use businessName2 instead.



42
43
44
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 42

def recipient_second_name
  @recipient_second_name
end

#reference_idObject

Internal reference ID. Never shown to any agency or recipient.



33
34
35
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 33

def reference_id
  @reference_id
end

#stateObject

Two-letter US state or Canadian province code (required for US/CA addresses).



54
55
56
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 54

def state
  @state
end

#state_and_local_withholdingObject

State and local withholding information



87
88
89
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 87

def state_and_local_withholding
  @state_and_local_withholding
end

#state_efile_dateObject

Date when state e-filing should be scheduled. Must be on or after federalEfileDate. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



75
76
77
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 75

def state_efile_date
  @state_efile_date
end

#state_efile_statusObject

State e-file status. Available values: - unscheduled: Form has not been scheduled for state e-filing - scheduled: Form is scheduled for state e-filing - airlocked: Form is in process of being uploaded to the state - sent: Form has been sent to the state - rejected: Form was rejected by the state - accepted: Form was accepted by the state - corrected_scheduled: Correction is scheduled to be sent - corrected_airlocked: Correction is in process of being uploaded to the state - corrected_sent: Correction has been sent to the state - corrected_rejected: Correction was rejected by the state - corrected_accepted: Correction was accepted by the state



93
94
95
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 93

def state_efile_status
  @state_efile_status
end

#tax_yearObject

Tax Year - only required when creating forms via $bulk-upsert



30
31
32
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 30

def tax_year
  @tax_year
end

#tinObject

Recipient's Federal Tax Identification Number (TIN).



36
37
38
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 36

def tin
  @tin
end

#tin_matchObject

Boolean indicating that TIN Matching should be scheduled for this form



81
82
83
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 81

def tin_match
  @tin_match
end

#tin_match_statusObject

TIN Match status. Available values: - none: TIN matching has not been performed - pending: TIN matching request is pending - matched: Name/TIN combination matches IRS records - unknown: TIN is missing, invalid, or request contains errors - rejected: Name/TIN combination does not match IRS records or TIN not currently issued



99
100
101
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 99

def tin_match_status
  @tin_match_status
end

#typeObject

Form type.



15
16
17
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 15

def type
  @type
end

#updated_atObject

Date time when the record was last updated.



114
115
116
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 114

def updated_at
  @updated_at
end

#validation_errorsObject

Validation errors



108
109
110
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 108

def validation_errors
  @validation_errors
end

#zipObject

ZIP/postal code.



57
58
59
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 57

def zip
  @zip
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 536

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::A1099::V2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



179
180
181
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 179

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 139

def self.attribute_map
  {
    :'type' => :'type',
    :'id' => :'id',
    :'issuer_id' => :'issuerId',
    :'issuer_reference_id' => :'issuerReferenceId',
    :'issuer_tin' => :'issuerTin',
    :'tax_year' => :'taxYear',
    :'reference_id' => :'referenceId',
    :'tin' => :'tin',
    :'recipient_name' => :'recipientName',
    :'recipient_second_name' => :'recipientSecondName',
    :'address' => :'address',
    :'address2' => :'address2',
    :'city' => :'city',
    :'state' => :'state',
    :'zip' => :'zip',
    :'email' => :'email',
    :'non_us_province' => :'nonUsProvince',
    :'country_code' => :'countryCode',
    :'federal_efile_date' => :'federalEfileDate',
    :'postal_mail' => :'postalMail',
    :'state_efile_date' => :'stateEfileDate',
    :'recipient_edelivery_date' => :'recipientEdeliveryDate',
    :'tin_match' => :'tinMatch',
    :'address_verification' => :'addressVerification',
    :'state_and_local_withholding' => :'stateAndLocalWithholding',
    :'federal_efile_status' => :'federalEfileStatus',
    :'state_efile_status' => :'stateEfileStatus',
    :'postal_mail_status' => :'postalMailStatus',
    :'tin_match_status' => :'tinMatchStatus',
    :'address_verification_status' => :'addressVerificationStatus',
    :'e_delivery_status' => :'eDeliveryStatus',
    :'validation_errors' => :'validationErrors',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 512

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 224

def self.openapi_nullable
  Set.new([
    :'id',
    :'issuer_id',
    :'issuer_reference_id',
    :'issuer_tin',
    :'tax_year',
    :'reference_id',
    :'tin',
    :'recipient_name',
    :'recipient_second_name',
    :'address',
    :'address2',
    :'city',
    :'state',
    :'zip',
    :'email',
    :'non_us_province',
    :'country_code',
    :'federal_efile_date',
    :'postal_mail',
    :'state_efile_date',
    :'recipient_edelivery_date',
    :'tin_match',
    :'address_verification',
    :'state_and_local_withholding',
    :'federal_efile_status',
    :'state_efile_status',
    :'postal_mail_status',
    :'tin_match_status',
    :'address_verification_status',
    :'e_delivery_status',
    :'validation_errors',
  ])
end

.openapi_typesObject

Attribute type mapping.



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 184

def self.openapi_types
  {
    :'type' => :'String',
    :'id' => :'String',
    :'issuer_id' => :'String',
    :'issuer_reference_id' => :'String',
    :'issuer_tin' => :'String',
    :'tax_year' => :'Integer',
    :'reference_id' => :'String',
    :'tin' => :'String',
    :'recipient_name' => :'String',
    :'recipient_second_name' => :'String',
    :'address' => :'String',
    :'address2' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'zip' => :'String',
    :'email' => :'String',
    :'non_us_province' => :'String',
    :'country_code' => :'String',
    :'federal_efile_date' => :'Date',
    :'postal_mail' => :'Boolean',
    :'state_efile_date' => :'Date',
    :'recipient_edelivery_date' => :'Date',
    :'tin_match' => :'Boolean',
    :'address_verification' => :'Boolean',
    :'state_and_local_withholding' => :'StateAndLocalWithholding',
    :'federal_efile_status' => :'Form1099StatusDetail',
    :'state_efile_status' => :'Array<StateEfileStatusDetail>',
    :'postal_mail_status' => :'Form1099StatusDetail',
    :'tin_match_status' => :'Form1099StatusDetail',
    :'address_verification_status' => :'Form1099StatusDetail',
    :'e_delivery_status' => :'Form1099StatusDetail',
    :'validation_errors' => :'Array<ValidationError>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 458

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      id == o.id &&
      issuer_id == o.issuer_id &&
      issuer_reference_id == o.issuer_reference_id &&
      issuer_tin == o.issuer_tin &&
      tax_year == o.tax_year &&
      reference_id == o.reference_id &&
      tin == o.tin &&
      recipient_name == o.recipient_name &&
      recipient_second_name == o.recipient_second_name &&
      address == o.address &&
      address2 == o.address2 &&
      city == o.city &&
      state == o.state &&
      zip == o.zip &&
      email == o.email &&
      non_us_province == o.non_us_province &&
      country_code == o.country_code &&
      federal_efile_date == o.federal_efile_date &&
      postal_mail == o.postal_mail &&
      state_efile_date == o.state_efile_date &&
      recipient_edelivery_date == o.recipient_edelivery_date &&
      tin_match == o.tin_match &&
      address_verification == o.address_verification &&
      state_and_local_withholding == o.state_and_local_withholding &&
      federal_efile_status == o.federal_efile_status &&
      state_efile_status == o.state_efile_status &&
      postal_mail_status == o.postal_mail_status &&
      tin_match_status == o.tin_match_status &&
      address_verification_status == o.address_verification_status &&
      e_delivery_status == o.e_delivery_status &&
      validation_errors == o.validation_errors &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



607
608
609
610
611
612
613
614
615
616
617
618
619
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 607

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


499
500
501
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 499

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



505
506
507
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 505

def hash
  [type, id, issuer_id, issuer_reference_id, issuer_tin, tax_year, reference_id, tin, recipient_name, recipient_second_name, address, address2, city, state, zip, email, non_us_province, country_code, federal_efile_date, postal_mail, state_efile_date, recipient_edelivery_date, tin_match, address_verification, state_and_local_withholding, federal_efile_status, state_efile_status, postal_mail_status, tin_match_status, address_verification_status, e_delivery_status, validation_errors, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



426
427
428
429
430
431
432
433
434
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 426

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



583
584
585
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 583

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 589

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



577
578
579
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 577

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



438
439
440
441
442
443
444
# File 'lib/avalara_sdk/models/A1099/V2/form1099_base.rb', line 438

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["1042-S", "1095-B", "1095-C", "1099-DIV", "1099-INT", "1099-K", "1099-MISC", "1099-NEC", "1099-R", "W-2"])
  return false unless type_validator.valid?(@type)
  true
end