Class: AvalaraSdk::A1099::V2::Form1099K

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/A1099/V2/form1099_k.rb

Overview

Form 1099-K: Payment Card and Third Party Network Transactions

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Form1099K

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 456

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::Form1099K` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::Form1099K`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'filer_type')
    self.filer_type = attributes[:'filer_type']
  else
    self.filer_type = nil
  end

  if attributes.key?(:'payment_type')
    self.payment_type = attributes[:'payment_type']
  else
    self.payment_type = nil
  end

  if attributes.key?(:'payment_settlement_entity_name_phone_number')
    self.payment_settlement_entity_name_phone_number = attributes[:'payment_settlement_entity_name_phone_number']
  end

  if attributes.key?(:'gross_amount_payment_card')
    self.gross_amount_payment_card = attributes[:'gross_amount_payment_card']
  else
    self.gross_amount_payment_card = nil
  end

  if attributes.key?(:'card_not_present_transactions')
    self.card_not_present_transactions = attributes[:'card_not_present_transactions']
  end

  if attributes.key?(:'merchant_category_code')
    self.merchant_category_code = attributes[:'merchant_category_code']
  end

  if attributes.key?(:'payment_transaction_number')
    self.payment_transaction_number = attributes[:'payment_transaction_number']
  else
    self.payment_transaction_number = nil
  end

  if attributes.key?(:'federal_income_tax_withheld')
    self.federal_income_tax_withheld = attributes[:'federal_income_tax_withheld']
  end

  if attributes.key?(:'january')
    self.january = attributes[:'january']
  end

  if attributes.key?(:'february')
    self.february = attributes[:'february']
  end

  if attributes.key?(:'march')
    self.march = attributes[:'march']
  end

  if attributes.key?(:'april')
    self.april = attributes[:'april']
  end

  if attributes.key?(:'may')
    self.may = attributes[:'may']
  end

  if attributes.key?(:'june')
    self.june = attributes[:'june']
  end

  if attributes.key?(:'july')
    self.july = attributes[:'july']
  end

  if attributes.key?(:'august')
    self.august = attributes[:'august']
  end

  if attributes.key?(:'september')
    self.september = attributes[:'september']
  end

  if attributes.key?(:'october')
    self.october = attributes[:'october']
  end

  if attributes.key?(:'november')
    self.november = attributes[:'november']
  end

  if attributes.key?(:'december')
    self.december = attributes[:'december']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'issuer_id')
    self.issuer_id = attributes[:'issuer_id']
  end

  if attributes.key?(:'issuer_reference_id')
    self.issuer_reference_id = attributes[:'issuer_reference_id']
  end

  if attributes.key?(:'issuer_tin')
    self.issuer_tin = attributes[:'issuer_tin']
  end

  if attributes.key?(:'tax_year')
    self.tax_year = attributes[:'tax_year']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'tin')
    self.tin = attributes[:'tin']
  end

  if attributes.key?(:'recipient_name')
    self.recipient_name = attributes[:'recipient_name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'address2')
    self.address2 = attributes[:'address2']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'zip')
    self.zip = attributes[:'zip']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'non_us_province')
    self.non_us_province = attributes[:'non_us_province']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  else
    self.country_code = nil
  end

  if attributes.key?(:'federal_efile_date')
    self.federal_efile_date = attributes[:'federal_efile_date']
  end

  if attributes.key?(:'postal_mail')
    self.postal_mail = attributes[:'postal_mail']
  end

  if attributes.key?(:'state_efile_date')
    self.state_efile_date = attributes[:'state_efile_date']
  end

  if attributes.key?(:'recipient_edelivery_date')
    self.recipient_edelivery_date = attributes[:'recipient_edelivery_date']
  end

  if attributes.key?(:'tin_match')
    self.tin_match = attributes[:'tin_match']
  end

  if attributes.key?(:'address_verification')
    self.address_verification = attributes[:'address_verification']
  end

  if attributes.key?(:'state_and_local_withholding')
    self.state_and_local_withholding = attributes[:'state_and_local_withholding']
  end

  if attributes.key?(:'federal_efile_status')
    self.federal_efile_status = attributes[:'federal_efile_status']
  end

  if attributes.key?(:'state_efile_status')
    if (value = attributes[:'state_efile_status']).is_a?(Array)
      self.state_efile_status = value
    end
  end

  if attributes.key?(:'postal_mail_status')
    self.postal_mail_status = attributes[:'postal_mail_status']
  end

  if attributes.key?(:'tin_match_status')
    self.tin_match_status = attributes[:'tin_match_status']
  end

  if attributes.key?(:'address_verification_status')
    self.address_verification_status = attributes[:'address_verification_status']
  end

  if attributes.key?(:'e_delivery_status')
    self.e_delivery_status = attributes[:'e_delivery_status']
  end

  if attributes.key?(:'validation_errors')
    if (value = attributes[:'validation_errors']).is_a?(Array)
      self.validation_errors = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'tin_type')
    self.tin_type = attributes[:'tin_type']
  end

  if attributes.key?(:'business_name')
    self.business_name = attributes[:'business_name']
  end

  if attributes.key?(:'business_name2')
    self.business_name2 = attributes[:'business_name2']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'suffix_name')
    self.suffix_name = attributes[:'suffix_name']
  end

  if attributes.key?(:'recipient_second_name')
    self.recipient_second_name = attributes[:'recipient_second_name']
  end

  if attributes.key?(:'account_number')
    self. = attributes[:'account_number']
  end

  if attributes.key?(:'office_code')
    self.office_code = attributes[:'office_code']
  end

  if attributes.key?(:'no_tin')
    self.no_tin = attributes[:'no_tin']
  end

  if attributes.key?(:'second_tin_notice')
    self.second_tin_notice = attributes[:'second_tin_notice']
  end
end

Instance Attribute Details

#account_numberObject

Account number



199
200
201
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 199

def 
  @account_number
end

#addressObject

Address.



103
104
105
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 103

def address
  @address
end

#address2Object

Address line 2.



106
107
108
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 106

def address2
  @address2
end

#address_verificationObject

Boolean indicating that address verification should be scheduled for this form



142
143
144
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 142

def address_verification
  @address_verification
end

#address_verification_statusObject

Address verification status. Available values: - unknown: Address verification has not been checked - pending: Address verification is in progress - failed: Address verification failed - incomplete: Address verification is incomplete - unchanged: User declined address changes - verified: Address has been verified and accepted



160
161
162
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 160

def address_verification_status
  @address_verification_status
end

#aprilObject

April gross payments



49
50
51
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 49

def april
  @april
end

#augustObject

August gross payments



61
62
63
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 61

def august
  @august
end

#business_nameObject

Business name. Required when the recipient of the form is a business; should only be used for businesses.



178
179
180
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 178

def business_name
  @business_name
end

#business_name2Object

Business name line 2. Should only be used for businesses.



181
182
183
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 181

def business_name2
  @business_name2
end

#card_not_present_transactionsObject

Card not present transactions



28
29
30
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 28

def card_not_present_transactions
  @card_not_present_transactions
end

#cityObject

City.



109
110
111
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 109

def city
  @city
end

#country_codeObject

Two-letter IRS country code (e.g., 'US', 'CA'), as defined at https://www.irs.gov/e-file-providers/country-codes.



124
125
126
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 124

def country_code
  @country_code
end

#created_atObject

Date time when the record was created.



169
170
171
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 169

def created_at
  @created_at
end

#decemberObject

December gross payments



73
74
75
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 73

def december
  @december
end

#e_delivery_statusObject

EDelivery status. Available values: - unscheduled: E-delivery has not been scheduled - scheduled: E-delivery is scheduled to be sent - sent: E-delivery has been sent to recipient - bounced: E-delivery bounced back (invalid email) - refused: E-delivery was refused by recipient - bad_verify: E-delivery failed verification - accepted: E-delivery was accepted by recipient - bad_verify_limit: E-delivery failed verification limit reached - second_delivery: Second e-delivery attempt - undelivered: E-delivery is undelivered (temporary state allowing resend)



163
164
165
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 163

def e_delivery_status
  @e_delivery_status
end

#emailObject

Recipient's Contact email address.



118
119
120
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 118

def email
  @email
end

#februaryObject

February gross payments



43
44
45
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 43

def february
  @february
end

#federal_efile_dateObject

Date when federal e-filing should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



127
128
129
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 127

def federal_efile_date
  @federal_efile_date
end

#federal_efile_statusObject

Federal e-file status. Available values: - unscheduled: Form has not been scheduled for federal e-filing - scheduled: Form is scheduled for federal e-filing - airlock: Form is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - sent: Form has been sent to the IRS - accepted: Form was accepted by the IRS - corrected_scheduled: Correction is scheduled to be sent - corrected_airlock: Correction is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - corrected: A correction has been sent to the IRS - corrected_accepted: Correction was accepted by the IRS - rejected: Form was rejected by the IRS - corrected_rejected: Correction was rejected by the IRS - held: Form is held and will not be submitted to IRS (used for certain forms submitted only to states)



148
149
150
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 148

def federal_efile_status
  @federal_efile_status
end

#federal_income_tax_withheldObject

Federal income tax withheld



37
38
39
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 37

def federal_income_tax_withheld
  @federal_income_tax_withheld
end

#filer_typeObject

Filer type for tax reporting purposes. Available values: - PSE: Payment Settlement Entity - EPF: Electronic Payment Facilitator or other third party



16
17
18
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 16

def filer_type
  @filer_type
end

#first_nameObject

First name. Required when the recipient of the form is an individual; should only be used for individuals.



184
185
186
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 184

def first_name
  @first_name
end

#gross_amount_payment_cardObject

Gross amount of payment card/third party network transactions. This value must equal the total of all monthly payment amounts (January through December).



25
26
27
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 25

def gross_amount_payment_card
  @gross_amount_payment_card
end

#idObject

Form ID. Unique identifier set when the record is created.



79
80
81
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 79

def id
  @id
end

#issuer_idObject

Issuer ID - only required when creating forms



82
83
84
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 82

def issuer_id
  @issuer_id
end

#issuer_reference_idObject

Issuer Reference ID - only required when creating forms via $bulk-upsert



85
86
87
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 85

def issuer_reference_id
  @issuer_reference_id
end

#issuer_tinObject

Issuer TIN - readonly



88
89
90
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 88

def issuer_tin
  @issuer_tin
end

#januaryObject

January gross payments



40
41
42
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 40

def january
  @january
end

#julyObject

July gross payments



58
59
60
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 58

def july
  @july
end

#juneObject

June gross payments



55
56
57
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 55

def june
  @june
end

#last_nameObject

Last name. Required when the recipient of the form is an individual; should only be used for individuals.



190
191
192
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 190

def last_name
  @last_name
end

#marchObject

March gross payments



46
47
48
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 46

def march
  @march
end

#mayObject

May gross payments



52
53
54
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 52

def may
  @may
end

#merchant_category_codeObject

Merchant category code (4 numbers)



31
32
33
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 31

def merchant_category_code
  @merchant_category_code
end

#middle_nameObject

Middle name. Should only be used for individuals.



187
188
189
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 187

def middle_name
  @middle_name
end

#no_tinObject

No TIN indicator



205
206
207
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 205

def no_tin
  @no_tin
end

#non_us_provinceObject

Province or region for non-US/CA addresses.



121
122
123
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 121

def non_us_province
  @non_us_province
end

#novemberObject

November gross payments



70
71
72
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 70

def november
  @november
end

#octoberObject

October gross payments



67
68
69
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 67

def october
  @october
end

#office_codeObject

Office code



202
203
204
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 202

def office_code
  @office_code
end

#payment_settlement_entity_name_phone_numberObject

Payment settlement entity name and phone number, if different from Filer's



22
23
24
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 22

def payment_settlement_entity_name_phone_number
  @payment_settlement_entity_name_phone_number
end

#payment_transaction_numberObject

Number of payment transactions



34
35
36
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 34

def payment_transaction_number
  @payment_transaction_number
end

#payment_typeObject

Payment type for transaction classification. Available values: - PaymentCard: Payment card transactions - ThirdPartyNetwork: Third party network transactions



19
20
21
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 19

def payment_type
  @payment_type
end

#postal_mailObject

Boolean indicating that postal mailing to the recipient should be scheduled for this form



130
131
132
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 130

def postal_mail
  @postal_mail
end

#postal_mail_statusObject

Postal mail to recipient status. Available values: - unscheduled: Postal mail has not been scheduled - pending: Postal mail is pending to be sent - sent: Postal mail has been sent - delivered: Postal mail has been delivered



154
155
156
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 154

def postal_mail_status
  @postal_mail_status
end

#recipient_edelivery_dateObject

Date when recipient e-delivery should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



136
137
138
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 136

def recipient_edelivery_date
  @recipient_edelivery_date
end

#recipient_nameObject

DEPRECATED: Use businessName for businesses; use firstName, middleName, lastName, and suffixName for individuals.



100
101
102
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 100

def recipient_name
  @recipient_name
end

#recipient_second_nameObject

DEPRECATED: Use businessName2 instead.



196
197
198
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 196

def recipient_second_name
  @recipient_second_name
end

#reference_idObject

Internal reference ID. Never shown to any agency or recipient.



94
95
96
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 94

def reference_id
  @reference_id
end

#second_tin_noticeObject

Second TIN notice



208
209
210
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 208

def second_tin_notice
  @second_tin_notice
end

#septemberObject

September gross payments



64
65
66
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 64

def september
  @september
end

#stateObject

Two-letter US state or Canadian province code (required for US/CA addresses).



112
113
114
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 112

def state
  @state
end

#state_and_local_withholdingObject

State and local withholding information



145
146
147
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 145

def state_and_local_withholding
  @state_and_local_withholding
end

#state_efile_dateObject

Date when state e-filing should be scheduled. Must be on or after federalEfileDate. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see https://www.track1099.com/info/IRS_info. Set to null to leave unscheduled.



133
134
135
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 133

def state_efile_date
  @state_efile_date
end

#state_efile_statusObject

State e-file status. Available values: - unscheduled: Form has not been scheduled for state e-filing - scheduled: Form is scheduled for state e-filing - airlocked: Form is in process of being uploaded to the state - sent: Form has been sent to the state - rejected: Form was rejected by the state - accepted: Form was accepted by the state - corrected_scheduled: Correction is scheduled to be sent - corrected_airlocked: Correction is in process of being uploaded to the state - corrected_sent: Correction has been sent to the state - corrected_rejected: Correction was rejected by the state - corrected_accepted: Correction was accepted by the state



151
152
153
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 151

def state_efile_status
  @state_efile_status
end

#suffix_nameObject

Suffix name. Should only be used for individuals.



193
194
195
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 193

def suffix_name
  @suffix_name
end

#tax_yearObject

Tax Year - only required when creating forms via $bulk-upsert



91
92
93
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 91

def tax_year
  @tax_year
end

#tinObject

Recipient's Federal Tax Identification Number (TIN).



97
98
99
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 97

def tin
  @tin
end

#tin_matchObject

Boolean indicating that TIN Matching should be scheduled for this form



139
140
141
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 139

def tin_match
  @tin_match
end

#tin_match_statusObject

TIN Match status. Available values: - none: TIN matching has not been performed - pending: TIN matching request is pending - matched: Name/TIN combination matches IRS records - unknown: TIN is missing, invalid, or request contains errors - rejected: Name/TIN combination does not match IRS records or TIN not currently issued



157
158
159
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 157

def tin_match_status
  @tin_match_status
end

#tin_typeObject

Recipient classification. The platform is transitioning from tax identifier classifications to recipient entity classifications. New values represent recipient entity types and should be preferred. Deprecated values represent identifier formats and remain supported for backward compatibility only. Available values: - INDIVIDUAL: Recipient is an individual - BUSINESS: Recipient is a business - UNKNOWN: Recipient classification is unknown - EIN: (Deprecated - use BUSINESS) Employer Identification Number - SSN: (Deprecated - use INDIVIDUAL) Social Security Number - ITIN: (Deprecated - use INDIVIDUAL) Individual Taxpayer Identification Number - ATIN: (Deprecated - use INDIVIDUAL) Adoption Taxpayer Identification Number



175
176
177
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 175

def tin_type
  @tin_type
end

#typeObject

Form type.



76
77
78
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 76

def type
  @type
end

#updated_atObject

Date time when the record was last updated.



172
173
174
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 172

def updated_at
  @updated_at
end

#validation_errorsObject

Validation errors



166
167
168
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 166

def validation_errors
  @validation_errors
end

#zipObject

ZIP/postal code.



115
116
117
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 115

def zip
  @zip
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 929

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::A1099::V2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



304
305
306
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 304

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 233

def self.attribute_map
  {
    :'filer_type' => :'filerType',
    :'payment_type' => :'paymentType',
    :'payment_settlement_entity_name_phone_number' => :'paymentSettlementEntityNamePhoneNumber',
    :'gross_amount_payment_card' => :'grossAmountPaymentCard',
    :'card_not_present_transactions' => :'cardNotPresentTransactions',
    :'merchant_category_code' => :'merchantCategoryCode',
    :'payment_transaction_number' => :'paymentTransactionNumber',
    :'federal_income_tax_withheld' => :'federalIncomeTaxWithheld',
    :'january' => :'january',
    :'february' => :'february',
    :'march' => :'march',
    :'april' => :'april',
    :'may' => :'may',
    :'june' => :'june',
    :'july' => :'july',
    :'august' => :'august',
    :'september' => :'september',
    :'october' => :'october',
    :'november' => :'november',
    :'december' => :'december',
    :'type' => :'type',
    :'id' => :'id',
    :'issuer_id' => :'issuerId',
    :'issuer_reference_id' => :'issuerReferenceId',
    :'issuer_tin' => :'issuerTin',
    :'tax_year' => :'taxYear',
    :'reference_id' => :'referenceId',
    :'tin' => :'tin',
    :'recipient_name' => :'recipientName',
    :'address' => :'address',
    :'address2' => :'address2',
    :'city' => :'city',
    :'state' => :'state',
    :'zip' => :'zip',
    :'email' => :'email',
    :'non_us_province' => :'nonUsProvince',
    :'country_code' => :'countryCode',
    :'federal_efile_date' => :'federalEfileDate',
    :'postal_mail' => :'postalMail',
    :'state_efile_date' => :'stateEfileDate',
    :'recipient_edelivery_date' => :'recipientEdeliveryDate',
    :'tin_match' => :'tinMatch',
    :'address_verification' => :'addressVerification',
    :'state_and_local_withholding' => :'stateAndLocalWithholding',
    :'federal_efile_status' => :'federalEfileStatus',
    :'state_efile_status' => :'stateEfileStatus',
    :'postal_mail_status' => :'postalMailStatus',
    :'tin_match_status' => :'tinMatchStatus',
    :'address_verification_status' => :'addressVerificationStatus',
    :'e_delivery_status' => :'eDeliveryStatus',
    :'validation_errors' => :'validationErrors',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'tin_type' => :'tinType',
    :'business_name' => :'businessName',
    :'business_name2' => :'businessName2',
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'last_name' => :'lastName',
    :'suffix_name' => :'suffixName',
    :'recipient_second_name' => :'recipientSecondName',
    :'account_number' => :'accountNumber',
    :'office_code' => :'officeCode',
    :'no_tin' => :'noTin',
    :'second_tin_notice' => :'secondTinNotice'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 905

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



448
449
450
451
452
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 448

def self.openapi_all_of
  [
  :'IrisFormBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 380

def self.openapi_nullable
  Set.new([
    :'filer_type',
    :'payment_type',
    :'payment_settlement_entity_name_phone_number',
    :'gross_amount_payment_card',
    :'card_not_present_transactions',
    :'merchant_category_code',
    :'payment_transaction_number',
    :'federal_income_tax_withheld',
    :'january',
    :'february',
    :'march',
    :'april',
    :'may',
    :'june',
    :'july',
    :'august',
    :'september',
    :'october',
    :'november',
    :'december',
    :'id',
    :'issuer_id',
    :'issuer_reference_id',
    :'issuer_tin',
    :'tax_year',
    :'reference_id',
    :'tin',
    :'recipient_name',
    :'address',
    :'address2',
    :'city',
    :'state',
    :'zip',
    :'email',
    :'non_us_province',
    :'country_code',
    :'federal_efile_date',
    :'postal_mail',
    :'state_efile_date',
    :'recipient_edelivery_date',
    :'tin_match',
    :'address_verification',
    :'state_and_local_withholding',
    :'federal_efile_status',
    :'state_efile_status',
    :'postal_mail_status',
    :'tin_match_status',
    :'address_verification_status',
    :'e_delivery_status',
    :'validation_errors',
    :'tin_type',
    :'business_name',
    :'business_name2',
    :'first_name',
    :'middle_name',
    :'last_name',
    :'suffix_name',
    :'recipient_second_name',
    :'account_number',
    :'office_code',
    :'no_tin',
    :'second_tin_notice'
  ])
end

.openapi_typesObject

Attribute type mapping.



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 309

def self.openapi_types
  {
    :'filer_type' => :'String',
    :'payment_type' => :'String',
    :'payment_settlement_entity_name_phone_number' => :'String',
    :'gross_amount_payment_card' => :'Float',
    :'card_not_present_transactions' => :'Float',
    :'merchant_category_code' => :'String',
    :'payment_transaction_number' => :'Float',
    :'federal_income_tax_withheld' => :'Float',
    :'january' => :'Float',
    :'february' => :'Float',
    :'march' => :'Float',
    :'april' => :'Float',
    :'may' => :'Float',
    :'june' => :'Float',
    :'july' => :'Float',
    :'august' => :'Float',
    :'september' => :'Float',
    :'october' => :'Float',
    :'november' => :'Float',
    :'december' => :'Float',
    :'type' => :'String',
    :'id' => :'String',
    :'issuer_id' => :'String',
    :'issuer_reference_id' => :'String',
    :'issuer_tin' => :'String',
    :'tax_year' => :'Integer',
    :'reference_id' => :'String',
    :'tin' => :'String',
    :'recipient_name' => :'String',
    :'address' => :'String',
    :'address2' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'zip' => :'String',
    :'email' => :'String',
    :'non_us_province' => :'String',
    :'country_code' => :'String',
    :'federal_efile_date' => :'Date',
    :'postal_mail' => :'Boolean',
    :'state_efile_date' => :'Date',
    :'recipient_edelivery_date' => :'Date',
    :'tin_match' => :'Boolean',
    :'address_verification' => :'Boolean',
    :'state_and_local_withholding' => :'StateAndLocalWithholding',
    :'federal_efile_status' => :'Form1099StatusDetail',
    :'state_efile_status' => :'Array<StateEfileStatusDetail>',
    :'postal_mail_status' => :'Form1099StatusDetail',
    :'tin_match_status' => :'Form1099StatusDetail',
    :'address_verification_status' => :'Form1099StatusDetail',
    :'e_delivery_status' => :'Form1099StatusDetail',
    :'validation_errors' => :'Array<ValidationError>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'tin_type' => :'String',
    :'business_name' => :'String',
    :'business_name2' => :'String',
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'suffix_name' => :'String',
    :'recipient_second_name' => :'String',
    :'account_number' => :'String',
    :'office_code' => :'String',
    :'no_tin' => :'Boolean',
    :'second_tin_notice' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 820

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      filer_type == o.filer_type &&
      payment_type == o.payment_type &&
      payment_settlement_entity_name_phone_number == o.payment_settlement_entity_name_phone_number &&
      gross_amount_payment_card == o.gross_amount_payment_card &&
      card_not_present_transactions == o.card_not_present_transactions &&
      merchant_category_code == o.merchant_category_code &&
      payment_transaction_number == o.payment_transaction_number &&
      federal_income_tax_withheld == o.federal_income_tax_withheld &&
      january == o.january &&
      february == o.february &&
      march == o.march &&
      april == o.april &&
      may == o.may &&
      june == o.june &&
      july == o.july &&
      august == o.august &&
      september == o.september &&
      october == o.october &&
      november == o.november &&
      december == o.december &&
      type == o.type &&
      id == o.id &&
      issuer_id == o.issuer_id &&
      issuer_reference_id == o.issuer_reference_id &&
      issuer_tin == o.issuer_tin &&
      tax_year == o.tax_year &&
      reference_id == o.reference_id &&
      tin == o.tin &&
      recipient_name == o.recipient_name &&
      address == o.address &&
      address2 == o.address2 &&
      city == o.city &&
      state == o.state &&
      zip == o.zip &&
      email == o.email &&
      non_us_province == o.non_us_province &&
      country_code == o.country_code &&
      federal_efile_date == o.federal_efile_date &&
      postal_mail == o.postal_mail &&
      state_efile_date == o.state_efile_date &&
      recipient_edelivery_date == o.recipient_edelivery_date &&
      tin_match == o.tin_match &&
      address_verification == o.address_verification &&
      state_and_local_withholding == o.state_and_local_withholding &&
      federal_efile_status == o.federal_efile_status &&
      state_efile_status == o.state_efile_status &&
      postal_mail_status == o.postal_mail_status &&
      tin_match_status == o.tin_match_status &&
      address_verification_status == o.address_verification_status &&
      e_delivery_status == o.e_delivery_status &&
      validation_errors == o.validation_errors &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      tin_type == o.tin_type &&
      business_name == o.business_name &&
      business_name2 == o.business_name2 &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      suffix_name == o.suffix_name &&
      recipient_second_name == o.recipient_second_name &&
       == o. &&
      office_code == o.office_code &&
      no_tin == o.no_tin &&
      second_tin_notice == o.second_tin_notice
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 1000

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


892
893
894
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 892

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



898
899
900
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 898

def hash
  [filer_type, payment_type, payment_settlement_entity_name_phone_number, gross_amount_payment_card, card_not_present_transactions, merchant_category_code, payment_transaction_number, federal_income_tax_withheld, january, february, march, april, may, june, july, august, september, october, november, december, type, id, issuer_id, issuer_reference_id, issuer_tin, tax_year, reference_id, tin, recipient_name, address, address2, city, state, zip, email, non_us_province, country_code, federal_efile_date, postal_mail, state_efile_date, recipient_edelivery_date, tin_match, address_verification, state_and_local_withholding, federal_efile_status, state_efile_status, postal_mail_status, tin_match_status, address_verification_status, e_delivery_status, validation_errors, created_at, updated_at, tin_type, business_name, business_name2, first_name, middle_name, last_name, suffix_name, recipient_second_name, , office_code, no_tin, second_tin_notice].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



752
753
754
755
756
757
758
759
760
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 752

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



976
977
978
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 976

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



982
983
984
985
986
987
988
989
990
991
992
993
994
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 982

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



970
971
972
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 970

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/avalara_sdk/models/A1099/V2/form1099_k.rb', line 764

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  filer_type_validator = EnumAttributeValidator.new('String', ["PSE", "EPF"])
  return false unless filer_type_validator.valid?(@filer_type)
  payment_type_validator = EnumAttributeValidator.new('String', ["PaymentCard", "ThirdPartyNetwork"])
  return false unless payment_type_validator.valid?(@payment_type)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["1042-S", "1095-B", "1095-C", "1099-DIV", "1099-INT", "1099-K", "1099-MISC", "1099-NEC", "1099-R", "W-2"])
  return false unless type_validator.valid?(@type)
  tin_type_validator = EnumAttributeValidator.new('String', ["EIN", "SSN", "ITIN", "ATIN", "INDIVIDUAL", "BUSINESS", "UNKNOWN"])
  return false unless tin_type_validator.valid?(@tin_type)
  true
end