Class: AvalaraSdk::A1099::V2::Form1099Nec
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::Form1099Nec
- Defined in:
- lib/avalara_sdk/models/A1099/V2/form1099_nec.rb
Overview
Form 1099-NEC: Nonemployee Compensation
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number.
-
#address ⇒ Object
Address.
-
#address2 ⇒ Object
Address line 2.
-
#address_verification ⇒ Object
Boolean indicating that address verification should be scheduled for this form.
-
#address_verification_status ⇒ Object
Address verification status.
-
#city ⇒ Object
City.
-
#country_code ⇒ Object
Two-letter IRS country code (e.g., ‘US’, ‘CA’), as defined at www.irs.gov/e-file-providers/country-codes.
-
#created_at ⇒ Object
Date time when the record was created.
-
#direct_sales_indicator ⇒ Object
Payer made direct sales totaling $5,000 or more of consumer products to recipient for resale.
-
#e_delivery_status ⇒ Object
EDelivery status.
-
#email ⇒ Object
Recipient’s Contact email address.
-
#excess_golden_parachute_payments ⇒ Object
Excess golden parachute payments - Available only for tax year 2025 and later.
-
#federal_efile_date ⇒ Object
Date when federal e-filing should be scheduled.
-
#federal_efile_status ⇒ Object
Federal e-file status.
-
#federal_income_tax_withheld ⇒ Object
Federal income tax withheld.
-
#id ⇒ Object
Form ID.
-
#issuer_id ⇒ Object
Issuer ID - only required when creating forms.
-
#issuer_reference_id ⇒ Object
Issuer Reference ID - only required when creating forms via $bulk-upsert.
-
#issuer_tin ⇒ Object
Issuer TIN - readonly.
-
#no_tin ⇒ Object
No TIN indicator.
-
#non_us_province ⇒ Object
Province or region for non-US/CA addresses.
-
#nonemployee_compensation ⇒ Object
Nonemployee compensation.
-
#office_code ⇒ Object
Office code.
-
#postal_mail ⇒ Object
Boolean indicating that postal mailing to the recipient should be scheduled for this form.
-
#postal_mail_status ⇒ Object
Postal mail to recipient status.
-
#recipient_edelivery_date ⇒ Object
Date when recipient e-delivery should be scheduled.
-
#recipient_name ⇒ Object
Recipient name.
-
#recipient_second_name ⇒ Object
Recipient second name.
-
#reference_id ⇒ Object
Internal reference ID.
-
#second_tin_notice ⇒ Object
Second TIN notice.
-
#state ⇒ Object
Two-letter US state or Canadian province code (required for US/CA addresses).
-
#state_and_local_withholding ⇒ Object
State and local withholding information.
-
#state_efile_date ⇒ Object
Date when state e-filing should be scheduled.
-
#state_efile_status ⇒ Object
State e-file status.
-
#tax_year ⇒ Object
Tax Year - only required when creating forms via $bulk-upsert.
-
#tin ⇒ Object
Recipient’s Federal Tax Identification Number (TIN).
-
#tin_match ⇒ Object
Boolean indicating that TIN Matching should be scheduled for this form.
-
#tin_match_status ⇒ Object
TIN Match status.
-
#tin_type ⇒ Object
Tax Identification Number (TIN) type.
-
#type ⇒ Object
Form type.
-
#updated_at ⇒ Object
Date time when the record was last updated.
-
#validation_errors ⇒ Object
Validation errors.
-
#zip ⇒ Object
ZIP/postal code.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Form1099Nec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Form1099Nec
Initializes the object
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 324 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::Form1099Nec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::Form1099Nec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'nonemployee_compensation') self.nonemployee_compensation = attributes[:'nonemployee_compensation'] else self.nonemployee_compensation = nil end if attributes.key?(:'direct_sales_indicator') self.direct_sales_indicator = attributes[:'direct_sales_indicator'] end if attributes.key?(:'excess_golden_parachute_payments') self.excess_golden_parachute_payments = attributes[:'excess_golden_parachute_payments'] end if attributes.key?(:'federal_income_tax_withheld') self.federal_income_tax_withheld = attributes[:'federal_income_tax_withheld'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'issuer_id') self.issuer_id = attributes[:'issuer_id'] end if attributes.key?(:'issuer_reference_id') self.issuer_reference_id = attributes[:'issuer_reference_id'] end if attributes.key?(:'issuer_tin') self.issuer_tin = attributes[:'issuer_tin'] end if attributes.key?(:'tax_year') self.tax_year = attributes[:'tax_year'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'tin') self.tin = attributes[:'tin'] end if attributes.key?(:'recipient_name') self.recipient_name = attributes[:'recipient_name'] else self.recipient_name = nil end if attributes.key?(:'tin_type') self.tin_type = attributes[:'tin_type'] end if attributes.key?(:'recipient_second_name') self.recipient_second_name = attributes[:'recipient_second_name'] end if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'address2') self.address2 = attributes[:'address2'] end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'zip') self.zip = attributes[:'zip'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] end if attributes.key?(:'office_code') self.office_code = attributes[:'office_code'] end if attributes.key?(:'non_us_province') self.non_us_province = attributes[:'non_us_province'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] else self.country_code = nil end if attributes.key?(:'federal_efile_date') self.federal_efile_date = attributes[:'federal_efile_date'] end if attributes.key?(:'postal_mail') self.postal_mail = attributes[:'postal_mail'] end if attributes.key?(:'state_efile_date') self.state_efile_date = attributes[:'state_efile_date'] end if attributes.key?(:'recipient_edelivery_date') self.recipient_edelivery_date = attributes[:'recipient_edelivery_date'] end if attributes.key?(:'tin_match') self.tin_match = attributes[:'tin_match'] end if attributes.key?(:'no_tin') self.no_tin = attributes[:'no_tin'] end if attributes.key?(:'address_verification') self.address_verification = attributes[:'address_verification'] end if attributes.key?(:'state_and_local_withholding') self.state_and_local_withholding = attributes[:'state_and_local_withholding'] end if attributes.key?(:'second_tin_notice') self.second_tin_notice = attributes[:'second_tin_notice'] end if attributes.key?(:'federal_efile_status') self.federal_efile_status = attributes[:'federal_efile_status'] end if attributes.key?(:'state_efile_status') if (value = attributes[:'state_efile_status']).is_a?(Array) self.state_efile_status = value end end if attributes.key?(:'postal_mail_status') self.postal_mail_status = attributes[:'postal_mail_status'] end if attributes.key?(:'tin_match_status') self.tin_match_status = attributes[:'tin_match_status'] end if attributes.key?(:'address_verification_status') self.address_verification_status = attributes[:'address_verification_status'] end if attributes.key?(:'e_delivery_status') self.e_delivery_status = attributes[:'e_delivery_status'] end if attributes.key?(:'validation_errors') if (value = attributes[:'validation_errors']).is_a?(Array) self.validation_errors = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#account_number ⇒ Object
Account number
79 80 81 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 79 def account_number @account_number end |
#address ⇒ Object
Address.
61 62 63 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 61 def address @address end |
#address2 ⇒ Object
Address line 2.
64 65 66 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 64 def address2 @address2 end |
#address_verification ⇒ Object
Boolean indicating that address verification should be scheduled for this form
109 110 111 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 109 def address_verification @address_verification end |
#address_verification_status ⇒ Object
Address verification status. Available values: - unknown: Address verification has not been checked - pending: Address verification is in progress - failed: Address verification failed - incomplete: Address verification is incomplete - unchanged: User declined address changes - verified: Address has been verified and accepted
130 131 132 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 130 def address_verification_status @address_verification_status end |
#city ⇒ Object
City.
67 68 69 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 67 def city @city end |
#country_code ⇒ Object
Two-letter IRS country code (e.g., ‘US’, ‘CA’), as defined at www.irs.gov/e-file-providers/country-codes.
88 89 90 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 88 def country_code @country_code end |
#created_at ⇒ Object
Date time when the record was created.
139 140 141 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 139 def created_at @created_at end |
#direct_sales_indicator ⇒ Object
Payer made direct sales totaling $5,000 or more of consumer products to recipient for resale. Should be true if Nonemployee compensation is not provided.
19 20 21 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 19 def direct_sales_indicator @direct_sales_indicator end |
#e_delivery_status ⇒ Object
EDelivery status. Available values: - unscheduled: E-delivery has not been scheduled - scheduled: E-delivery is scheduled to be sent - sent: E-delivery has been sent to recipient - bounced: E-delivery bounced back (invalid email) - refused: E-delivery was refused by recipient - bad_verify: E-delivery failed verification - accepted: E-delivery was accepted by recipient - bad_verify_limit: E-delivery failed verification limit reached - second_delivery: Second e-delivery attempt - undelivered: E-delivery is undelivered (temporary state allowing resend)
133 134 135 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 133 def e_delivery_status @e_delivery_status end |
#email ⇒ Object
Recipient’s Contact email address.
76 77 78 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 76 def email @email end |
#excess_golden_parachute_payments ⇒ Object
Excess golden parachute payments - Available only for tax year 2025 and later
22 23 24 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 22 def excess_golden_parachute_payments @excess_golden_parachute_payments end |
#federal_efile_date ⇒ Object
Date when federal e-filing should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.
91 92 93 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 91 def federal_efile_date @federal_efile_date end |
#federal_efile_status ⇒ Object
Federal e-file status. Available values: - unscheduled: Form has not been scheduled for federal e-filing - scheduled: Form is scheduled for federal e-filing - airlock: Form is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - sent: Form has been sent to the IRS - accepted: Form was accepted by the IRS - corrected_scheduled: Correction is scheduled to be sent - corrected_airlock: Correction is in process of being uploaded to the IRS (forms exist in this state for a very short period and cannot be updated while in this state) - corrected: A correction has been sent to the IRS - corrected_accepted: Correction was accepted by the IRS - rejected: Form was rejected by the IRS - corrected_rejected: Correction was rejected by the IRS - held: Form is held and will not be submitted to IRS (used for certain forms submitted only to states)
118 119 120 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 118 def federal_efile_status @federal_efile_status end |
#federal_income_tax_withheld ⇒ Object
Federal income tax withheld.
25 26 27 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 25 def federal_income_tax_withheld @federal_income_tax_withheld end |
#id ⇒ Object
Form ID. Unique identifier set when the record is created.
31 32 33 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 31 def id @id end |
#issuer_id ⇒ Object
Issuer ID - only required when creating forms
34 35 36 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 34 def issuer_id @issuer_id end |
#issuer_reference_id ⇒ Object
Issuer Reference ID - only required when creating forms via $bulk-upsert
37 38 39 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 37 def issuer_reference_id @issuer_reference_id end |
#issuer_tin ⇒ Object
Issuer TIN - readonly
40 41 42 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 40 def issuer_tin @issuer_tin end |
#no_tin ⇒ Object
No TIN indicator
106 107 108 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 106 def no_tin @no_tin end |
#non_us_province ⇒ Object
Province or region for non-US/CA addresses.
85 86 87 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 85 def non_us_province @non_us_province end |
#nonemployee_compensation ⇒ Object
Nonemployee compensation. Required if DirectSalesIndicator is false.
16 17 18 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 16 def nonemployee_compensation @nonemployee_compensation end |
#office_code ⇒ Object
Office code
82 83 84 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 82 def office_code @office_code end |
#postal_mail ⇒ Object
Boolean indicating that postal mailing to the recipient should be scheduled for this form
94 95 96 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 94 def postal_mail @postal_mail end |
#postal_mail_status ⇒ Object
Postal mail to recipient status. Available values: - unscheduled: Postal mail has not been scheduled - pending: Postal mail is pending to be sent - sent: Postal mail has been sent - delivered: Postal mail has been delivered
124 125 126 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 124 def postal_mail_status @postal_mail_status end |
#recipient_edelivery_date ⇒ Object
Date when recipient e-delivery should be scheduled. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.
100 101 102 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 100 def recipient_edelivery_date @recipient_edelivery_date end |
#recipient_name ⇒ Object
Recipient name
52 53 54 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 52 def recipient_name @recipient_name end |
#recipient_second_name ⇒ Object
Recipient second name
58 59 60 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 58 def recipient_second_name @recipient_second_name end |
#reference_id ⇒ Object
Internal reference ID. Never shown to any agency or recipient.
46 47 48 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 46 def reference_id @reference_id end |
#second_tin_notice ⇒ Object
Second TIN notice
115 116 117 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 115 def second_tin_notice @second_tin_notice end |
#state ⇒ Object
Two-letter US state or Canadian province code (required for US/CA addresses).
70 71 72 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 70 def state @state end |
#state_and_local_withholding ⇒ Object
State and local withholding information
112 113 114 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 112 def state_and_local_withholding @state_and_local_withholding end |
#state_efile_date ⇒ Object
Date when state e-filing should be scheduled. Must be on or after federalEfileDate. If set between current date and beginning of blackout period, scheduled to that date. If in the past or blackout period, scheduled to next available date. For blackout period information, see www.track1099.com/info/IRS_info. Set to null to leave unscheduled.
97 98 99 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 97 def state_efile_date @state_efile_date end |
#state_efile_status ⇒ Object
State e-file status. Available values: - unscheduled: Form has not been scheduled for state e-filing - scheduled: Form is scheduled for state e-filing - airlocked: Form is in process of being uploaded to the state - sent: Form has been sent to the state - rejected: Form was rejected by the state - accepted: Form was accepted by the state - corrected_scheduled: Correction is scheduled to be sent - corrected_airlocked: Correction is in process of being uploaded to the state - corrected_sent: Correction has been sent to the state - corrected_rejected: Correction was rejected by the state - corrected_accepted: Correction was accepted by the state
121 122 123 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 121 def state_efile_status @state_efile_status end |
#tax_year ⇒ Object
Tax Year - only required when creating forms via $bulk-upsert
43 44 45 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 43 def tax_year @tax_year end |
#tin ⇒ Object
Recipient’s Federal Tax Identification Number (TIN).
49 50 51 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 49 def tin @tin end |
#tin_match ⇒ Object
Boolean indicating that TIN Matching should be scheduled for this form
103 104 105 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 103 def tin_match @tin_match end |
#tin_match_status ⇒ Object
TIN Match status. Available values: - none: TIN matching has not been performed - pending: TIN matching request is pending - matched: Name/TIN combination matches IRS records - unknown: TIN is missing, invalid, or request contains errors - rejected: Name/TIN combination does not match IRS records or TIN not currently issued
127 128 129 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 127 def tin_match_status @tin_match_status end |
#tin_type ⇒ Object
Tax Identification Number (TIN) type. Available values: - EIN: Employer Identification Number - SSN: Social Security Number - ITIN: Individual Taxpayer Identification Number - ATIN: Adoption Taxpayer Identification Number
55 56 57 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 55 def tin_type @tin_type end |
#type ⇒ Object
Form type.
28 29 30 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 28 def type @type end |
#updated_at ⇒ Object
Date time when the record was last updated.
142 143 144 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 142 def updated_at @updated_at end |
#validation_errors ⇒ Object
Validation errors
136 137 138 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 136 def validation_errors @validation_errors end |
#zip ⇒ Object
ZIP/postal code.
73 74 75 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 73 def zip @zip end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 659 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
216 217 218 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 216 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 167 def self.attribute_map { :'nonemployee_compensation' => :'nonemployeeCompensation', :'direct_sales_indicator' => :'directSalesIndicator', :'excess_golden_parachute_payments' => :'excessGoldenParachutePayments', :'federal_income_tax_withheld' => :'federalIncomeTaxWithheld', :'type' => :'type', :'id' => :'id', :'issuer_id' => :'issuerId', :'issuer_reference_id' => :'issuerReferenceId', :'issuer_tin' => :'issuerTin', :'tax_year' => :'taxYear', :'reference_id' => :'referenceId', :'tin' => :'tin', :'recipient_name' => :'recipientName', :'tin_type' => :'tinType', :'recipient_second_name' => :'recipientSecondName', :'address' => :'address', :'address2' => :'address2', :'city' => :'city', :'state' => :'state', :'zip' => :'zip', :'email' => :'email', :'account_number' => :'accountNumber', :'office_code' => :'officeCode', :'non_us_province' => :'nonUsProvince', :'country_code' => :'countryCode', :'federal_efile_date' => :'federalEfileDate', :'postal_mail' => :'postalMail', :'state_efile_date' => :'stateEfileDate', :'recipient_edelivery_date' => :'recipientEdeliveryDate', :'tin_match' => :'tinMatch', :'no_tin' => :'noTin', :'address_verification' => :'addressVerification', :'state_and_local_withholding' => :'stateAndLocalWithholding', :'second_tin_notice' => :'secondTinNotice', :'federal_efile_status' => :'federalEfileStatus', :'state_efile_status' => :'stateEfileStatus', :'postal_mail_status' => :'postalMailStatus', :'tin_match_status' => :'tinMatchStatus', :'address_verification_status' => :'addressVerificationStatus', :'e_delivery_status' => :'eDeliveryStatus', :'validation_errors' => :'validationErrors', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 635 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
316 317 318 319 320 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 316 def self.openapi_all_of [ :'Form1099Base' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 270 def self.openapi_nullable Set.new([ :'nonemployee_compensation', :'direct_sales_indicator', :'excess_golden_parachute_payments', :'federal_income_tax_withheld', :'id', :'issuer_id', :'issuer_reference_id', :'issuer_tin', :'tax_year', :'reference_id', :'tin', :'recipient_name', :'tin_type', :'recipient_second_name', :'address', :'address2', :'city', :'state', :'zip', :'email', :'account_number', :'office_code', :'non_us_province', :'country_code', :'federal_efile_date', :'postal_mail', :'state_efile_date', :'recipient_edelivery_date', :'tin_match', :'no_tin', :'address_verification', :'state_and_local_withholding', :'second_tin_notice', :'federal_efile_status', :'state_efile_status', :'postal_mail_status', :'tin_match_status', :'address_verification_status', :'e_delivery_status', :'validation_errors', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 221 def self.openapi_types { :'nonemployee_compensation' => :'Float', :'direct_sales_indicator' => :'Boolean', :'excess_golden_parachute_payments' => :'Float', :'federal_income_tax_withheld' => :'Float', :'type' => :'String', :'id' => :'String', :'issuer_id' => :'String', :'issuer_reference_id' => :'String', :'issuer_tin' => :'String', :'tax_year' => :'Integer', :'reference_id' => :'String', :'tin' => :'String', :'recipient_name' => :'String', :'tin_type' => :'String', :'recipient_second_name' => :'String', :'address' => :'String', :'address2' => :'String', :'city' => :'String', :'state' => :'String', :'zip' => :'String', :'email' => :'String', :'account_number' => :'String', :'office_code' => :'String', :'non_us_province' => :'String', :'country_code' => :'String', :'federal_efile_date' => :'Date', :'postal_mail' => :'Boolean', :'state_efile_date' => :'Date', :'recipient_edelivery_date' => :'Date', :'tin_match' => :'Boolean', :'no_tin' => :'Boolean', :'address_verification' => :'Boolean', :'state_and_local_withholding' => :'StateAndLocalWithholding', :'second_tin_notice' => :'Boolean', :'federal_efile_status' => :'Form1099StatusDetail', :'state_efile_status' => :'Array<StateEfileStatusDetail>', :'postal_mail_status' => :'Form1099StatusDetail', :'tin_match_status' => :'Form1099StatusDetail', :'address_verification_status' => :'Form1099StatusDetail', :'e_delivery_status' => :'Form1099StatusDetail', :'validation_errors' => :'Array<ValidationError>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 572 def ==(o) return true if self.equal?(o) self.class == o.class && nonemployee_compensation == o.nonemployee_compensation && direct_sales_indicator == o.direct_sales_indicator && excess_golden_parachute_payments == o.excess_golden_parachute_payments && federal_income_tax_withheld == o.federal_income_tax_withheld && type == o.type && id == o.id && issuer_id == o.issuer_id && issuer_reference_id == o.issuer_reference_id && issuer_tin == o.issuer_tin && tax_year == o.tax_year && reference_id == o.reference_id && tin == o.tin && recipient_name == o.recipient_name && tin_type == o.tin_type && recipient_second_name == o.recipient_second_name && address == o.address && address2 == o.address2 && city == o.city && state == o.state && zip == o.zip && email == o.email && account_number == o.account_number && office_code == o.office_code && non_us_province == o.non_us_province && country_code == o.country_code && federal_efile_date == o.federal_efile_date && postal_mail == o.postal_mail && state_efile_date == o.state_efile_date && recipient_edelivery_date == o.recipient_edelivery_date && tin_match == o.tin_match && no_tin == o.no_tin && address_verification == o.address_verification && state_and_local_withholding == o.state_and_local_withholding && second_tin_notice == o.second_tin_notice && federal_efile_status == o.federal_efile_status && state_efile_status == o.state_efile_status && postal_mail_status == o.postal_mail_status && tin_match_status == o.tin_match_status && address_verification_status == o.address_verification_status && e_delivery_status == o.e_delivery_status && validation_errors == o.validation_errors && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 730 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
622 623 624 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 622 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
628 629 630 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 628 def hash [nonemployee_compensation, direct_sales_indicator, excess_golden_parachute_payments, federal_income_tax_withheld, type, id, issuer_id, issuer_reference_id, issuer_tin, tax_year, reference_id, tin, recipient_name, tin_type, recipient_second_name, address, address2, city, state, zip, email, account_number, office_code, non_us_province, country_code, federal_efile_date, postal_mail, state_efile_date, recipient_edelivery_date, tin_match, no_tin, address_verification, state_and_local_withholding, second_tin_notice, federal_efile_status, state_efile_status, postal_mail_status, tin_match_status, address_verification_status, e_delivery_status, validation_errors, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
528 529 530 531 532 533 534 535 536 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 528 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
706 707 708 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 706 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
712 713 714 715 716 717 718 719 720 721 722 723 724 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 712 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
700 701 702 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 700 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
540 541 542 543 544 545 546 547 548 |
# File 'lib/avalara_sdk/models/A1099/V2/form1099_nec.rb', line 540 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["1042-S", "1095-B", "1095-C", "1099-DIV", "1099-INT", "1099-K", "1099-MISC", "1099-NEC", "1099-R"]) return false unless type_validator.valid?(@type) tin_type_validator = EnumAttributeValidator.new('String', ["EIN", "SSN", "ITIN", "ATIN"]) return false unless tin_type_validator.valid?(@tin_type) true end |