Class: AvalaraSdk::A1099::V2::IssuerBase

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/A1099/V2/issuer_base.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IssuerBase

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 193

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::IssuerBase` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::IssuerBase`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'business_name')
    self.business_name = attributes[:'business_name']
  else
    self.business_name = nil
  end

  if attributes.key?(:'business_name2')
    self.business_name2 = attributes[:'business_name2']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'dba_name')
    self.dba_name = attributes[:'dba_name']
  end

  if attributes.key?(:'tin_type')
    self.tin_type = attributes[:'tin_type']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.key?(:'tin')
    self.tin = attributes[:'tin']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'telephone')
    self.telephone = attributes[:'telephone']
  else
    self.telephone = nil
  end

  if attributes.key?(:'tax_year')
    self.tax_year = attributes[:'tax_year']
  else
    self.tax_year = nil
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  else
    self.country_code = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'zip')
    self.zip = attributes[:'zip']
  else
    self.zip = nil
  end

  if attributes.key?(:'foreign_province')
    self.foreign_province = attributes[:'foreign_province']
  end

  if attributes.key?(:'transfer_agent_name')
    self.transfer_agent_name = attributes[:'transfer_agent_name']
  end

  if attributes.key?(:'last_filing')
    self.last_filing = attributes[:'last_filing']
  else
    self.last_filing = nil
  end
end

Instance Attribute Details

#addressObject

Address.



60
61
62
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 60

def address
  @address
end

#business_nameObject

Business name. Required when the recipient of the form is a business; should only be used for businesses.



15
16
17
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 15

def business_name
  @business_name
end

#business_name2Object

Business name line 2. Should only be used for businesses. Use either this or 'transferAgentName'.



18
19
20
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 18

def business_name2
  @business_name2
end

#cityObject

City.



63
64
65
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 63

def city
  @city
end

#country_codeObject

Two-letter IRS country code (e.g., 'US', 'CA'), as defined at https://www.irs.gov/e-file-providers/country-codes. If there is a transfer agent, use the transfer agent's shipping address.



54
55
56
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 54

def country_code
  @country_code
end

#dba_nameObject

Doing Business As (DBA) name or continuation of a long legal name. Deprecated alias for 'businessName2'. Use either this or 'transferAgentName'.



24
25
26
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 24

def dba_name
  @dba_name
end

#emailObject

Contact email address. For recipient inquiries. Phone will be used on communications if you don't specify an email



57
58
59
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 57

def email
  @email
end

#first_nameObject

First name. Required when the recipient of the form is an individual; should only be used for individuals.



30
31
32
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 30

def first_name
  @first_name
end

#foreign_provinceObject

Province or region for non-US/CA addresses.



72
73
74
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 72

def foreign_province
  @foreign_province
end

#last_filingObject

Indicates if this is the issuer's final year filing.



78
79
80
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 78

def last_filing
  @last_filing
end

#last_nameObject

Last name. Required when the recipient of the form is an individual; should only be used for individuals.



36
37
38
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 36

def last_name
  @last_name
end

#middle_nameObject

Middle name. Should only be used for individuals.



33
34
35
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 33

def middle_name
  @middle_name
end

#nameObject

Legal name. Not the DBA name. Deprecated alias for 'businessName'.



21
22
23
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 21

def name
  @name
end

#reference_idObject

Internal reference ID. Never shown to any agency or recipient. If present, it will prefix download filenames. Allowed characters: letters, numbers, dashes, underscores, and spaces.



45
46
47
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 45

def reference_id
  @reference_id
end

#stateObject

Two-letter US state or Canadian province code (required for US/CA addresses).



66
67
68
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 66

def state
  @state
end

#suffixObject

Suffix name. Should only be used for individuals.



39
40
41
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 39

def suffix
  @suffix
end

#tax_yearObject

Tax year for which the forms are being filed (e.g., 2024). Must be within current tax year and current tax year - 4. It's only required on creation, and cannot be modified on update.



51
52
53
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 51

def tax_year
  @tax_year
end

#telephoneObject

Contact phone number (must contain at least 10 digits, max 15 characters). For recipient inquiries.



48
49
50
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 48

def telephone
  @telephone
end

#tinObject

Federal Tax Identification Number (TIN).



42
43
44
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 42

def tin
  @tin
end

#tin_typeObject

Recipient classification. The platform is transitioning from tax identifier classifications to recipient entity classifications. New values represent recipient entity types and should be preferred. Deprecated values represent identifier formats and remain supported for backward compatibility only. Available values: - INDIVIDUAL: Recipient is an individual - BUSINESS: Recipient is a business - UNKNOWN: Recipient classification is unknown - EIN: (Deprecated - use BUSINESS) Employer Identification Number - SSN: (Deprecated - use INDIVIDUAL) Social Security Number - ITIN: (Deprecated - use INDIVIDUAL) Individual Taxpayer Identification Number - ATIN: (Deprecated - use INDIVIDUAL) Adoption Taxpayer Identification Number



27
28
29
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 27

def tin_type
  @tin_type
end

#transfer_agent_nameObject

Name of the transfer agent, if applicable — optional; use either this or 'dbaName'.



75
76
77
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 75

def transfer_agent_name
  @transfer_agent_name
end

#zipObject

ZIP/postal code.



69
70
71
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 69

def zip
  @zip
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 408

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::A1099::V2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 131

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 103

def self.attribute_map
  {
    :'business_name' => :'businessName',
    :'business_name2' => :'businessName2',
    :'name' => :'name',
    :'dba_name' => :'dbaName',
    :'tin_type' => :'tinType',
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'last_name' => :'lastName',
    :'suffix' => :'suffix',
    :'tin' => :'tin',
    :'reference_id' => :'referenceId',
    :'telephone' => :'telephone',
    :'tax_year' => :'taxYear',
    :'country_code' => :'countryCode',
    :'email' => :'email',
    :'address' => :'address',
    :'city' => :'city',
    :'state' => :'state',
    :'zip' => :'zip',
    :'foreign_province' => :'foreignProvince',
    :'transfer_agent_name' => :'transferAgentName',
    :'last_filing' => :'lastFiling'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 384

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 164

def self.openapi_nullable
  Set.new([
    :'business_name',
    :'business_name2',
    :'name',
    :'dba_name',
    :'tin_type',
    :'first_name',
    :'middle_name',
    :'last_name',
    :'suffix',
    :'tin',
    :'reference_id',
    :'telephone',
    :'tax_year',
    :'country_code',
    :'email',
    :'address',
    :'city',
    :'state',
    :'zip',
    :'foreign_province',
    :'transfer_agent_name',
    :'last_filing'
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 136

def self.openapi_types
  {
    :'business_name' => :'String',
    :'business_name2' => :'String',
    :'name' => :'String',
    :'dba_name' => :'String',
    :'tin_type' => :'String',
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'suffix' => :'String',
    :'tin' => :'String',
    :'reference_id' => :'String',
    :'telephone' => :'String',
    :'tax_year' => :'Integer',
    :'country_code' => :'String',
    :'email' => :'String',
    :'address' => :'String',
    :'city' => :'String',
    :'state' => :'String',
    :'zip' => :'String',
    :'foreign_province' => :'String',
    :'transfer_agent_name' => :'String',
    :'last_filing' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 342

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      business_name == o.business_name &&
      business_name2 == o.business_name2 &&
      name == o.name &&
      dba_name == o.dba_name &&
      tin_type == o.tin_type &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      suffix == o.suffix &&
      tin == o.tin &&
      reference_id == o.reference_id &&
      telephone == o.telephone &&
      tax_year == o.tax_year &&
      country_code == o.country_code &&
      email == o.email &&
      address == o.address &&
      city == o.city &&
      state == o.state &&
      zip == o.zip &&
      foreign_province == o.foreign_province &&
      transfer_agent_name == o.transfer_agent_name &&
      last_filing == o.last_filing
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 479

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


371
372
373
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 371

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



377
378
379
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 377

def hash
  [business_name, business_name2, name, dba_name, tin_type, first_name, middle_name, last_name, suffix, tin, reference_id, telephone, tax_year, country_code, email, address, city, state, zip, foreign_province, transfer_agent_name, last_filing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



315
316
317
318
319
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 315

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



455
456
457
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 455

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 461

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



449
450
451
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 449

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



323
324
325
326
327
328
# File 'lib/avalara_sdk/models/A1099/V2/issuer_base.rb', line 323

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  tin_type_validator = EnumAttributeValidator.new('String', ["UNKNOWN", "INDIVIDUAL", "BUSINESS"])
  return false unless tin_type_validator.valid?(@tin_type)
  true
end