Class: AvalaraSdk::A1099::V2::W4FormRequest
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::W4FormRequest
- Defined in:
- lib/avalara_sdk/models/A1099/V2/w4_form_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#additional_withheld ⇒ Object
The additional amount withheld.
-
#address ⇒ Object
The address of the employee.
-
#city ⇒ Object
The city of residence of the employee.
-
#company_id ⇒ Object
The ID of the associated company.
-
#deductions ⇒ Object
The amount of deductions claimed.
-
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
-
#email ⇒ Object
The email address of the individual associated with the form.
-
#employee_first_name ⇒ Object
The first name of the employee.
-
#employee_last_name ⇒ Object
The last name of the employee.
-
#employee_middle_name ⇒ Object
The middle name of the employee.
-
#employee_name_suffix ⇒ Object
The name suffix of the employee.
-
#exempt_from_withholding ⇒ Object
Indicates whether the employee is exempt from withholding.
-
#last_name_differs ⇒ Object
Indicates whether the last name differs from prior records.
-
#marital_status ⇒ Object
The marital status of the employee.
-
#non_job_income ⇒ Object
The amount of non-job income.
-
#num_allowances ⇒ Object
The number of allowances claimed by the employee.
-
#office_code ⇒ Object
The office code associated with the form.
-
#other_dependents ⇒ Object
The number of dependents other than allowances.
-
#reference_id ⇒ Object
A reference identifier for the form.
-
#signature ⇒ Object
The signature of the form.
-
#state ⇒ Object
The state of residence of the employee.
-
#tin ⇒ Object
The taxpayer identification number (TIN).
-
#tin_type ⇒ Object
Tax Identification Number (TIN) type.
-
#type ⇒ Object
The form type (always "w4" for this model).
-
#zip ⇒ Object
The ZIP code of residence of the employee.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ W4FormRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ W4FormRequest
Initializes the object
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 210 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::W4FormRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::W4FormRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'employee_first_name') self.employee_first_name = attributes[:'employee_first_name'] else self.employee_first_name = nil end if attributes.key?(:'employee_middle_name') self.employee_middle_name = attributes[:'employee_middle_name'] end if attributes.key?(:'employee_last_name') self.employee_last_name = attributes[:'employee_last_name'] else self.employee_last_name = nil end if attributes.key?(:'employee_name_suffix') self.employee_name_suffix = attributes[:'employee_name_suffix'] end if attributes.key?(:'tin_type') self.tin_type = attributes[:'tin_type'] else self.tin_type = nil end if attributes.key?(:'tin') self.tin = attributes[:'tin'] else self.tin = nil end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'zip') self.zip = attributes[:'zip'] end if attributes.key?(:'marital_status') self.marital_status = attributes[:'marital_status'] end if attributes.key?(:'last_name_differs') self.last_name_differs = attributes[:'last_name_differs'] end if attributes.key?(:'num_allowances') self.num_allowances = attributes[:'num_allowances'] end if attributes.key?(:'other_dependents') self.other_dependents = attributes[:'other_dependents'] end if attributes.key?(:'non_job_income') self.non_job_income = attributes[:'non_job_income'] end if attributes.key?(:'deductions') self.deductions = attributes[:'deductions'] end if attributes.key?(:'additional_withheld') self.additional_withheld = attributes[:'additional_withheld'] end if attributes.key?(:'exempt_from_withholding') self.exempt_from_withholding = attributes[:'exempt_from_withholding'] end if attributes.key?(:'office_code') self.office_code = attributes[:'office_code'] end if attributes.key?(:'e_delivery_consented_at') self. = attributes[:'e_delivery_consented_at'] end if attributes.key?(:'signature') self.signature = attributes[:'signature'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'email') self.email = attributes[:'email'] end end |
Instance Attribute Details
#additional_withheld ⇒ Object
The additional amount withheld.
66 67 68 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 66 def additional_withheld @additional_withheld end |
#address ⇒ Object
The address of the employee. Required unless exempt.
36 37 38 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 36 def address @address end |
#city ⇒ Object
The city of residence of the employee. Required unless exempt.
39 40 41 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 39 def city @city end |
#company_id ⇒ Object
The ID of the associated company. Required when creating a form.
81 82 83 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 81 def company_id @company_id end |
#deductions ⇒ Object
The amount of deductions claimed.
63 64 65 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 63 def deductions @deductions end |
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
75 76 77 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 75 def @e_delivery_consented_at end |
#email ⇒ Object
The email address of the individual associated with the form.
87 88 89 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 87 def email @email end |
#employee_first_name ⇒ Object
The first name of the employee.
18 19 20 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 18 def employee_first_name @employee_first_name end |
#employee_last_name ⇒ Object
The last name of the employee.
24 25 26 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 24 def employee_last_name @employee_last_name end |
#employee_middle_name ⇒ Object
The middle name of the employee.
21 22 23 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 21 def employee_middle_name @employee_middle_name end |
#employee_name_suffix ⇒ Object
The name suffix of the employee.
27 28 29 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 27 def employee_name_suffix @employee_name_suffix end |
#exempt_from_withholding ⇒ Object
Indicates whether the employee is exempt from withholding.
69 70 71 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 69 def exempt_from_withholding @exempt_from_withholding end |
#last_name_differs ⇒ Object
Indicates whether the last name differs from prior records.
51 52 53 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 51 def last_name_differs @last_name_differs end |
#marital_status ⇒ Object
The marital status of the employee. Required unless exempt. Available values: - Single: Single or Married filing separately - Married: Married filing jointly or qualifying surviving spouse - MarriedBut: Head of household. Check only if you’re unmarried and pay more than half the costs of keeping up a home for yourself and a qualifying individual.
48 49 50 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 48 def marital_status @marital_status end |
#non_job_income ⇒ Object
The amount of non-job income.
60 61 62 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 60 def non_job_income @non_job_income end |
#num_allowances ⇒ Object
The number of allowances claimed by the employee.
54 55 56 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 54 def num_allowances @num_allowances end |
#office_code ⇒ Object
The office code associated with the form.
72 73 74 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 72 def office_code @office_code end |
#other_dependents ⇒ Object
The number of dependents other than allowances.
57 58 59 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 57 def other_dependents @other_dependents end |
#reference_id ⇒ Object
A reference identifier for the form.
84 85 86 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 84 def reference_id @reference_id end |
#signature ⇒ Object
The signature of the form.
78 79 80 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 78 def signature @signature end |
#state ⇒ Object
The state of residence of the employee. Required unless exempt.
42 43 44 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 42 def state @state end |
#tin ⇒ Object
The taxpayer identification number (TIN).
33 34 35 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 33 def tin @tin end |
#tin_type ⇒ Object
Tax Identification Number (TIN) type.
30 31 32 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 30 def tin_type @tin_type end |
#type ⇒ Object
The form type (always "w4" for this model).
15 16 17 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 15 def type @type end |
#zip ⇒ Object
The ZIP code of residence of the employee. Required unless exempt.
45 46 47 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 45 def zip @zip end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 474 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
143 144 145 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 143 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 112 def self.attribute_map { :'type' => :'type', :'employee_first_name' => :'employeeFirstName', :'employee_middle_name' => :'employeeMiddleName', :'employee_last_name' => :'employeeLastName', :'employee_name_suffix' => :'employeeNameSuffix', :'tin_type' => :'tinType', :'tin' => :'tin', :'address' => :'address', :'city' => :'city', :'state' => :'state', :'zip' => :'zip', :'marital_status' => :'maritalStatus', :'last_name_differs' => :'lastNameDiffers', :'num_allowances' => :'numAllowances', :'other_dependents' => :'otherDependents', :'non_job_income' => :'nonJobIncome', :'deductions' => :'deductions', :'additional_withheld' => :'additionalWithheld', :'exempt_from_withholding' => :'exemptFromWithholding', :'office_code' => :'officeCode', :'e_delivery_consented_at' => :'eDeliveryConsentedAt', :'signature' => :'signature', :'company_id' => :'companyId', :'reference_id' => :'referenceId', :'email' => :'email' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 450 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
202 203 204 205 206 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 202 def self.openapi_all_of [ :'W9FormBaseRequest' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 179 def self.openapi_nullable Set.new([ :'employee_middle_name', :'employee_name_suffix', :'address', :'city', :'state', :'zip', :'marital_status', :'num_allowances', :'other_dependents', :'non_job_income', :'deductions', :'additional_withheld', :'office_code', :'e_delivery_consented_at', :'signature', :'reference_id', :'email' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 148 def self.openapi_types { :'type' => :'String', :'employee_first_name' => :'String', :'employee_middle_name' => :'String', :'employee_last_name' => :'String', :'employee_name_suffix' => :'String', :'tin_type' => :'String', :'tin' => :'String', :'address' => :'String', :'city' => :'String', :'state' => :'String', :'zip' => :'String', :'marital_status' => :'String', :'last_name_differs' => :'Boolean', :'num_allowances' => :'Integer', :'other_dependents' => :'Integer', :'non_job_income' => :'Float', :'deductions' => :'Float', :'additional_withheld' => :'Float', :'exempt_from_withholding' => :'Boolean', :'office_code' => :'String', :'e_delivery_consented_at' => :'Time', :'signature' => :'String', :'company_id' => :'String', :'reference_id' => :'String', :'email' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 405 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && employee_first_name == o.employee_first_name && employee_middle_name == o.employee_middle_name && employee_last_name == o.employee_last_name && employee_name_suffix == o.employee_name_suffix && tin_type == o.tin_type && tin == o.tin && address == o.address && city == o.city && state == o.state && zip == o.zip && marital_status == o.marital_status && last_name_differs == o.last_name_differs && num_allowances == o.num_allowances && other_dependents == o.other_dependents && non_job_income == o.non_job_income && deductions == o.deductions && additional_withheld == o.additional_withheld && exempt_from_withholding == o.exempt_from_withholding && office_code == o.office_code && == o. && signature == o.signature && company_id == o.company_id && reference_id == o.reference_id && email == o.email end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
545 546 547 548 549 550 551 552 553 554 555 556 557 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 545 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
437 438 439 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 437 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
443 444 445 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 443 def hash [type, employee_first_name, employee_middle_name, employee_last_name, employee_name_suffix, tin_type, tin, address, city, state, zip, marital_status, last_name_differs, num_allowances, other_dependents, non_job_income, deductions, additional_withheld, exempt_from_withholding, office_code, , signature, company_id, reference_id, email].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 334 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @employee_first_name.nil? invalid_properties.push('invalid value for "employee_first_name", employee_first_name cannot be nil.') end if @employee_last_name.nil? invalid_properties.push('invalid value for "employee_last_name", employee_last_name cannot be nil.') end if @tin_type.nil? invalid_properties.push('invalid value for "tin_type", tin_type cannot be nil.') end if @tin.nil? invalid_properties.push('invalid value for "tin", tin cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
521 522 523 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 521 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 527 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
515 516 517 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 515 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/avalara_sdk/models/A1099/V2/w4_form_request.rb', line 358 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["W4", "W8Ben", "W8BenE", "W8Imy", "W9"]) return false unless type_validator.valid?(@type) return false if @employee_first_name.nil? return false if @employee_last_name.nil? return false if @tin_type.nil? return false if @tin.nil? state_validator = EnumAttributeValidator.new('String', ["AA", "AE", "AK", "AL", "AP", "AR", "AS", "AZ", "CA", "CO", "CT", "DC", "DE", "FL", "FM", "GA", "GU", "HI", "IA", "ID", "IL", "IN", "KS", "KY", "LA", "MA", "MD", "ME", "MH", "MI", "MN", "MO", "MP", "MS", "MT", "NC", "ND", "NE", "NH", "NJ", "NM", "NV", "NY", "OH", "OK", "OR", "PA", "PR", "PW", "RI", "SC", "SD", "TN", "TX", "UT", "VA", "VI", "VT", "WA", "WI", "WV", "WY"]) return false unless state_validator.valid?(@state) marital_status_validator = EnumAttributeValidator.new('String', ["Single", "Married", "MarriedBut"]) return false unless marital_status_validator.valid?(@marital_status) true end |