Class: AvalaraSdk::A1099::V2::W8BenFormRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ W8BenFormRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 237

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::W8BenFormRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::W8BenFormRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'citizenship_country')
    self.citizenship_country = attributes[:'citizenship_country']
  else
    self.citizenship_country = nil
  end

  if attributes.key?(:'residence_address')
    self.residence_address = attributes[:'residence_address']
  end

  if attributes.key?(:'residence_city')
    self.residence_city = attributes[:'residence_city']
  end

  if attributes.key?(:'residence_state')
    self.residence_state = attributes[:'residence_state']
  end

  if attributes.key?(:'residence_zip')
    self.residence_zip = attributes[:'residence_zip']
  end

  if attributes.key?(:'residence_country')
    self.residence_country = attributes[:'residence_country']
  else
    self.residence_country = nil
  end

  if attributes.key?(:'residence_is_mailing')
    self.residence_is_mailing = attributes[:'residence_is_mailing']
  end

  if attributes.key?(:'mailing_address')
    self.mailing_address = attributes[:'mailing_address']
  end

  if attributes.key?(:'mailing_city')
    self.mailing_city = attributes[:'mailing_city']
  end

  if attributes.key?(:'mailing_state')
    self.mailing_state = attributes[:'mailing_state']
  end

  if attributes.key?(:'mailing_zip')
    self.mailing_zip = attributes[:'mailing_zip']
  end

  if attributes.key?(:'mailing_country')
    self.mailing_country = attributes[:'mailing_country']
  else
    self.mailing_country = nil
  end

  if attributes.key?(:'tin')
    self.tin = attributes[:'tin']
  end

  if attributes.key?(:'foreign_tin_not_required')
    self.foreign_tin_not_required = attributes[:'foreign_tin_not_required']
  end

  if attributes.key?(:'foreign_tin')
    self.foreign_tin = attributes[:'foreign_tin']
  end

  if attributes.key?(:'reference_number')
    self.reference_number = attributes[:'reference_number']
  end

  if attributes.key?(:'birthday')
    self.birthday = attributes[:'birthday']
  end

  if attributes.key?(:'treaty_country')
    self.treaty_country = attributes[:'treaty_country']
  end

  if attributes.key?(:'treaty_article')
    self.treaty_article = attributes[:'treaty_article']
  end

  if attributes.key?(:'treaty_reasons')
    self.treaty_reasons = attributes[:'treaty_reasons']
  end

  if attributes.key?(:'withholding_rate')
    self.withholding_rate = attributes[:'withholding_rate']
  end

  if attributes.key?(:'income_type')
    self.income_type = attributes[:'income_type']
  end

  if attributes.key?(:'signer_name')
    self.signer_name = attributes[:'signer_name']
  end

  if attributes.key?(:'e_delivery_consented_at')
    self.e_delivery_consented_at = attributes[:'e_delivery_consented_at']
  end

  if attributes.key?(:'signature')
    self.signature = attributes[:'signature']
  end

  if attributes.key?(:'company_id')
    self.company_id = attributes[:'company_id']
  end

  if attributes.key?(:'reference_id')
    self.reference_id = attributes[:'reference_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end
end

Instance Attribute Details

#birthdayObject

The birthday of the individual associated with the form.



69
70
71
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 69

def birthday
  @birthday
end

#citizenship_countryObject

The country of citizenship.. Allowed values: US, AF, AX, AL, AG, AQ, AN, AO, AV, AY (and 248 more)



21
22
23
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 21

def citizenship_country
  @citizenship_country
end

#company_idObject

The ID of the associated company. Required when creating a form.



96
97
98
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 96

def company_id
  @company_id
end

#e_delivery_consented_atObject

The date when e-delivery was consented.



90
91
92
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 90

def e_delivery_consented_at
  @e_delivery_consented_at
end

#emailObject

The email address of the individual associated with the form.



102
103
104
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 102

def email
  @email
end

#foreign_tinObject

The foreign taxpayer identification number (TIN).



63
64
65
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 63

def foreign_tin
  @foreign_tin
end

#foreign_tin_not_requiredObject

Indicates whether a foreign TIN is not legally required.



60
61
62
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 60

def foreign_tin_not_required
  @foreign_tin_not_required
end

#income_typeObject

The type of income covered by the treaty.



84
85
86
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 84

def income_type
  @income_type
end

#mailing_addressObject

The mailing address.



42
43
44
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 42

def mailing_address
  @mailing_address
end

#mailing_cityObject

The city of the mailing address.



45
46
47
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 45

def mailing_city
  @mailing_city
end

#mailing_countryObject

The country of the mailing address.. Allowed values: US, AF, AX, AL, AG, AQ, AN, AO, AV, AY (and 248 more)



54
55
56
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 54

def mailing_country
  @mailing_country
end

#mailing_stateObject

The state of the mailing address. Required for US and Canada.. Allowed values: AA, AE, AK, AL, AP, AR, AS, AZ, CA, CO (and 65 more)



48
49
50
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 48

def mailing_state
  @mailing_state
end

#mailing_zipObject

The ZIP code of the mailing address.



51
52
53
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 51

def mailing_zip
  @mailing_zip
end

#nameObject

The name of the individual or entity associated with the form.



18
19
20
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 18

def name
  @name
end

#reference_idObject

A reference identifier for the form.



99
100
101
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 99

def reference_id
  @reference_id
end

#reference_numberObject

A reference number for the form.



66
67
68
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 66

def reference_number
  @reference_number
end

#residence_addressObject

The residential address of the individual or entity.



24
25
26
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 24

def residence_address
  @residence_address
end

#residence_cityObject

The city of residence.



27
28
29
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 27

def residence_city
  @residence_city
end

#residence_countryObject

The country of residence.. Allowed values: US, AF, AX, AL, AG, AQ, AN, AO, AV, AY (and 248 more)



36
37
38
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 36

def residence_country
  @residence_country
end

#residence_is_mailingObject

Indicates whether the residence address is the mailing address.



39
40
41
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 39

def residence_is_mailing
  @residence_is_mailing
end

#residence_stateObject

The state of residence. Required for US and Canada.. Allowed values: AA, AE, AK, AL, AP, AR, AS, AZ, CA, CO (and 65 more)



30
31
32
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 30

def residence_state
  @residence_state
end

#residence_zipObject

The ZIP code of the residence.



33
34
35
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 33

def residence_zip
  @residence_zip
end

#signatureObject

The signature of the form.



93
94
95
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 93

def signature
  @signature
end

#signer_nameObject

The name of the signer of the form.



87
88
89
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 87

def signer_name
  @signer_name
end

#tinObject

The taxpayer identification number (TIN).



57
58
59
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 57

def tin
  @tin
end

#treaty_articleObject

The specific article of the treaty being claimed.



75
76
77
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 75

def treaty_article
  @treaty_article
end

#treaty_countryObject

The country for which the treaty applies.. Allowed values: US, AF, AX, AL, AG, AQ, AN, AO, AV, AY (and 248 more)



72
73
74
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 72

def treaty_country
  @treaty_country
end

#treaty_reasonsObject

The reasons for claiming treaty benefits.



78
79
80
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 78

def treaty_reasons
  @treaty_reasons
end

#typeObject

The form type (always "w8ben" for this model).



15
16
17
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 15

def type
  @type
end

#withholding_rateObject

The withholding rate applied as per the treaty. Must be a percentage with up to two decimals (e.g., 12.50, 0).. Allowed values: 0, 0.0, 0.00, 5, 5.5, 10, 12.50, 15, 20, 25 (and 1 more)



81
82
83
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 81

def withholding_rate
  @withholding_rate
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 581

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::A1099::V2.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



163
164
165
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 163

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 127

def self.attribute_map
  {
    :'type' => :'type',
    :'name' => :'name',
    :'citizenship_country' => :'citizenshipCountry',
    :'residence_address' => :'residenceAddress',
    :'residence_city' => :'residenceCity',
    :'residence_state' => :'residenceState',
    :'residence_zip' => :'residenceZip',
    :'residence_country' => :'residenceCountry',
    :'residence_is_mailing' => :'residenceIsMailing',
    :'mailing_address' => :'mailingAddress',
    :'mailing_city' => :'mailingCity',
    :'mailing_state' => :'mailingState',
    :'mailing_zip' => :'mailingZip',
    :'mailing_country' => :'mailingCountry',
    :'tin' => :'tin',
    :'foreign_tin_not_required' => :'foreignTinNotRequired',
    :'foreign_tin' => :'foreignTin',
    :'reference_number' => :'referenceNumber',
    :'birthday' => :'birthday',
    :'treaty_country' => :'treatyCountry',
    :'treaty_article' => :'treatyArticle',
    :'treaty_reasons' => :'treatyReasons',
    :'withholding_rate' => :'withholdingRate',
    :'income_type' => :'incomeType',
    :'signer_name' => :'signerName',
    :'e_delivery_consented_at' => :'eDeliveryConsentedAt',
    :'signature' => :'signature',
    :'company_id' => :'companyId',
    :'reference_id' => :'referenceId',
    :'email' => :'email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 557

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



229
230
231
232
233
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 229

def self.openapi_all_of
  [
  :'W9FormBaseRequest'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 204

def self.openapi_nullable
  Set.new([
    :'residence_state',
    :'mailing_address',
    :'mailing_city',
    :'mailing_state',
    :'mailing_zip',
    :'mailing_country',
    :'tin',
    :'foreign_tin',
    :'reference_number',
    :'birthday',
    :'treaty_article',
    :'treaty_reasons',
    :'withholding_rate',
    :'income_type',
    :'signer_name',
    :'e_delivery_consented_at',
    :'signature',
    :'reference_id',
    :'email'
  ])
end

.openapi_typesObject

Attribute type mapping.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 168

def self.openapi_types
  {
    :'type' => :'String',
    :'name' => :'String',
    :'citizenship_country' => :'String',
    :'residence_address' => :'String',
    :'residence_city' => :'String',
    :'residence_state' => :'String',
    :'residence_zip' => :'String',
    :'residence_country' => :'String',
    :'residence_is_mailing' => :'Boolean',
    :'mailing_address' => :'String',
    :'mailing_city' => :'String',
    :'mailing_state' => :'String',
    :'mailing_zip' => :'String',
    :'mailing_country' => :'String',
    :'tin' => :'String',
    :'foreign_tin_not_required' => :'Boolean',
    :'foreign_tin' => :'String',
    :'reference_number' => :'String',
    :'birthday' => :'Date',
    :'treaty_country' => :'String',
    :'treaty_article' => :'String',
    :'treaty_reasons' => :'String',
    :'withholding_rate' => :'String',
    :'income_type' => :'String',
    :'signer_name' => :'String',
    :'e_delivery_consented_at' => :'Time',
    :'signature' => :'String',
    :'company_id' => :'String',
    :'reference_id' => :'String',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 507

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      name == o.name &&
      citizenship_country == o.citizenship_country &&
      residence_address == o.residence_address &&
      residence_city == o.residence_city &&
      residence_state == o.residence_state &&
      residence_zip == o.residence_zip &&
      residence_country == o.residence_country &&
      residence_is_mailing == o.residence_is_mailing &&
      mailing_address == o.mailing_address &&
      mailing_city == o.mailing_city &&
      mailing_state == o.mailing_state &&
      mailing_zip == o.mailing_zip &&
      mailing_country == o.mailing_country &&
      tin == o.tin &&
      foreign_tin_not_required == o.foreign_tin_not_required &&
      foreign_tin == o.foreign_tin &&
      reference_number == o.reference_number &&
      birthday == o.birthday &&
      treaty_country == o.treaty_country &&
      treaty_article == o.treaty_article &&
      treaty_reasons == o.treaty_reasons &&
      withholding_rate == o.withholding_rate &&
      income_type == o.income_type &&
      signer_name == o.signer_name &&
      e_delivery_consented_at == o.e_delivery_consented_at &&
      signature == o.signature &&
      company_id == o.company_id &&
      reference_id == o.reference_id &&
      email == o.email
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



652
653
654
655
656
657
658
659
660
661
662
663
664
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 652

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


544
545
546
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 544

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



550
551
552
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 550

def hash
  [type, name, citizenship_country, residence_address, residence_city, residence_state, residence_zip, residence_country, residence_is_mailing, mailing_address, mailing_city, mailing_state, mailing_zip, mailing_country, tin, foreign_tin_not_required, foreign_tin, reference_number, birthday, treaty_country, treaty_article, treaty_reasons, withholding_rate, income_type, signer_name, e_delivery_consented_at, signature, company_id, reference_id, email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 381

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @citizenship_country.nil?
    invalid_properties.push('invalid value for "citizenship_country", citizenship_country cannot be nil.')
  end

  if @residence_country.nil?
    invalid_properties.push('invalid value for "residence_country", residence_country cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



628
629
630
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 628

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



634
635
636
637
638
639
640
641
642
643
644
645
646
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 634

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



622
623
624
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 622

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/avalara_sdk/models/A1099/V2/w8_ben_form_request.rb', line 401

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["W4", "W8Ben", "W8BenE", "W8Imy", "W9"])
  return false unless type_validator.valid?(@type)
  return false if @name.nil?
  return false if @citizenship_country.nil?
  citizenship_country_validator = EnumAttributeValidator.new('String', ["US", "AF", "AX", "AL", "AG", "AQ", "AN", "AO", "AV", "AY", "AC", "AR", "AM", "AA", "AT", "AS", "AU", "AJ", "BF", "BA", "FQ", "BG", "BB", "BO", "BE", "BH", "BN", "BD", "BT", "BL", "BK", "BC", "BV", "BR", "IO", "VI", "BX", "BU", "UV", "BM", "BY", "CB", "CM", "CA", "CV", "CJ", "CT", "CD", "CI", "CH", "KT", "IP", "CK", "CO", "CN", "CF", "CG", "CW", "CR", "CS", "IV", "HR", "CU", "UC", "CY", "EZ", "DA", "DX", "DJ", "DO", "DR", "TT", "EC", "EG", "ES", "EK", "ER", "EN", "ET", "FK", "FO", "FM", "FJ", "FI", "FR", "FP", "FS", "GB", "GA", "GG", "GM", "GH", "GI", "GR", "GL", "GJ", "GQ", "GT", "GK", "GV", "PU", "GY", "HA", "HM", "VT", "HO", "HK", "HQ", "HU", "IC", "IN", "ID", "IR", "IZ", "EI", "IS", "IT", "JM", "JN", "JA", "DQ", "JE", "JQ", "JO", "KZ", "KE", "KQ", "KR", "KN", "KS", "KV", "KU", "KG", "LA", "LG", "LE", "LT", "LI", "LY", "LS", "LH", "LU", "MC", "MK", "MA", "MI", "MY", "MV", "ML", "MT", "IM", "RM", "MR", "MP", "MX", "MQ", "MD", "MN", "MG", "MJ", "MH", "MO", "MZ", "WA", "NR", "BQ", "NP", "NL", "NC", "NZ", "NU", "NG", "NI", "NE", "NF", "CQ", "NO", "MU", "OC", "PK", "PS", "LQ", "PM", "PP", "PF", "PA", "PE", "RP", "PC", "PL", "PO", "RQ", "QA", "RO", "RS", "RW", "TB", "RN", "WS", "SM", "TP", "SA", "SG", "RI", "SE", "SL", "SN", "NN", "LO", "SI", "BP", "SO", "SF", "SX", "SP", "PG", "CE", "SH", "SC", "ST", "SB", "VC", "SU", "NS", "SV", "WZ", "SW", "SZ", "SY", "TW", "TI", "TZ", "TH", "TO", "TL", "TN", "TD", "TS", "TU", "TX", "TK", "TV", "UG", "UP", "AE", "UK", "UY", "UZ", "NH", "VE", "VM", "VQ", "WQ", "WF", "WI", "YM", "ZA", "ZI"])
  return false unless citizenship_country_validator.valid?(@citizenship_country)
  residence_state_validator = EnumAttributeValidator.new('String', ["AA", "AE", "AK", "AL", "AP", "AR", "AS", "AZ", "CA", "CO", "CT", "DC", "DE", "FL", "FM", "GA", "GU", "HI", "IA", "ID", "IL", "IN", "KS", "KY", "LA", "MA", "MD", "ME", "MH", "MI", "MN", "MO", "MP", "MS", "MT", "NC", "ND", "NE", "NH", "NJ", "NM", "NV", "NY", "OH", "OK", "OR", "PA", "PR", "PW", "RI", "SC", "SD", "TN", "TX", "UT", "VA", "VI", "VT", "WA", "WI", "WV", "WY", "AB", "BC", "MB", "NB", "NL", "NS", "NT", "NU", "ON", "PE", "QC", "SK", "YT"])
  return false unless residence_state_validator.valid?(@residence_state)
  return false if @residence_country.nil?
  residence_country_validator = EnumAttributeValidator.new('String', ["US", "AF", "AX", "AL", "AG", "AQ", "AN", "AO", "AV", "AY", "AC", "AR", "AM", "AA", "AT", "AS", "AU", "AJ", "BF", "BA", "FQ", "BG", "BB", "BO", "BE", "BH", "BN", "BD", "BT", "BL", "BK", "BC", "BV", "BR", "IO", "VI", "BX", "BU", "UV", "BM", "BY", "CB", "CM", "CA", "CV", "CJ", "CT", "CD", "CI", "CH", "KT", "IP", "CK", "CO", "CN", "CF", "CG", "CW", "CR", "CS", "IV", "HR", "CU", "UC", "CY", "EZ", "DA", "DX", "DJ", "DO", "DR", "TT", "EC", "EG", "ES", "EK", "ER", "EN", "ET", "FK", "FO", "FM", "FJ", "FI", "FR", "FP", "FS", "GB", "GA", "GG", "GM", "GH", "GI", "GR", "GL", "GJ", "GQ", "GT", "GK", "GV", "PU", "GY", "HA", "HM", "VT", "HO", "HK", "HQ", "HU", "IC", "IN", "ID", "IR", "IZ", "EI", "IS", "IT", "JM", "JN", "JA", "DQ", "JE", "JQ", "JO", "KZ", "KE", "KQ", "KR", "KN", "KS", "KV", "KU", "KG", "LA", "LG", "LE", "LT", "LI", "LY", "LS", "LH", "LU", "MC", "MK", "MA", "MI", "MY", "MV", "ML", "MT", "IM", "RM", "MR", "MP", "MX", "MQ", "MD", "MN", "MG", "MJ", "MH", "MO", "MZ", "WA", "NR", "BQ", "NP", "NL", "NC", "NZ", "NU", "NG", "NI", "NE", "NF", "CQ", "NO", "MU", "OC", "PK", "PS", "LQ", "PM", "PP", "PF", "PA", "PE", "RP", "PC", "PL", "PO", "RQ", "QA", "RO", "RS", "RW", "TB", "RN", "WS", "SM", "TP", "SA", "SG", "RI", "SE", "SL", "SN", "NN", "LO", "SI", "BP", "SO", "SF", "SX", "SP", "PG", "CE", "SH", "SC", "ST", "SB", "VC", "SU", "NS", "SV", "WZ", "SW", "SZ", "SY", "TW", "TI", "TZ", "TH", "TO", "TL", "TN", "TD", "TS", "TU", "TX", "TK", "TV", "UG", "UP", "AE", "UK", "UY", "UZ", "NH", "VE", "VM", "VQ", "WQ", "WF", "WI", "YM", "ZA", "ZI"])
  return false unless residence_country_validator.valid?(@residence_country)
  mailing_state_validator = EnumAttributeValidator.new('String', ["AA", "AE", "AK", "AL", "AP", "AR", "AS", "AZ", "CA", "CO", "CT", "DC", "DE", "FL", "FM", "GA", "GU", "HI", "IA", "ID", "IL", "IN", "KS", "KY", "LA", "MA", "MD", "ME", "MH", "MI", "MN", "MO", "MP", "MS", "MT", "NC", "ND", "NE", "NH", "NJ", "NM", "NV", "NY", "OH", "OK", "OR", "PA", "PR", "PW", "RI", "SC", "SD", "TN", "TX", "UT", "VA", "VI", "VT", "WA", "WI", "WV", "WY", "AB", "BC", "MB", "NB", "NL", "NS", "NT", "NU", "ON", "PE", "QC", "SK", "YT"])
  return false unless mailing_state_validator.valid?(@mailing_state)
  mailing_country_validator = EnumAttributeValidator.new('String', ["US", "AF", "AX", "AL", "AG", "AQ", "AN", "AO", "AV", "AY", "AC", "AR", "AM", "AA", "AT", "AS", "AU", "AJ", "BF", "BA", "FQ", "BG", "BB", "BO", "BE", "BH", "BN", "BD", "BT", "BL", "BK", "BC", "BV", "BR", "IO", "VI", "BX", "BU", "UV", "BM", "BY", "CB", "CM", "CA", "CV", "CJ", "CT", "CD", "CI", "CH", "KT", "IP", "CK", "CO", "CN", "CF", "CG", "CW", "CR", "CS", "IV", "HR", "CU", "UC", "CY", "EZ", "DA", "DX", "DJ", "DO", "DR", "TT", "EC", "EG", "ES", "EK", "ER", "EN", "ET", "FK", "FO", "FM", "FJ", "FI", "FR", "FP", "FS", "GB", "GA", "GG", "GM", "GH", "GI", "GR", "GL", "GJ", "GQ", "GT", "GK", "GV", "PU", "GY", "HA", "HM", "VT", "HO", "HK", "HQ", "HU", "IC", "IN", "ID", "IR", "IZ", "EI", "IS", "IT", "JM", "JN", "JA", "DQ", "JE", "JQ", "JO", "KZ", "KE", "KQ", "KR", "KN", "KS", "KV", "KU", "KG", "LA", "LG", "LE", "LT", "LI", "LY", "LS", "LH", "LU", "MC", "MK", "MA", "MI", "MY", "MV", "ML", "MT", "IM", "RM", "MR", "MP", "MX", "MQ", "MD", "MN", "MG", "MJ", "MH", "MO", "MZ", "WA", "NR", "BQ", "NP", "NL", "NC", "NZ", "NU", "NG", "NI", "NE", "NF", "CQ", "NO", "MU", "OC", "PK", "PS", "LQ", "PM", "PP", "PF", "PA", "PE", "RP", "PC", "PL", "PO", "RQ", "QA", "RO", "RS", "RW", "TB", "RN", "WS", "SM", "TP", "SA", "SG", "RI", "SE", "SL", "SN", "NN", "LO", "SI", "BP", "SO", "SF", "SX", "SP", "PG", "CE", "SH", "SC", "ST", "SB", "VC", "SU", "NS", "SV", "WZ", "SW", "SZ", "SY", "TW", "TI", "TZ", "TH", "TO", "TL", "TN", "TD", "TS", "TU", "TX", "TK", "TV", "UG", "UP", "AE", "UK", "UY", "UZ", "NH", "VE", "VM", "VQ", "WQ", "WF", "WI", "YM", "ZA", "ZI"])
  return false unless mailing_country_validator.valid?(@mailing_country)
  treaty_country_validator = EnumAttributeValidator.new('String', ["US", "AF", "AX", "AL", "AG", "AQ", "AN", "AO", "AV", "AY", "AC", "AR", "AM", "AA", "AT", "AS", "AU", "AJ", "BF", "BA", "FQ", "BG", "BB", "BO", "BE", "BH", "BN", "BD", "BT", "BL", "BK", "BC", "BV", "BR", "IO", "VI", "BX", "BU", "UV", "BM", "BY", "CB", "CM", "CA", "CV", "CJ", "CT", "CD", "CI", "CH", "KT", "IP", "CK", "CO", "CN", "CF", "CG", "CW", "CR", "CS", "IV", "HR", "CU", "UC", "CY", "EZ", "DA", "DX", "DJ", "DO", "DR", "TT", "EC", "EG", "ES", "EK", "ER", "EN", "ET", "FK", "FO", "FM", "FJ", "FI", "FR", "FP", "FS", "GB", "GA", "GG", "GM", "GH", "GI", "GR", "GL", "GJ", "GQ", "GT", "GK", "GV", "PU", "GY", "HA", "HM", "VT", "HO", "HK", "HQ", "HU", "IC", "IN", "ID", "IR", "IZ", "EI", "IS", "IT", "JM", "JN", "JA", "DQ", "JE", "JQ", "JO", "KZ", "KE", "KQ", "KR", "KN", "KS", "KV", "KU", "KG", "LA", "LG", "LE", "LT", "LI", "LY", "LS", "LH", "LU", "MC", "MK", "MA", "MI", "MY", "MV", "ML", "MT", "IM", "RM", "MR", "MP", "MX", "MQ", "MD", "MN", "MG", "MJ", "MH", "MO", "MZ", "WA", "NR", "BQ", "NP", "NL", "NC", "NZ", "NU", "NG", "NI", "NE", "NF", "CQ", "NO", "MU", "OC", "PK", "PS", "LQ", "PM", "PP", "PF", "PA", "PE", "RP", "PC", "PL", "PO", "RQ", "QA", "RO", "RS", "RW", "TB", "RN", "WS", "SM", "TP", "SA", "SG", "RI", "SE", "SL", "SN", "NN", "LO", "SI", "BP", "SO", "SF", "SX", "SP", "PG", "CE", "SH", "SC", "ST", "SB", "VC", "SU", "NS", "SV", "WZ", "SW", "SZ", "SY", "TW", "TI", "TZ", "TH", "TO", "TL", "TN", "TD", "TS", "TU", "TX", "TK", "TV", "UG", "UP", "AE", "UK", "UY", "UZ", "NH", "VE", "VM", "VQ", "WQ", "WF", "WI", "YM", "ZA", "ZI"])
  return false unless treaty_country_validator.valid?(@treaty_country)
  withholding_rate_validator = EnumAttributeValidator.new('String', ["0", "0.0", "0.00", "5", "5.5", "10", "12.50", "15", "20", "25", "30"])
  return false unless withholding_rate_validator.valid?(@withholding_rate)
  true
end