Class: AvalaraSdk::A1099::V2::W9FormBaseResponse
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::W9FormBaseResponse
- Defined in:
- lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ancestor_id ⇒ Object
Form ID of previous version.
-
#archived ⇒ Object
Indicates whether the form is archived.
-
#company_id ⇒ Object
The ID of the associated company.
-
#created_at ⇒ Object
The creation date of the form.
-
#display_name ⇒ Object
The display name associated with the form.
-
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
-
#email ⇒ Object
The email address of the individual associated with the form.
-
#entry_status ⇒ Object
The entry status information for the form.
-
#id ⇒ Object
The unique identifier for the form.
-
#reference_id ⇒ Object
A reference identifier for the form.
-
#signature ⇒ Object
The signature of the form.
-
#signed_date ⇒ Object
The date the form was signed.
-
#type ⇒ Object
The form type.
-
#updated_at ⇒ Object
The last updated date of the form.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ W9FormBaseResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ W9FormBaseResponse
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::W9FormBaseResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::W9FormBaseResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'entry_status') self.entry_status = attributes[:'entry_status'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'archived') self.archived = attributes[:'archived'] end if attributes.key?(:'ancestor_id') self.ancestor_id = attributes[:'ancestor_id'] end if attributes.key?(:'signature') self.signature = attributes[:'signature'] end if attributes.key?(:'signed_date') self.signed_date = attributes[:'signed_date'] end if attributes.key?(:'e_delivery_consented_at') self. = attributes[:'e_delivery_consented_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#ancestor_id ⇒ Object
Form ID of previous version.
39 40 41 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 39 def ancestor_id @ancestor_id end |
#archived ⇒ Object
Indicates whether the form is archived.
36 37 38 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 36 def archived @archived end |
#company_id ⇒ Object
The ID of the associated company.
27 28 29 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 27 def company_id @company_id end |
#created_at ⇒ Object
The creation date of the form.
51 52 53 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 51 def created_at @created_at end |
#display_name ⇒ Object
The display name associated with the form.
30 31 32 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 30 def display_name @display_name end |
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
48 49 50 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 48 def @e_delivery_consented_at end |
#email ⇒ Object
The email address of the individual associated with the form.
33 34 35 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 33 def email @email end |
#entry_status ⇒ Object
The entry status information for the form.
21 22 23 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 21 def entry_status @entry_status end |
#id ⇒ Object
The unique identifier for the form.
18 19 20 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 18 def id @id end |
#reference_id ⇒ Object
A reference identifier for the form.
24 25 26 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 24 def reference_id @reference_id end |
#signature ⇒ Object
The signature of the form.
42 43 44 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 42 def signature @signature end |
#signed_date ⇒ Object
The date the form was signed.
45 46 47 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 45 def signed_date @signed_date end |
#type ⇒ Object
The form type.
15 16 17 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 15 def type @type end |
#updated_at ⇒ Object
The last updated date of the form.
54 55 56 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 54 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 294 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 99 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 79 def self.attribute_map { :'type' => :'type', :'id' => :'id', :'entry_status' => :'entryStatus', :'reference_id' => :'referenceId', :'company_id' => :'companyId', :'display_name' => :'displayName', :'email' => :'email', :'archived' => :'archived', :'ancestor_id' => :'ancestorId', :'signature' => :'signature', :'signed_date' => :'signedDate', :'e_delivery_consented_at' => :'eDeliveryConsentedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
124 125 126 127 128 129 130 131 132 133 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 124 def self.openapi_nullable Set.new([ :'reference_id', :'email', :'ancestor_id', :'signature', :'signed_date', :'e_delivery_consented_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 104 def self.openapi_types { :'type' => :'String', :'id' => :'String', :'entry_status' => :'EntryStatusResponse', :'reference_id' => :'String', :'company_id' => :'String', :'display_name' => :'String', :'email' => :'String', :'archived' => :'Boolean', :'ancestor_id' => :'String', :'signature' => :'String', :'signed_date' => :'Time', :'e_delivery_consented_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && id == o.id && entry_status == o.entry_status && reference_id == o.reference_id && company_id == o.company_id && display_name == o.display_name && email == o.email && archived == o.archived && ancestor_id == o.ancestor_id && signature == o.signature && signed_date == o.signed_date && == o. && created_at == o.created_at && updated_at == o.updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 365 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 263 def hash [type, id, entry_status, reference_id, company_id, display_name, email, archived, ancestor_id, signature, signed_date, , created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
341 342 343 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 341 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 347 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
335 336 337 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 335 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_base_response.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["W4", "W8Ben", "W8BenE", "W8Imy", "W9"]) return false unless type_validator.valid?(@type) true end |