Class: AvalaraSdk::A1099::V2::W9FormRequest
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::W9FormRequest
- Defined in:
- lib/avalara_sdk/models/A1099/V2/w9_form_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_number ⇒ Object
The account number associated with the form.
-
#address ⇒ Object
The address of the individual or entity.
-
#backup_withholding ⇒ Object
Indicates whether backup withholding applies.
-
#business_classification ⇒ Object
The classification of the business.
-
#business_name ⇒ Object
The name of the business associated with the form.
-
#business_other ⇒ Object
The classification description when "businessClassification" is "Other".
-
#city ⇒ Object
The city of the address.
-
#company_id ⇒ Object
The ID of the associated company.
-
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
-
#email ⇒ Object
The email address of the individual associated with the form.
-
#exempt_fatca_code ⇒ Object
The exemption from FATCA reporting code.
-
#exempt_payee_code ⇒ Object
The exempt payee code.
-
#foreign_address ⇒ Object
The foreign address of the individual or entity.
-
#foreign_country_indicator ⇒ Object
Indicates whether the individual or entity is in a foreign country.
-
#foreign_partner_owner_or_beneficiary ⇒ Object
Indicates whether the individual is a foreign partner, owner, or beneficiary.
-
#is1099able ⇒ Object
Indicates whether the individual or entity should be issued a 1099 form.
-
#name ⇒ Object
The name of the individual or entity associated with the form.
-
#reference_id ⇒ Object
A reference identifier for the form.
-
#signature ⇒ Object
The signature of the form.
-
#state ⇒ Object
The state of the address.
-
#tin ⇒ Object
The taxpayer identification number (TIN).
-
#tin_type ⇒ Object
Tax Identification Number (TIN) type.
-
#type ⇒ Object
The form type (always "w9" for this model).
-
#zip ⇒ Object
The ZIP code of the address.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ W9FormRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ W9FormRequest
Initializes the object
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 201 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::W9FormRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::W9FormRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] end if attributes.key?(:'business_classification') self.business_classification = attributes[:'business_classification'] else self.business_classification = nil end if attributes.key?(:'business_other') self.business_other = attributes[:'business_other'] end if attributes.key?(:'foreign_partner_owner_or_beneficiary') self.foreign_partner_owner_or_beneficiary = attributes[:'foreign_partner_owner_or_beneficiary'] end if attributes.key?(:'exempt_payee_code') self.exempt_payee_code = attributes[:'exempt_payee_code'] end if attributes.key?(:'exempt_fatca_code') self.exempt_fatca_code = attributes[:'exempt_fatca_code'] end if attributes.key?(:'foreign_country_indicator') self.foreign_country_indicator = attributes[:'foreign_country_indicator'] end if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'foreign_address') self.foreign_address = attributes[:'foreign_address'] end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'zip') self.zip = attributes[:'zip'] else self.zip = nil end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] end if attributes.key?(:'tin_type') self.tin_type = attributes[:'tin_type'] else self.tin_type = nil end if attributes.key?(:'tin') self.tin = attributes[:'tin'] else self.tin = nil end if attributes.key?(:'backup_withholding') self.backup_withholding = attributes[:'backup_withholding'] end if attributes.key?(:'is1099able') self.is1099able = attributes[:'is1099able'] end if attributes.key?(:'e_delivery_consented_at') self. = attributes[:'e_delivery_consented_at'] end if attributes.key?(:'signature') self.signature = attributes[:'signature'] end if attributes.key?(:'company_id') self.company_id = attributes[:'company_id'] end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'email') self.email = attributes[:'email'] end end |
Instance Attribute Details
#account_number ⇒ Object
The account number associated with the form.
57 58 59 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 57 def account_number @account_number end |
#address ⇒ Object
The address of the individual or entity.
42 43 44 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 42 def address @address end |
#backup_withholding ⇒ Object
Indicates whether backup withholding applies.
66 67 68 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 66 def backup_withholding @backup_withholding end |
#business_classification ⇒ Object
The classification of the business. Available values: - Individual: Individual/sole proprietor - C Corporation: C Corporation - S Corporation: S Corporation - Partnership: Partnership - Trust/estate: Trust/estate - LLC-C: Limited liability company (C Corporation) - LLC-S: Limited liability company (S Corporation) - LLC-P: Limited liability company (Partnership) - Other: Other (requires BusinessOther field to be populated)
24 25 26 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 24 def business_classification @business_classification end |
#business_name ⇒ Object
The name of the business associated with the form.
21 22 23 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 21 def business_name @business_name end |
#business_other ⇒ Object
The classification description when "businessClassification" is "Other".
27 28 29 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 27 def business_other @business_other end |
#city ⇒ Object
The city of the address.
48 49 50 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 48 def city @city end |
#company_id ⇒ Object
The ID of the associated company. Required when creating a form.
78 79 80 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 78 def company_id @company_id end |
#e_delivery_consented_at ⇒ Object
The date when e-delivery was consented.
72 73 74 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 72 def @e_delivery_consented_at end |
#email ⇒ Object
The email address of the individual associated with the form.
84 85 86 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 84 def email @email end |
#exempt_fatca_code ⇒ Object
The exemption from FATCA reporting code. Allowed values (A–M): - A — Tax‑exempt organization under 501(a) or IRA (7701(a)(37)) - B — U.S. government or any of its agencies/instrumentalities - C — U.S. state, DC, territory/possession, or their political subdivisions/instrumentalities - D — Corporation whose stock is regularly traded on an established securities market - E — Corporation that is a member of the same expanded affiliated group as a D corporation - F — Registered dealer in securities/commodities/derivatives - G — REIT (Real Estate Investment Trust) - H — Regulated investment company (851) or entity registered all year under the Investment Company Act of 1940 - I — Common trust fund (584(a)) - J — Bank (581) - K — Broker - L — Charitable remainder trust (664) or trust described in 4947(a)(1) - M — Trust under 403(b) plan or 457(g) plan
36 37 38 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 36 def exempt_fatca_code @exempt_fatca_code end |
#exempt_payee_code ⇒ Object
The exempt payee code. Allowed values (1–13): - 1 — Organization exempt under 501(a) or IRA; custodial account under 403(b)(7) - 2 — U.S. government or its agencies/instrumentalities - 3 — U.S. state, DC, U.S. territory/possession, or their political subdivisions/agencies/instrumentalities - 4 — Foreign government or its political subdivisions/agencies/instrumentalities - 5 — Corporation - 6 — Dealer in securities or commodities required to register in the U.S., DC, or U.S. territory/possession - 7 — Futures commission merchant registered with the CFTC - 8 — Real estate investment trust (REIT) - 9 — Entity registered at all times during the tax year under the Investment Company Act of 1940 - 10 — Common trust fund operated by a bank under 584(a) - 11 — Financial institution (see 581) - 12 — Broker (nominee/custodian) - 13 — Trust exempt under 664 or described in 4947
33 34 35 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 33 def exempt_payee_code @exempt_payee_code end |
#foreign_address ⇒ Object
The foreign address of the individual or entity.
45 46 47 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 45 def foreign_address @foreign_address end |
#foreign_country_indicator ⇒ Object
Indicates whether the individual or entity is in a foreign country.
39 40 41 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 39 def foreign_country_indicator @foreign_country_indicator end |
#foreign_partner_owner_or_beneficiary ⇒ Object
Indicates whether the individual is a foreign partner, owner, or beneficiary.
30 31 32 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 30 def foreign_partner_owner_or_beneficiary @foreign_partner_owner_or_beneficiary end |
#is1099able ⇒ Object
Indicates whether the individual or entity should be issued a 1099 form.
69 70 71 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 69 def is1099able @is1099able end |
#name ⇒ Object
The name of the individual or entity associated with the form.
18 19 20 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 18 def name @name end |
#reference_id ⇒ Object
A reference identifier for the form.
81 82 83 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 81 def reference_id @reference_id end |
#signature ⇒ Object
The signature of the form.
75 76 77 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 75 def signature @signature end |
#state ⇒ Object
The state of the address.
51 52 53 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 51 def state @state end |
#tin ⇒ Object
The taxpayer identification number (TIN).
63 64 65 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 63 def tin @tin end |
#tin_type ⇒ Object
Tax Identification Number (TIN) type. SSN/ITIN (for individuals) and EIN (for businesses).
60 61 62 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 60 def tin_type @tin_type end |
#type ⇒ Object
The form type (always "w9" for this model).
15 16 17 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 15 def type @type end |
#zip ⇒ Object
The ZIP code of the address.
54 55 56 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 54 def zip @zip end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 473 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
139 140 141 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 139 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 109 def self.attribute_map { :'type' => :'type', :'name' => :'name', :'business_name' => :'businessName', :'business_classification' => :'businessClassification', :'business_other' => :'businessOther', :'foreign_partner_owner_or_beneficiary' => :'foreignPartnerOwnerOrBeneficiary', :'exempt_payee_code' => :'exemptPayeeCode', :'exempt_fatca_code' => :'exemptFatcaCode', :'foreign_country_indicator' => :'foreignCountryIndicator', :'address' => :'address', :'foreign_address' => :'foreignAddress', :'city' => :'city', :'state' => :'state', :'zip' => :'zip', :'account_number' => :'accountNumber', :'tin_type' => :'tinType', :'tin' => :'tin', :'backup_withholding' => :'backupWithholding', :'is1099able' => :'is1099able', :'e_delivery_consented_at' => :'eDeliveryConsentedAt', :'signature' => :'signature', :'company_id' => :'companyId', :'reference_id' => :'referenceId', :'email' => :'email' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 449 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
193 194 195 196 197 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 193 def self.openapi_all_of [ :'W9FormBaseRequest' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 174 def self.openapi_nullable Set.new([ :'business_name', :'business_other', :'exempt_payee_code', :'exempt_fatca_code', :'foreign_address', :'city', :'state', :'zip', :'account_number', :'e_delivery_consented_at', :'signature', :'reference_id', :'email' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 144 def self.openapi_types { :'type' => :'String', :'name' => :'String', :'business_name' => :'String', :'business_classification' => :'String', :'business_other' => :'String', :'foreign_partner_owner_or_beneficiary' => :'Boolean', :'exempt_payee_code' => :'String', :'exempt_fatca_code' => :'String', :'foreign_country_indicator' => :'Boolean', :'address' => :'String', :'foreign_address' => :'String', :'city' => :'String', :'state' => :'String', :'zip' => :'String', :'account_number' => :'String', :'tin_type' => :'String', :'tin' => :'String', :'backup_withholding' => :'Boolean', :'is1099able' => :'Boolean', :'e_delivery_consented_at' => :'Time', :'signature' => :'String', :'company_id' => :'String', :'reference_id' => :'String', :'email' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 405 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && name == o.name && business_name == o.business_name && business_classification == o.business_classification && business_other == o.business_other && foreign_partner_owner_or_beneficiary == o.foreign_partner_owner_or_beneficiary && exempt_payee_code == o.exempt_payee_code && exempt_fatca_code == o.exempt_fatca_code && foreign_country_indicator == o.foreign_country_indicator && address == o.address && foreign_address == o.foreign_address && city == o.city && state == o.state && zip == o.zip && account_number == o.account_number && tin_type == o.tin_type && tin == o.tin && backup_withholding == o.backup_withholding && is1099able == o.is1099able && == o. && signature == o.signature && company_id == o.company_id && reference_id == o.reference_id && email == o.email end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
544 545 546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 544 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
436 437 438 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 436 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
442 443 444 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 442 def hash [type, name, business_name, business_classification, business_other, foreign_partner_owner_or_beneficiary, exempt_payee_code, exempt_fatca_code, foreign_country_indicator, address, foreign_address, city, state, zip, account_number, tin_type, tin, backup_withholding, is1099able, , signature, company_id, reference_id, email].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 329 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @business_classification.nil? invalid_properties.push('invalid value for "business_classification", business_classification cannot be nil.') end if @address.nil? invalid_properties.push('invalid value for "address", address cannot be nil.') end if @tin_type.nil? invalid_properties.push('invalid value for "tin_type", tin_type cannot be nil.') end if @tin.nil? invalid_properties.push('invalid value for "tin", tin cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
520 521 522 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 520 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 526 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
514 515 516 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 514 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/avalara_sdk/models/A1099/V2/w9_form_request.rb', line 357 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["W4", "W8Ben", "W8BenE", "W8Imy", "W9"]) return false unless type_validator.valid?(@type) return false if @name.nil? return false if @business_classification.nil? business_classification_validator = EnumAttributeValidator.new('String', ["Individual", "CCorporation", "SCorporation", "Partnership", "TrustEstate", "LlcC", "LlcS", "LlcP", "Other"]) return false unless business_classification_validator.valid?(@business_classification) return false if @address.nil? state_validator = EnumAttributeValidator.new('String', ["AA", "AE", "AK", "AL", "AP", "AR", "AS", "AZ", "CA", "CO", "CT", "DC", "DE", "FL", "FM", "GA", "GU", "HI", "IA", "ID", "IL", "IN", "KS", "KY", "LA", "MA", "MD", "ME", "MH", "MI", "MN", "MO", "MP", "MS", "MT", "NC", "ND", "NE", "NH", "NJ", "NM", "NV", "NY", "OH", "OK", "OR", "PA", "PR", "PW", "RI", "SC", "SD", "TN", "TX", "UT", "VA", "VI", "VT", "WA", "WI", "WV", "WY"]) return false unless state_validator.valid?(@state) return false if @tin_type.nil? return false if @tin.nil? true end |