Class: AvalaraSdk::EInvoicing::V1::DocumentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client) ⇒ DocumentsApi

Returns a new instance of DocumentsApi.



16
17
18
19
20
21
22
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 16

def initialize(api_client)
  if (api_client.nil?)
    fail  ArgumentError,'api_client is nil'
  end
  api_client.set_sdk_version("26.4.0")
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



14
15
16
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 14

def api_client
  @api_client
end

Instance Method Details

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 210

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as typhoeus will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#convert_to_type(data, return_type) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 91

def convert_to_type(data, return_type)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'Time'
    # parse date time (expecting ISO 8601 format)
    Time.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type) }
    end
  else
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::EInvoicing::V1.const_get(return_type)
    klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data)
  end
end

#deserialize(response, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array<User>”, “Hash<String, Integer>”



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 39

def deserialize(response, return_type)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  if return_type == 'File'
    content_disposition = response.headers['Content-Disposition']
    if content_disposition && content_disposition =~ /filename=/i
      filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
      prefix = sanitize_filename(filename)
    else
      prefix = 'download-'
    end
    prefix = prefix + '-' unless prefix.end_with?('-')
    encoding = body.encoding
    @tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
    @tempfile.write(@stream.join.force_encoding(encoding))
    @tempfile.close
    @config.logger.info "Temp file written to #{@tempfile.path}, please copy the file to a proper folder "\
                        "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                        "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                        "explicitly with `tempfile.delete`"
    return @tempfile
  end

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date Time).include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type
end

#download_document(request_parameters) ⇒ File

Returns a copy of the document Downloads the document when it is available. Specify the output format in the Accept header. Returns 404 if the file has not been created.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param accept [String] Header that specifies the MIME type of the returned document. # @param document_id [String] The unique documentId returned in the POST /documents response body. # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:

  • (File)


232
233
234
235
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 232

def download_document(request_parameters)
  data, _status_code, _headers = download_document_with_http_info(request_parameters)
  data
end

#download_document_with_http_info(request_parameters) ⇒ Array<(File, Integer, Hash)>

Returns File data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • accept (String)

    Header that specifies the MIME type of the returned document.

  • document_id (String)

    The unique documentId returned in the POST /documents response body.

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 245

def download_document_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  accept = request_parameters.get_accept()
  document_id = request_parameters.get_document_id()
  x_avalara_client = request_parameters.get_x_avalara_client()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling DocumentsApi.download_document"
  end
  # verify the required parameter 'accept' is set
  if @api_client.config.client_side_validation && accept.nil?
    fail ArgumentError, "Missing the required parameter 'accept' when calling DocumentsApi.download_document"
  end
  # verify the required parameter 'document_id' is set
  if @api_client.config.client_side_validation && document_id.nil?
    fail ArgumentError, "Missing the required parameter 'document_id' when calling DocumentsApi.download_document"
  end
  # resource path
  local_var_path = '/einvoicing/documents/{documentId}/$download'.sub('{' + 'documentId' + '}', CGI.escape(document_id.to_s))

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/pdf', 'application/xml', 'application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !accept.nil?
    header_params[:'Accept'] = accept
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'File'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"DocumentsApi.download_document",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#fetch_documents(request_parameters) ⇒ DocumentFetch

Fetch the inbound document from a tax authority Retrieves an inbound document. Provide key-value pairs as request parameters. Supported parameters vary by tax authority and country.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param fetch_documents_request [FetchDocumentsRequest] # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:



322
323
324
325
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 322

def fetch_documents(request_parameters)
  data, _status_code, _headers = fetch_documents_with_http_info(request_parameters)
  data
end

#fetch_documents_with_http_info(request_parameters) ⇒ Array<(DocumentFetch, Integer, Hash)>

Returns DocumentFetch data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • fetch_documents_request (FetchDocumentsRequest)
  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:

  • (Array<(DocumentFetch, Integer, Hash)>)

    DocumentFetch data, response status code and response headers



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 334

def fetch_documents_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  fetch_documents_request = request_parameters.get_fetch_documents_request()
  x_avalara_client = request_parameters.get_x_avalara_client()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling DocumentsApi.fetch_documents"
  end
  # verify the required parameter 'fetch_documents_request' is set
  if @api_client.config.client_side_validation && fetch_documents_request.nil?
    fail ArgumentError, "Missing the required parameter 'fetch_documents_request' when calling DocumentsApi.fetch_documents"
  end
  # resource path
  local_var_path = '/einvoicing/documents/$fetch'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body =  @api_client.object_to_http_body(fetch_documents_request) || {}

  # return_type
  return_type = 'DocumentFetch'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"DocumentsApi.fetch_documents",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:POST, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#get_document_list(request_parameters) ⇒ DocumentListResponse

Returns a summary of documents for a date range Returns a list of document summaries with a processing date within the specified date range.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;). # @param start_date [Time] Start date for documents to return. Defaults to the previous month. Format: &quot;YYYY-MM-DDThh:mm:ss&quot;. # @param end_date [Time] End date for documents to return. Defaults to the current date. Format: &quot;YYYY-MM-DDThh:mm:ss&quot;. # @param flow [String] Optional filter for document direction: issued uses &quot;out&quot; and received uses &quot;in&quot;. # @param count [String] When set to true, the response body also includes the count of items in the collection. # @param count_only [String] When set to true, the response returns only the count of items in the collection. # @param filter [String] Filter by field name and value. This filter supports only eq. For more information, refer to the Avalara filtering guide. # @param include [String] When set to &#x60;events&#x60;, each document in the response includes its events array. Omit this parameter or use any other value to exclude events from the response. # @param top [Integer] The number of items to include in the result. # @param skip [Integer] The number of items to skip in the result.

Returns:



408
409
410
411
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 408

def get_document_list(request_parameters)
  data, _status_code, _headers = get_document_list_with_http_info(request_parameters)
  data
end

#get_document_list_with_http_info(request_parameters) ⇒ Array<(DocumentListResponse, Integer, Hash)>

Returns DocumentListResponse data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

  • start_date (Time)

    Start date for documents to return. Defaults to the previous month. Format: &quot;YYYY-MM-DDThh:mm:ss&quot;.

  • end_date (Time)

    End date for documents to return. Defaults to the current date. Format: &quot;YYYY-MM-DDThh:mm:ss&quot;.

  • flow (String)

    Optional filter for document direction: issued uses &quot;out&quot; and received uses &quot;in&quot;.

  • count (String)

    When set to true, the response body also includes the count of items in the collection.

  • count_only (String)

    When set to true, the response returns only the count of items in the collection.

  • filter (String)

    Filter by field name and value. This filter supports only eq. For more information, refer to the Avalara filtering guide.

  • include (String)

    When set to &#x60;events&#x60;, each document in the response includes its events array. Omit this parameter or use any other value to exclude events from the response.

  • top (Integer)

    The number of items to include in the result.

  • skip (Integer)

    The number of items to skip in the result.

Returns:

  • (Array<(DocumentListResponse, Integer, Hash)>)

    DocumentListResponse data, response status code and response headers



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 428

def get_document_list_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  x_avalara_client = request_parameters.get_x_avalara_client()
  start_date = request_parameters.get_start_date()
  end_date = request_parameters.get_end_date()
  flow = request_parameters.get_flow()
  count = request_parameters.get_count()
  count_only = request_parameters.get_count_only()
  filter = request_parameters.get_filter()
  include = request_parameters.get_include()
  top = request_parameters.get_top()
  skip = request_parameters.get_skip()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling DocumentsApi.get_document_list"
  end
  # resource path
  local_var_path = '/einvoicing/documents'

  # query parameters
  query_params = {}
  if !start_date.nil?
    query_params[:'startDate'] = start_date
  end
  if !end_date.nil?
    query_params[:'endDate'] = end_date
  end
  if !flow.nil?
    query_params[:'flow'] = flow
  end
  if !count.nil?
    query_params[:'$count'] = count
  end
  if !count_only.nil?
    query_params[:'$countOnly'] = count_only
  end
  if !filter.nil?
    query_params[:'$filter'] = filter
  end
  if !include.nil?
    query_params[:'$include'] = include
  end
  if !top.nil?
    query_params[:'$top'] = top
  end
  if !skip.nil?
    query_params[:'$skip'] = skip
  end

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'DocumentListResponse'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"DocumentsApi.get_document_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#get_document_status(request_parameters) ⇒ DocumentStatusResponse

Checks the status of a document Uses the documentId from the POST /documents response body to return the current status of a document.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param document_id [String] The unique documentId returned in the POST /documents response body. # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:



528
529
530
531
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 528

def get_document_status(request_parameters)
  data, _status_code, _headers = get_document_status_with_http_info(request_parameters)
  data
end

#get_document_status_with_http_info(request_parameters) ⇒ Array<(DocumentStatusResponse, Integer, Hash)>

Returns DocumentStatusResponse data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • document_id (String)

    The unique documentId returned in the POST /documents response body.

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:

  • (Array<(DocumentStatusResponse, Integer, Hash)>)

    DocumentStatusResponse data, response status code and response headers



540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 540

def get_document_status_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  document_id = request_parameters.get_document_id()
  x_avalara_client = request_parameters.get_x_avalara_client()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling DocumentsApi.get_document_status"
  end
  # verify the required parameter 'document_id' is set
  if @api_client.config.client_side_validation && document_id.nil?
    fail ArgumentError, "Missing the required parameter 'document_id' when calling DocumentsApi.get_document_status"
  end
  # resource path
  local_var_path = '/einvoicing/documents/{documentId}/status'.sub('{' + 'documentId' + '}', CGI.escape(document_id.to_s))

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'DocumentStatusResponse'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"DocumentsApi.get_document_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#json_mime?(mime) ⇒ Boolean

JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



31
32
33
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 31

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



200
201
202
203
204
205
206
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 200

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    obj.to_hash
  else
    obj
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



186
187
188
189
190
191
192
193
194
195
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 186

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



133
134
135
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 133

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



165
166
167
168
169
170
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 165

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



175
176
177
178
179
180
181
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 175

def select_header_content_type(content_types)
  # return nil by default
  return if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#submit_document(request_parameters) ⇒ DocumentSubmitResponse

Submits a document to Avalara E-Invoicing API When a UBL document is sent to this endpoint, it generates a document in the required format as mandated by the specified country. Additionally, it initiates the workflow to transmit the generated document to the relevant tax authority, if necessary.
The response from the endpoint contains a unique document ID, which can be used to request the status of the document and verify if it was successfully accepted at the destination.
Furthermore, the unique ID enables the download of a copy of the generated document for reference purposes.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param metadata [SubmitDocumentMetadata] # @param data [Object] The document to be submitted, as indicated by the metadata fields &#39;dataFormat&#39; and &#39;dataFormatVersion&#39; # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:



609
610
611
612
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 609

def submit_document(request_parameters)
  data, _status_code, _headers = submit_document_with_http_info(request_parameters)
  data
end

#submit_document_with_http_info(request_parameters) ⇒ Array<(DocumentSubmitResponse, Integer, Hash)>

Returns DocumentSubmitResponse data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • metadata (SubmitDocumentMetadata)
  • data (Object)

    The document to be submitted, as indicated by the metadata fields &#39;dataFormat&#39; and &#39;dataFormatVersion&#39;

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

Returns:

  • (Array<(DocumentSubmitResponse, Integer, Hash)>)

    DocumentSubmitResponse data, response status code and response headers



622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 622

def submit_document_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
   = request_parameters.()
  data = request_parameters.get_data()
  x_avalara_client = request_parameters.get_x_avalara_client()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling DocumentsApi.submit_document"
  end
  # verify the required parameter 'metadata' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'metadata' when calling DocumentsApi.submit_document"
  end
  # verify the required parameter 'data' is set
  if @api_client.config.client_side_validation && data.nil?
    fail ArgumentError, "Missing the required parameter 'data' when calling DocumentsApi.submit_document"
  end
  # resource path
  local_var_path = '/einvoicing/documents'

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'text/xml'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end

  # form parameters
  form_params = {}
  if !.nil?
    form_params['metadata'] = 
  end
  if !data.nil?
    form_params['data'] = data
  end

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'DocumentSubmitResponse'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"DocumentsApi.submit_document",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:POST, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update header and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 142

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` or `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



157
158
159
160
# File 'lib/avalara_sdk/api/EInvoicing/V1/documents_api.rb', line 157

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end