Class: AvalaraSdk::EInvoicing::V1::ReportItem

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/models/EInvoicing/V1/report_item.rb

Overview

Represents a single report with full details including metadata and associated transaction IDs.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReportItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::EInvoicing::V1::ReportItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::EInvoicing::V1::ReportItem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'report_id')
    self.report_id = attributes[:'report_id']
  end

  if attributes.key?(:'job_id')
    self.job_id = attributes[:'job_id']
  end

  if attributes.key?(:'report_generate_date')
    self.report_generate_date = attributes[:'report_generate_date']
  end

  if attributes.key?(:'report_from')
    self.report_from = attributes[:'report_from']
  end

  if attributes.key?(:'report_to')
    self.report_to = attributes[:'report_to']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end

  if attributes.key?(:'country_mandate')
    self.country_mandate = attributes[:'country_mandate']
  end

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  end

  if attributes.key?(:'document_sub_type')
    self.document_sub_type = attributes[:'document_sub_type']
  end

  if attributes.key?(:'report_reference')
    self.report_reference = attributes[:'report_reference']
  end

  if attributes.key?(:'report_name')
    self.report_name = attributes[:'report_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'report_format_mimetypes')
    self.report_format_mimetypes = attributes[:'report_format_mimetypes']
  end

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ta_name')
    self.ta_name = attributes[:'ta_name']
  end

  if attributes.key?(:'tax_invoice_amount')
    self.tax_invoice_amount = attributes[:'tax_invoice_amount']
  end

  if attributes.key?(:'total_tax_amount')
    self.total_tax_amount = attributes[:'total_tax_amount']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'transaction_ids')
    if (value = attributes[:'transaction_ids']).is_a?(Array)
      self.transaction_ids = value
    end
  end
end

Instance Attribute Details

#country_codeObject

The two-letter ISO-3166 country code for which this report was generated.



31
32
33
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 31

def country_code
  @country_code
end

#country_mandateObject

The e-invoicing mandate for the specified country.



34
35
36
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 34

def country_mandate
  @country_mandate
end

#document_sub_typeObject

The sub-type of the document.



40
41
42
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 40

def document_sub_type
  @document_sub_type
end

#document_typeObject

The type of document covered by this report.



37
38
39
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 37

def document_type
  @document_type
end

#job_idObject

The unique ID of the job that generated this report.



19
20
21
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 19

def job_id
  @job_id
end

#metadataObject

Additional report metadata (free-form JSON). Contents vary by country mandate.



67
68
69
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 67

def 
  @metadata
end

#report_format_mimetypesObject

The MIME type of the report file.



52
53
54
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 52

def report_format_mimetypes
  @report_format_mimetypes
end

#report_fromObject

The start date of the reporting period.



25
26
27
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 25

def report_from
  @report_from
end

#report_generate_dateObject

The date and time when the report was generated.



22
23
24
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 22

def report_generate_date
  @report_generate_date
end

#report_idObject

The unique ID for this report.



16
17
18
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 16

def report_id
  @report_id
end

#report_nameObject

The name of the report file.



46
47
48
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 46

def report_name
  @report_name
end

#report_referenceObject

An internal reference path for the report.



43
44
45
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 43

def report_reference
  @report_reference
end

#report_toObject

The end date of the reporting period.



28
29
30
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 28

def report_to
  @report_to
end

#statusObject

The current status of the report. Possible values include: PENDING, PROCESSING, COMPLETED, FAILED, SENT_TO_PPF, ERROR.



49
50
51
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 49

def status
  @status
end

#ta_nameObject

The name of the tax authority for this report.



58
59
60
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 58

def ta_name
  @ta_name
end

#tax_invoice_amountObject

The total invoice amount covered by this report.



61
62
63
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 61

def tax_invoice_amount
  @tax_invoice_amount
end

#tenant_idObject

The tenant identifier associated with this report.



55
56
57
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 55

def tenant_id
  @tenant_id
end

#total_tax_amountObject

The total tax amount covered by this report.



64
65
66
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 64

def total_tax_amount
  @total_tax_amount
end

#transaction_idsObject

List of transaction IDs associated with this report.



70
71
72
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 70

def transaction_ids
  @transaction_ids
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 315

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::EInvoicing::V1.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 73

def self.attribute_map
  {
    :'report_id' => :'reportId',
    :'job_id' => :'jobId',
    :'report_generate_date' => :'reportGenerateDate',
    :'report_from' => :'reportFrom',
    :'report_to' => :'reportTo',
    :'country_code' => :'countryCode',
    :'country_mandate' => :'countryMandate',
    :'document_type' => :'documentType',
    :'document_sub_type' => :'documentSubType',
    :'report_reference' => :'reportReference',
    :'report_name' => :'reportName',
    :'status' => :'status',
    :'report_format_mimetypes' => :'reportFormatMimetypes',
    :'tenant_id' => :'tenantId',
    :'ta_name' => :'taName',
    :'tax_invoice_amount' => :'taxInvoiceAmount',
    :'total_tax_amount' => :'totalTaxAmount',
    :'metadata' => :'metadata',
    :'transaction_ids' => :'transactionIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 128

def self.openapi_nullable
  Set.new([
    :'job_id',
    :'report_from',
    :'report_to',
    :'document_type',
    :'document_sub_type',
    :'report_reference',
    :'tax_invoice_amount',
    :'total_tax_amount',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 103

def self.openapi_types
  {
    :'report_id' => :'String',
    :'job_id' => :'String',
    :'report_generate_date' => :'Time',
    :'report_from' => :'Date',
    :'report_to' => :'Date',
    :'country_code' => :'String',
    :'country_mandate' => :'String',
    :'document_type' => :'String',
    :'document_sub_type' => :'String',
    :'report_reference' => :'String',
    :'report_name' => :'String',
    :'status' => :'String',
    :'report_format_mimetypes' => :'String',
    :'tenant_id' => :'String',
    :'ta_name' => :'String',
    :'tax_invoice_amount' => :'Float',
    :'total_tax_amount' => :'Float',
    :'metadata' => :'Object',
    :'transaction_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 252

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      report_id == o.report_id &&
      job_id == o.job_id &&
      report_generate_date == o.report_generate_date &&
      report_from == o.report_from &&
      report_to == o.report_to &&
      country_code == o.country_code &&
      country_mandate == o.country_mandate &&
      document_type == o.document_type &&
      document_sub_type == o.document_sub_type &&
      report_reference == o.report_reference &&
      report_name == o.report_name &&
      status == o.status &&
      report_format_mimetypes == o.report_format_mimetypes &&
      tenant_id == o.tenant_id &&
      ta_name == o.ta_name &&
      tax_invoice_amount == o.tax_invoice_amount &&
      total_tax_amount == o.total_tax_amount &&
       == o. &&
      transaction_ids == o.transaction_ids
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 386

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 284

def hash
  [report_id, job_id, report_generate_date, report_from, report_to, country_code, country_mandate, document_type, document_sub_type, report_reference, report_name, status, report_format_mimetypes, tenant_id, ta_name, tax_invoice_amount, total_tax_amount, , transaction_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



237
238
239
240
241
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 237

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 362

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 368

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



356
357
358
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 356

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
# File 'lib/avalara_sdk/models/EInvoicing/V1/report_item.rb', line 245

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end