Class: AvalaraSdk::EInvoicing::V1::ReportsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client) ⇒ ReportsApi

Returns a new instance of ReportsApi.



16
17
18
19
20
21
22
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 16

def initialize(api_client)
  if (api_client.nil?)
    fail  ArgumentError,'api_client is nil'
  end
  api_client.set_sdk_version("26.4.0")
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



14
15
16
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 14

def api_client
  @api_client
end

Instance Method Details

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 210

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as typhoeus will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#convert_to_type(data, return_type) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 91

def convert_to_type(data, return_type)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'Time'
    # parse date time (expecting ISO 8601 format)
    Time.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type) }
    end
  else
    # models (e.g. Pet) or oneOf
    klass = AvalaraSdk::EInvoicing::V1.const_get(return_type)
    klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data)
  end
end

#deserialize(response, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array<User>”, “Hash<String, Integer>”



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 39

def deserialize(response, return_type)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  if return_type == 'File'
    content_disposition = response.headers['Content-Disposition']
    if content_disposition && content_disposition =~ /filename=/i
      filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
      prefix = sanitize_filename(filename)
    else
      prefix = 'download-'
    end
    prefix = prefix + '-' unless prefix.end_with?('-')
    encoding = body.encoding
    @tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
    @tempfile.write(@stream.join.force_encoding(encoding))
    @tempfile.close
    @config.logger.info "Temp file written to #{@tempfile.path}, please copy the file to a proper folder "\
                        "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                        "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                        "explicitly with `tempfile.delete`"
    return @tempfile
  end

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date Time).include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type
end

#download_report(request_parameters) ⇒ ReportDownloadResponse

Returns a pre-signed download URL for a report Returns a pre-signed URL to download the report file when it is available. If the report has not yet been generated, a 404 (not found) is returned.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param report_id [String] The unique ID for this report as returned in a GET /reports response. # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;). # @param x_correlation_id [String] Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;).

Returns:



232
233
234
235
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 232

def download_report(request_parameters)
  data, _status_code, _headers = download_report_with_http_info(request_parameters)
  data
end

#download_report_with_http_info(request_parameters) ⇒ Array<(ReportDownloadResponse, Integer, Hash)>

Returns ReportDownloadResponse data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • report_id (String)

    The unique ID for this report as returned in a GET /reports response.

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

  • x_correlation_id (String)

    Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;).

Returns:

  • (Array<(ReportDownloadResponse, Integer, Hash)>)

    ReportDownloadResponse data, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 245

def download_report_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  report_id = request_parameters.get_report_id()
  x_avalara_client = request_parameters.get_x_avalara_client()
  x_correlation_id = request_parameters.get_x_correlation_id()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling ReportsApi.download_report"
  end
  # verify the required parameter 'report_id' is set
  if @api_client.config.client_side_validation && report_id.nil?
    fail ArgumentError, "Missing the required parameter 'report_id' when calling ReportsApi.download_report"
  end
  # resource path
  local_var_path = '/einvoicing/reports/{reportId}/$download'.sub('{' + 'reportId' + '}', CGI.escape(report_id.to_s))

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end
  if !x_correlation_id.nil?
    header_params[:'X-Correlation-ID'] = x_correlation_id
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'ReportDownloadResponse'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"ReportsApi.download_report",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#get_report_by_id(request_parameters) ⇒ ReportItem

Retrieves a report by its unique ID Retrieves a specific report by its unique identifier. Returns complete report details including metadata, status, and associated information.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param report_id [String] The unique ID for this report as returned in a GET /reports response. # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;). # @param x_correlation_id [String] Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;).

Returns:



318
319
320
321
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 318

def get_report_by_id(request_parameters)
  data, _status_code, _headers = get_report_by_id_with_http_info(request_parameters)
  data
end

#get_report_by_id_with_http_info(request_parameters) ⇒ Array<(ReportItem, Integer, Hash)>

Returns ReportItem data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • report_id (String)

    The unique ID for this report as returned in a GET /reports response.

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

  • x_correlation_id (String)

    Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;).

Returns:

  • (Array<(ReportItem, Integer, Hash)>)

    ReportItem data, response status code and response headers



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 331

def get_report_by_id_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  report_id = request_parameters.get_report_id()
  x_avalara_client = request_parameters.get_x_avalara_client()
  x_correlation_id = request_parameters.get_x_correlation_id()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling ReportsApi.get_report_by_id"
  end
  # verify the required parameter 'report_id' is set
  if @api_client.config.client_side_validation && report_id.nil?
    fail ArgumentError, "Missing the required parameter 'report_id' when calling ReportsApi.get_report_by_id"
  end
  # resource path
  local_var_path = '/einvoicing/reports/{reportId}/status'.sub('{' + 'reportId' + '}', CGI.escape(report_id.to_s))

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end
  if !x_correlation_id.nil?
    header_params[:'X-Correlation-ID'] = x_correlation_id
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'ReportItem'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"ReportsApi.get_report_by_id",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#get_reports(request_parameters) ⇒ ReportListResponse

Returns a list of reports Retrieves all reports with optional filtering, paging, and sorting. Results are filtered by tenant. Supports OData-style filtering using the $filter parameter. Use $top and $skip for paging; when more results exist, the response includes @nextLink to fetch the next page. Default sort order is by report generation date (descending).

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;). # @param x_avalara_client [String] Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;). # @param x_correlation_id [String] Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;). # @param filter [String] OData-style filter expression. Supports operators: eq, ne, gt, ge, lt, le, like, ilike, contains. Examples: status eq &#39;COMPLETED&#39;, reportGenerateDate gt &#39;2025-11-01&#39;, transactionIds contains &#39;TXN-2025-001&#39; # @param top [Integer] The number of items to include in the result. # @param skip [Integer] The number of items to skip in the result. # @param count [String] When set to true, the response body also includes the count of items in the collection. # @param count_only [String] When set to true, the response returns only the count of items in the collection. # @param orderby [String] OData-style orderby expression. Format: &#39;field asc&#39; or &#39;field desc&#39;. Default: reportGenerateDate desc

Returns:



404
405
406
407
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 404

def get_reports(request_parameters)
  data, _status_code, _headers = get_reports_with_http_info(request_parameters)
  data
end

#get_reports_with_http_info(request_parameters) ⇒ Array<(ReportListResponse, Integer, Hash)>

Returns ReportListResponse data, response status code and response headers.

Parameters:

  • avalara_version (String)

    Header that specifies the API version to use (for example &quot;1.6&quot;).

  • x_avalara_client (String)

    Optional header for a client identifier string used for diagnostics (for example &quot;Fingerprint&quot;).

  • x_correlation_id (String)

    Optional correlation identifier provided by the caller to trace the call (for example &quot;f3f0d19a-01a1-4748-8a58-f000d0424f43&quot;).

  • filter (String)

    OData-style filter expression. Supports operators: eq, ne, gt, ge, lt, le, like, ilike, contains. Examples: status eq &#39;COMPLETED&#39;, reportGenerateDate gt &#39;2025-11-01&#39;, transactionIds contains &#39;TXN-2025-001&#39;

  • top (Integer)

    The number of items to include in the result.

  • skip (Integer)

    The number of items to skip in the result.

  • count (String)

    When set to true, the response body also includes the count of items in the collection.

  • count_only (String)

    When set to true, the response returns only the count of items in the collection.

  • orderby (String)

    OData-style orderby expression. Format: &#39;field asc&#39; or &#39;field desc&#39;. Default: reportGenerateDate desc

Returns:

  • (Array<(ReportListResponse, Integer, Hash)>)

    ReportListResponse data, response status code and response headers



422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 422

def get_reports_with_http_info(request_parameters)
  # OAuth2 Scopes
  required_scopes = ''
  # Request Parameters
  avalara_version = request_parameters.get_avalara_version()
  x_avalara_client = request_parameters.get_x_avalara_client()
  x_correlation_id = request_parameters.get_x_correlation_id()
  filter = request_parameters.get_filter()
  top = request_parameters.get_top()
  skip = request_parameters.get_skip()
  count = request_parameters.get_count()
  count_only = request_parameters.get_count_only()
  orderby = request_parameters.get_orderby()
  # verify the required parameter 'avalara_version' is set
  if @api_client.config.client_side_validation && avalara_version.nil?
    fail ArgumentError, "Missing the required parameter 'avalara_version' when calling ReportsApi.get_reports"
  end
  # resource path
  local_var_path = '/einvoicing/reports'

  # query parameters
  query_params = {}
  if !filter.nil?
    query_params[:'$filter'] = filter
  end
  if !top.nil?
    query_params[:'$top'] = top
  end
  if !skip.nil?
    query_params[:'$skip'] = skip
  end
  if !count.nil?
    query_params[:'$count'] = count
  end
  if !count_only.nil?
    query_params[:'$countOnly'] = count_only
  end
  if !orderby.nil?
    query_params[:'$orderby'] = orderby
  end

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  if !avalara_version.nil?
    header_params[:'avalara-version'] = avalara_version
  end
  if !x_avalara_client.nil?
    header_params[:'X-Avalara-Client'] = x_avalara_client
  end
  if !x_correlation_id.nil?
    header_params[:'X-Correlation-ID'] = x_correlation_id
  end

  # form parameters
  form_params = {}

  # http body (model)
  post_body = {}

  # return_type
  return_type = 'ReportListResponse'

  # auth_names
  auth_names = ['Bearer']

  @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes)

  new_options = {
    :operation => :"ReportsApi.get_reports",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  }

  response = @api_client.call_api(:GET, local_var_path, new_options, required_scopes, false, :EInvoicing)
  if new_options[:return_type]
    data = deserialize(response, new_options[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#json_mime?(mime) ⇒ Boolean

JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



31
32
33
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 31

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



200
201
202
203
204
205
206
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 200

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    obj.to_hash
  else
    obj
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



186
187
188
189
190
191
192
193
194
195
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 186

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



133
134
135
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 133

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



165
166
167
168
169
170
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 165

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



175
176
177
178
179
180
181
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 175

def select_header_content_type(content_types)
  # return nil by default
  return if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update header and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 142

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` or `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



157
158
159
160
# File 'lib/avalara_sdk/api/EInvoicing/V1/reports_api.rb', line 157

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end