Class: AvalaraSdk::A1099::V2::CompanyRequest
- Inherits:
-
Object
- Object
- AvalaraSdk::A1099::V2::CompanyRequest
- Defined in:
- lib/avalara_sdk/models/A1099/V2/company_request.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Address.
-
#city ⇒ Object
City.
-
#country_code ⇒ Object
Two-letter IRS country code (e.g., ‘US’, ‘CA’), as defined at www.irs.gov/e-file-providers/country-codes.
-
#dba_name ⇒ Object
Doing Business As (DBA) name or continuation of a long legal name.
-
#do_tin_match ⇒ Object
Indicates whether the company authorizes IRS TIN matching.
-
#email ⇒ Object
Contact email address.
-
#foreign_province ⇒ Object
Province or region for non-US/CA addresses.
-
#group_name ⇒ Object
Group name for organizing companies (creates or finds group by name).
-
#max_reminder_attempts ⇒ Object
Maximum number of reminder attempts (1-52, required if resendRequests is true).
-
#name ⇒ Object
Legal name.
-
#reference_id ⇒ Object
Internal reference ID.
-
#resend_interval_days ⇒ Object
Days between reminder emails (7-365, required if resendRequests is true).
-
#resend_requests ⇒ Object
Boolean to enable automatic reminder emails (default: false).
-
#state ⇒ Object
Two-letter US state or Canadian province code (required for US/CA addresses).
-
#telephone ⇒ Object
Contact phone number (must contain at least 10 digits, max 15 characters).
-
#tin ⇒ Object
Federal Tax Identification Number (TIN).
-
#zip ⇒ Object
ZIP/postal code.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompanyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CompanyRequest
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AvalaraSdk::A1099::V2::CompanyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AvalaraSdk::A1099::V2::CompanyRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'dba_name') self.dba_name = attributes[:'dba_name'] end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'city') self.city = attributes[:'city'] else self.city = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'zip') self.zip = attributes[:'zip'] else self.zip = nil end if attributes.key?(:'telephone') self.telephone = attributes[:'telephone'] else self.telephone = nil end if attributes.key?(:'tin') self.tin = attributes[:'tin'] else self.tin = nil end if attributes.key?(:'reference_id') self.reference_id = attributes[:'reference_id'] end if attributes.key?(:'do_tin_match') self.do_tin_match = attributes[:'do_tin_match'] end if attributes.key?(:'group_name') self.group_name = attributes[:'group_name'] end if attributes.key?(:'foreign_province') self.foreign_province = attributes[:'foreign_province'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] else self.country_code = nil end if attributes.key?(:'resend_requests') self.resend_requests = attributes[:'resend_requests'] end if attributes.key?(:'resend_interval_days') self.resend_interval_days = attributes[:'resend_interval_days'] end if attributes.key?(:'max_reminder_attempts') self.max_reminder_attempts = attributes[:'max_reminder_attempts'] end end |
Instance Attribute Details
#address ⇒ Object
Address.
24 25 26 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 24 def address @address end |
#city ⇒ Object
City.
27 28 29 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 27 def city @city end |
#country_code ⇒ Object
Two-letter IRS country code (e.g., ‘US’, ‘CA’), as defined at www.irs.gov/e-file-providers/country-codes.
54 55 56 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 54 def country_code @country_code end |
#dba_name ⇒ Object
Doing Business As (DBA) name or continuation of a long legal name.
18 19 20 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 18 def dba_name @dba_name end |
#do_tin_match ⇒ Object
Indicates whether the company authorizes IRS TIN matching.
45 46 47 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 45 def do_tin_match @do_tin_match end |
#email ⇒ Object
Contact email address. For inquiries by vendors/employees.
21 22 23 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 21 def email @email end |
#foreign_province ⇒ Object
Province or region for non-US/CA addresses.
51 52 53 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 51 def foreign_province @foreign_province end |
#group_name ⇒ Object
Group name for organizing companies (creates or finds group by name).
48 49 50 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 48 def group_name @group_name end |
#max_reminder_attempts ⇒ Object
Maximum number of reminder attempts (1-52, required if resendRequests is true).
63 64 65 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 63 def max_reminder_attempts @max_reminder_attempts end |
#name ⇒ Object
Legal name. Not the DBA name.
15 16 17 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 15 def name @name end |
#reference_id ⇒ Object
Internal reference ID. Never shown to any agency or recipient.
42 43 44 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 42 def reference_id @reference_id end |
#resend_interval_days ⇒ Object
Days between reminder emails (7-365, required if resendRequests is true).
60 61 62 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 60 def resend_interval_days @resend_interval_days end |
#resend_requests ⇒ Object
Boolean to enable automatic reminder emails (default: false).
57 58 59 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 57 def resend_requests @resend_requests end |
#state ⇒ Object
Two-letter US state or Canadian province code (required for US/CA addresses).
30 31 32 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 30 def state @state end |
#telephone ⇒ Object
Contact phone number (must contain at least 10 digits, max 15 characters).
36 37 38 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 36 def telephone @telephone end |
#tin ⇒ Object
Federal Tax Identification Number (TIN). EIN/Tax ID (required for US companies).
39 40 41 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 39 def tin @tin end |
#zip ⇒ Object
ZIP/postal code.
33 34 35 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 33 def zip @zip end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 324 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AvalaraSdk::A1099::V2.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 66 def self.attribute_map { :'name' => :'name', :'dba_name' => :'dbaName', :'email' => :'email', :'address' => :'address', :'city' => :'city', :'state' => :'state', :'zip' => :'zip', :'telephone' => :'telephone', :'tin' => :'tin', :'reference_id' => :'referenceId', :'do_tin_match' => :'doTinMatch', :'group_name' => :'groupName', :'foreign_province' => :'foreignProvince', :'country_code' => :'countryCode', :'resend_requests' => :'resendRequests', :'resend_interval_days' => :'resendIntervalDays', :'max_reminder_attempts' => :'maxReminderAttempts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
140 141 142 143 144 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 140 def self.openapi_all_of [ :'CompanyBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 117 def self.openapi_nullable Set.new([ :'name', :'dba_name', :'email', :'address', :'city', :'state', :'zip', :'telephone', :'tin', :'reference_id', :'do_tin_match', :'group_name', :'foreign_province', :'country_code', :'resend_requests', :'resend_interval_days', :'max_reminder_attempts' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 94 def self.openapi_types { :'name' => :'String', :'dba_name' => :'String', :'email' => :'String', :'address' => :'String', :'city' => :'String', :'state' => :'String', :'zip' => :'String', :'telephone' => :'String', :'tin' => :'String', :'reference_id' => :'String', :'do_tin_match' => :'Boolean', :'group_name' => :'String', :'foreign_province' => :'String', :'country_code' => :'String', :'resend_requests' => :'Boolean', :'resend_interval_days' => :'Integer', :'max_reminder_attempts' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 263 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && dba_name == o.dba_name && email == o.email && address == o.address && city == o.city && state == o.state && zip == o.zip && telephone == o.telephone && tin == o.tin && reference_id == o.reference_id && do_tin_match == o.do_tin_match && group_name == o.group_name && foreign_province == o.foreign_province && country_code == o.country_code && resend_requests == o.resend_requests && resend_interval_days == o.resend_interval_days && max_reminder_attempts == o.max_reminder_attempts end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 395 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 293 def hash [name, dba_name, email, address, city, state, zip, telephone, tin, reference_id, do_tin_match, group_name, foreign_province, country_code, resend_requests, resend_interval_days, max_reminder_attempts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
248 249 250 251 252 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 248 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
371 372 373 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 371 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
365 366 367 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 365 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
256 257 258 259 |
# File 'lib/avalara_sdk/models/A1099/V2/company_request.rb', line 256 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |