Class: AvalaraSdk::EInvoicing::V1::CodeListsApi
- Inherits:
-
Object
- Object
- AvalaraSdk::EInvoicing::V1::CodeListsApi
- Defined in:
- lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#build_collection_param(param, collection_format) ⇒ Object
Build parameter value according to the given collection format.
-
#convert_to_type(data, return_type) ⇒ Mixed
Convert data to the given return type.
-
#deserialize(response, return_type) ⇒ Object
Deserialize the response to the given return type.
-
#get_code_list(request_parameters) ⇒ CodeListResponse
Retrieves a code list by ID for a specific country A Code List is a controlled set of predefined, standardized values used to populate specific fields in electronic documents (such as e-invoices).
-
#get_code_list_list(request_parameters) ⇒ CodeListListResponse
Returns a list of code lists for a specific country Get a list of code lists on the Avalara E-Invoicing platform for the specified country.
-
#get_code_list_list_with_http_info(request_parameters) ⇒ Array<(CodeListListResponse, Integer, Hash)>
CodeListListResponse data, response status code and response headers.
-
#get_code_list_with_http_info(request_parameters) ⇒ Array<(CodeListResponse, Integer, Hash)>
CodeListResponse data, response status code and response headers.
-
#initialize(api_client) ⇒ CodeListsApi
constructor
A new instance of CodeListsApi.
-
#json_mime?(mime) ⇒ Boolean
JSON MIME examples: application/json application/json; charset=UTF8 APPLICATION/JSON /.
-
#object_to_hash(obj) ⇒ String
Convert object(non-array) to hash.
-
#object_to_http_body(model) ⇒ String
Convert object (array, hash, object, etc) to JSON string.
-
#sanitize_filename(filename) ⇒ String
Sanitize filename by removing path.
-
#select_header_accept(accepts) ⇒ String
Return Accept header based on an array of accepts provided.
-
#select_header_content_type(content_types) ⇒ String
Return Content-Type header based on an array of content types provided.
-
#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object
Update header and query params based on authentication settings.
-
#user_agent=(user_agent) ⇒ Object
Sets user agent in HTTP header.
Constructor Details
#initialize(api_client) ⇒ CodeListsApi
Returns a new instance of CodeListsApi.
16 17 18 19 20 21 22 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 16 def initialize(api_client) if (api_client.nil?) fail ArgumentError,'api_client is nil' end api_client.set_sdk_version("26.4.0") @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#build_collection_param(param, collection_format) ⇒ Object
Build parameter value according to the given collection format.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 210 def build_collection_param(param, collection_format) case collection_format when :csv param.join(',') when :ssv param.join(' ') when :tsv param.join("\t") when :pipes param.join('|') when :multi # return the array directly as typhoeus will handle it as expected param else fail "unknown collection format: #{collection_format.inspect}" end end |
#convert_to_type(data, return_type) ⇒ Mixed
Convert data to the given return type.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 91 def convert_to_type(data, return_type) return nil if data.nil? case return_type when 'String' data.to_s when 'Integer' data.to_i when 'Float' data.to_f when 'Boolean' data == true when 'Time' # parse date time (expecting ISO 8601 format) Time.parse data when 'Date' # parse date time (expecting ISO 8601 format) Date.parse data when 'Object' # generic object (usually a Hash), return directly data when /\AArray<(.+)>\z/ # e.g. Array<Pet> sub_type = $1 data.map { |item| convert_to_type(item, sub_type) } when /\AHash\<String, (.+)\>\z/ # e.g. Hash<String, Integer> sub_type = $1 {}.tap do |hash| data.each { |k, v| hash[k] = convert_to_type(v, sub_type) } end else # models (e.g. Pet) or oneOf klass = AvalaraSdk::EInvoicing::V1.const_get(return_type) klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data) end end |
#deserialize(response, return_type) ⇒ Object
Deserialize the response to the given return type.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 39 def deserialize(response, return_type) body = response.body # handle file downloading - return the File instance processed in request callbacks # note that response body is empty when the file is written in chunks in request on_body callback if return_type == 'File' content_disposition = response.headers['Content-Disposition'] if content_disposition && content_disposition =~ /filename=/i filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1] prefix = sanitize_filename(filename) else prefix = 'download-' end prefix = prefix + '-' unless prefix.end_with?('-') encoding = body.encoding @tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding) @tempfile.write(@stream.join.force_encoding(encoding)) @tempfile.close @config.logger.info "Temp file written to #{@tempfile.path}, please copy the file to a proper folder "\ "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\ "will be deleted automatically with GC. It's also recommended to delete the temp file "\ "explicitly with `tempfile.delete`" return @tempfile end return nil if body.nil? || body.empty? # return response body directly for String return type return body if return_type == 'String' # ensuring a default content type content_type = response.headers['Content-Type'] || 'application/json' fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type) begin data = JSON.parse("[#{body}]", :symbolize_names => true)[0] rescue JSON::ParserError => e if %w(String Date Time).include?(return_type) data = body else raise e end end convert_to_type data, return_type end |
#get_code_list(request_parameters) ⇒ CodeListResponse
Retrieves a code list by ID for a specific country A Code List is a controlled set of predefined, standardized values used to populate specific fields in electronic documents (such as e-invoices). Each code has a stable, machine-readable identifier and a human-readable description. Code Lists are typically based on global standards (e.g., UN/CEFACT, ISO, EN16931) and may include jurisdiction-specific extensions or restrictions.
Code Lists are versioned, and each version may have defined effective and sunset dates to ensure that the correct set of allowable values is applied according to regulatory or jurisdictional requirements.
By default, the API returns only non-expired code list versions (versions where the sunset date has not passed). To retrieve expired versions or filter by specific date ranges, use the effectiveDate and sunsetDate query parameters.
232 233 234 235 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 232 def get_code_list(request_parameters) data, _status_code, _headers = get_code_list_with_http_info(request_parameters) data end |
#get_code_list_list(request_parameters) ⇒ CodeListListResponse
Returns a list of code lists for a specific country Get a list of code lists on the Avalara E-Invoicing platform for the specified country. By default, the API returns only non-expired code lists (code lists where the sunset date has not passed). To retrieve expired code lists or filter by specific date ranges, use the effectiveDate and sunsetDate query parameters.
A Code List is a controlled set of predefined, standardized values used to populate specific fields in electronic documents (such as e-invoices). Each code has a stable, machine-readable identifier and a human-readable description. Code Lists are typically based on global standards (e.g., UN/CEFACT, ISO, EN16931) and may include jurisdiction-specific extensions or restrictions.
332 333 334 335 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 332 def get_code_list_list(request_parameters) data, _status_code, _headers = get_code_list_list_with_http_info(request_parameters) data end |
#get_code_list_list_with_http_info(request_parameters) ⇒ Array<(CodeListListResponse, Integer, Hash)>
Returns CodeListListResponse data, response status code and response headers.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 350 def get_code_list_list_with_http_info(request_parameters) # OAuth2 Scopes required_scopes = '' # Request Parameters avalara_version = request_parameters.get_avalara_version() country_code = request_parameters.get_country_code() x_avalara_client = request_parameters.get_x_avalara_client() effective_date = request_parameters.get_effective_date() sunset_date = request_parameters.get_sunset_date() count = request_parameters.get_count() count_only = request_parameters.get_count_only() top = request_parameters.get_top() skip = request_parameters.get_skip() # verify the required parameter 'avalara_version' is set if @api_client.config.client_side_validation && avalara_version.nil? fail ArgumentError, "Missing the required parameter 'avalara_version' when calling CodeListsApi.get_code_list_list" end # verify the required parameter 'country_code' is set if @api_client.config.client_side_validation && country_code.nil? fail ArgumentError, "Missing the required parameter 'country_code' when calling CodeListsApi.get_code_list_list" end # resource path local_var_path = '/einvoicing/codelists' # query parameters query_params = {} if !country_code.nil? query_params[:'countryCode'] = country_code end if !effective_date.nil? query_params[:'effectiveDate'] = effective_date end if !sunset_date.nil? query_params[:'sunsetDate'] = sunset_date end if !count.nil? query_params[:'$count'] = count end if !count_only.nil? query_params[:'$countOnly'] = count_only end if !top.nil? query_params[:'$top'] = top end if !skip.nil? query_params[:'$skip'] = skip end # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) if !avalara_version.nil? header_params[:'avalara-version'] = avalara_version end if !x_avalara_client.nil? header_params[:'X-Avalara-Client'] = x_avalara_client end # form parameters form_params = {} # http body (model) post_body = {} # return_type return_type = 'CodeListListResponse' # auth_names auth_names = ['Bearer'] @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes) = { :operation => :"CodeListsApi.get_code_list_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type } response = @api_client.call_api(:GET, local_var_path, , required_scopes, false, :EInvoicing) if [:return_type] data = deserialize(response, [:return_type]) else data = nil end return data, response.code, response.headers end |
#get_code_list_with_http_info(request_parameters) ⇒ Array<(CodeListResponse, Integer, Hash)>
Returns CodeListResponse data, response status code and response headers.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 247 def get_code_list_with_http_info(request_parameters) # OAuth2 Scopes required_scopes = '' # Request Parameters avalara_version = request_parameters.get_avalara_version() codelist_id = request_parameters.get_codelist_id() country_code = request_parameters.get_country_code() x_avalara_client = request_parameters.get_x_avalara_client() effective_date = request_parameters.get_effective_date() sunset_date = request_parameters.get_sunset_date() # verify the required parameter 'avalara_version' is set if @api_client.config.client_side_validation && avalara_version.nil? fail ArgumentError, "Missing the required parameter 'avalara_version' when calling CodeListsApi.get_code_list" end # verify the required parameter 'codelist_id' is set if @api_client.config.client_side_validation && codelist_id.nil? fail ArgumentError, "Missing the required parameter 'codelist_id' when calling CodeListsApi.get_code_list" end # verify the required parameter 'country_code' is set if @api_client.config.client_side_validation && country_code.nil? fail ArgumentError, "Missing the required parameter 'country_code' when calling CodeListsApi.get_code_list" end # resource path local_var_path = '/einvoicing/codelists/{codelistId}'.sub('{' + 'codelistId' + '}', CGI.escape(codelist_id.to_s)) # query parameters query_params = {} if !country_code.nil? query_params[:'countryCode'] = country_code end if !effective_date.nil? query_params[:'effectiveDate'] = effective_date end if !sunset_date.nil? query_params[:'sunsetDate'] = sunset_date end # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) if !avalara_version.nil? header_params[:'avalara-version'] = avalara_version end if !x_avalara_client.nil? header_params[:'X-Avalara-Client'] = x_avalara_client end # form parameters form_params = {} # http body (model) post_body = {} # return_type return_type = 'CodeListResponse' # auth_names auth_names = ['Bearer'] @api_client.apply_auth_to_request!(header_params, auth_names, required_scopes) = { :operation => :"CodeListsApi.get_code_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type } response = @api_client.call_api(:GET, local_var_path, , required_scopes, false, :EInvoicing) if [:return_type] data = deserialize(response, [:return_type]) else data = nil end return data, response.code, response.headers end |
#json_mime?(mime) ⇒ Boolean
JSON MIME examples:
application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*
31 32 33 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 31 def json_mime?(mime) (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil? end |
#object_to_hash(obj) ⇒ String
Convert object(non-array) to hash.
200 201 202 203 204 205 206 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 200 def object_to_hash(obj) if obj.respond_to?(:to_hash) obj.to_hash else obj end end |
#object_to_http_body(model) ⇒ String
Convert object (array, hash, object, etc) to JSON string.
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 186 def object_to_http_body(model) return model if model.nil? || model.is_a?(String) local_body = nil if model.is_a?(Array) local_body = model.map { |m| object_to_hash(m) } else local_body = object_to_hash(model) end local_body.to_json end |
#sanitize_filename(filename) ⇒ String
Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif
133 134 135 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 133 def sanitize_filename(filename) filename.gsub(/.*[\/\\]/, '') end |
#select_header_accept(accepts) ⇒ String
Return Accept header based on an array of accepts provided.
165 166 167 168 169 170 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 165 def select_header_accept(accepts) return nil if accepts.nil? || accepts.empty? # use JSON when present, otherwise use all of the provided json_accept = accepts.find { |s| json_mime?(s) } json_accept || accepts.join(',') end |
#select_header_content_type(content_types) ⇒ String
Return Content-Type header based on an array of content types provided.
175 176 177 178 179 180 181 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 175 def select_header_content_type(content_types) # return nil by default return if content_types.nil? || content_types.empty? # use JSON when present, otherwise use the first one json_content_type = content_types.find { |s| json_mime?(s) } json_content_type || content_types.first end |
#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object
Update header and query params based on authentication settings.
142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 142 def update_params_for_auth!(header_params, query_params, auth_names) Array(auth_names).each do |auth_name| auth_setting = @config.auth_settings[auth_name] next unless auth_setting case auth_setting[:in] when 'header' then header_params[auth_setting[:key]] = auth_setting[:value] when 'query' then query_params[auth_setting[:key]] = auth_setting[:value] else fail ArgumentError, 'Authentication token must be in `query` or `header`' end end end |
#user_agent=(user_agent) ⇒ Object
Sets user agent in HTTP header
157 158 159 160 |
# File 'lib/avalara_sdk/api/EInvoicing/V1/code_lists_api.rb', line 157 def user_agent=(user_agent) @user_agent = user_agent @default_headers['User-Agent'] = @user_agent end |